@@ -32,7 +32,7 @@ pub struct StaticCanvasPrompt {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct StaticImagePrompt {
     /// Required. The source url of the image. Images can be JPG, PNG and GIF (animated and
-    /// non-animated). For example,`https://www.agentx.com/logo.png`.
+    /// non-animated). For example,`<https://www.agentx.com/logo.png`.>
     #[prost(string, tag = "1")]
     pub url: ::prost::alloc::string::String,
     /// Required. A text description of the image to be used for accessibility, e.g. screen
@@ -247,11 +247,7 @@ pub struct StaticMediaPrompt {
     /// If set, request will be made to 3p when a certain media event happens.
     /// If not set, 3p must still handle two default control type, FINISHED and
     /// FAILED.
-    #[prost(
-        enumeration = "static_media_prompt::OptionalMediaControls",
-        repeated,
-        tag = "6"
-    )]
+    #[prost(enumeration = "static_media_prompt::OptionalMediaControls", repeated, tag = "6")]
     pub optional_media_controls: ::prost::alloc::vec::Vec<i32>,
     /// List of media objects.
     #[prost(message, repeated, tag = "7")]
