@@ -88,7 +88,7 @@ pub mod assist_response {
 pub struct DebugInfo {
     /// The original JSON response from an Action-on-Google agent to Google server.
     /// See
-    /// https://developers.google.com/actions/reference/rest/Shared.Types/AppResponse.
+    /// <https://developers.google.com/actions/reference/rest/Shared.Types/AppResponse.>
     /// It will only be populated if the request maker owns the AoG project and the
     /// AoG project is in preview mode.
     #[prost(string, tag = "1")]
@@ -121,7 +121,7 @@ pub mod assist_config {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Type {
         /// Specifies how to process the subsequent incoming audio. Required if
-        /// [AssistRequest.audio_in][google.assistant.embedded.v1alpha2.AssistRequest.audio_in]
+        /// \[AssistRequest.audio_in][google.assistant.embedded.v1alpha2.AssistRequest.audio_in\]
         /// bytes will be provided in subsequent requests.
         #[prost(message, tag = "1")]
         AudioInConfig(super::AudioInConfig),
@@ -134,7 +134,7 @@ pub mod assist_config {
 /// Specifies how to process the `audio_in` data that will be provided in
 /// subsequent requests. For recommended settings, see the Google Assistant SDK
 /// [best
-/// practices](https://developers.google.com/assistant/sdk/guides/service/python/best-practices/audio).
+/// practices](<https://developers.google.com/assistant/sdk/guides/service/python/best-practices/audio>).
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AudioInConfig {
     /// *Required* Encoding of audio data sent in all `audio_in` messages.
@@ -155,12 +155,12 @@ pub mod audio_in_config {
     #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
     #[repr(i32)]
     pub enum Encoding {
-        /// Not specified. Will return result [google.rpc.Code.INVALID_ARGUMENT][].
+        /// Not specified. Will return result \[google.rpc.Code.INVALID_ARGUMENT][\].
         Unspecified = 0,
         /// Uncompressed 16-bit signed little-endian samples (Linear PCM).
         /// This encoding includes no header, only the raw audio bytes.
         Linear16 = 1,
-        /// [`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio
+        /// \[`FLAC`\](<https://xiph.org/flac/documentation.html>) (Free Lossless Audio
         /// Codec) is the recommended encoding because it is
         /// lossless--therefore recognition is not compromised--and
         /// requires only about half the bandwidth of `LINEAR16`. This encoding
@@ -194,7 +194,7 @@ pub mod audio_out_config {
     #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
     #[repr(i32)]
     pub enum Encoding {
-        /// Not specified. Will return result [google.rpc.Code.INVALID_ARGUMENT][].
+        /// Not specified. Will return result \[google.rpc.Code.INVALID_ARGUMENT][\].
         Unspecified = 0,
         /// Uncompressed 16-bit signed little-endian samples (Linear PCM).
         Linear16 = 1,
@@ -237,7 +237,7 @@ pub mod screen_out_config {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DialogStateIn {
     /// *Required* This field must always be set to the
-    /// [DialogStateOut.conversation_state][google.assistant.embedded.v1alpha2.DialogStateOut.conversation_state]
+    /// \[DialogStateOut.conversation_state][google.assistant.embedded.v1alpha2.DialogStateOut.conversation_state\]
     /// value that was returned in the prior `Assist` RPC. It should only be
     /// omitted (field not set) if there was no prior `Assist` RPC because this is
     /// the first `Assist` RPC made by this device after it was first setup and/or
@@ -245,12 +245,12 @@ pub struct DialogStateIn {
     #[prost(bytes = "vec", tag = "1")]
     pub conversation_state: ::prost::alloc::vec::Vec<u8>,
     /// *Required* Language of the request in
-    /// [IETF BCP 47 syntax](https://tools.ietf.org/html/bcp47) (for example,
+    /// [IETF BCP 47 syntax](<https://tools.ietf.org/html/bcp47>) (for example,
     /// "en-US"). See [Language
-    /// Support](https://developers.google.com/assistant/sdk/reference/rpc/languages)
+    /// Support](<https://developers.google.com/assistant/sdk/reference/rpc/languages>)
     /// for more information. If you have selected a language for this `device_id`
     /// using the
-    /// [Settings](https://developers.google.com/assistant/sdk/reference/assistant-app/assistant-settings)
+    /// \[Settings\](<https://developers.google.com/assistant/sdk/reference/assistant-app/assistant-settings>)
     /// menu in your phone's Google Assistant app, that selection will override
     /// this value.
     #[prost(string, tag = "2")]
@@ -270,11 +270,11 @@ pub struct DialogStateIn {
 /// See also:
 ///
 /// *   [Register a Device - REST
-/// API](https://developers.google.com/assistant/sdk/reference/device-registration/register-device-manual)
+/// API](<https://developers.google.com/assistant/sdk/reference/device-registration/register-device-manual>)
 /// *   [Device Model and Instance
-/// Schemas](https://developers.google.com/assistant/sdk/reference/device-registration/model-and-instance-schemas)
+/// Schemas](<https://developers.google.com/assistant/sdk/reference/device-registration/model-and-instance-schemas>)
 /// *   [Device
-/// Proto](https://developers.google.com/assistant/sdk/reference/rpc/google.assistant.devices.v1alpha2#device)
+/// Proto](<https://developers.google.com/assistant/sdk/reference/rpc/google.assistant.devices.v1alpha2#device>)
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeviceConfig {
     /// *Required* Unique identifier for the device. The id length must be 128
@@ -338,7 +338,7 @@ pub struct DeviceAction {
     /// JSON containing the device command response generated from the triggered
     /// Device Action grammar. The format is given by the
     /// `action.devices.EXECUTE` intent for a given
-    /// [trait](https://developers.google.com/assistant/sdk/reference/traits/).
+    /// \[trait\](<https://developers.google.com/assistant/sdk/reference/traits/>).
     #[prost(string, tag = "1")]
     pub device_request_json: ::prost::alloc::string::String,
 }
@@ -367,7 +367,7 @@ pub struct DialogStateOut {
     pub supplemental_display_text: ::prost::alloc::string::String,
     /// *Output-only* State information for the subsequent `Assist` RPC. This
     /// value should be saved in the client and returned in the
-    /// [`DialogStateIn.conversation_state`](#dialogstatein) field with the next
+    /// \[`DialogStateIn.conversation_state`\](#dialogstatein) field with the next
     /// `Assist` RPC. (The client does not need to interpret or otherwise use this
     /// value.) This information should be saved across device reboots. However,
     /// this value should be cleared (not saved in the client) during a
@@ -450,7 +450,7 @@ pub mod embedded_assistant_client {
     impl<T> EmbeddedAssistantClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -463,7 +463,7 @@ pub mod embedded_assistant_client {
             interceptor: F,
         ) -> EmbeddedAssistantClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -546,9 +546,7 @@ pub mod embedded_assistant_client {
             let path = http::uri::PathAndQuery::from_static(
                 "/google.assistant.embedded.v1alpha2.EmbeddedAssistant/Assist",
             );
-            self.inner
-                .streaming(request.into_streaming_request(), path, codec)
-                .await
+            self.inner.streaming(request.into_streaming_request(), path, codec).await
         }
     }
 }
