@@ -10,10 +10,7 @@ pub struct AutoMlImageClassification {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlImageClassificationInputs {
-    #[prost(
-        enumeration = "auto_ml_image_classification_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_image_classification_inputs::ModelType", tag = "1")]
     pub model_type: i32,
     /// The ID of the `base` model. If it is specified, the new model will be
     /// trained based on the `base` model. Otherwise, the new model will be
@@ -122,10 +119,7 @@ pub struct AutoMlImageObjectDetection {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlImageObjectDetectionInputs {
-    #[prost(
-        enumeration = "auto_ml_image_object_detection_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_image_object_detection_inputs::ModelType", tag = "1")]
     pub model_type: i32,
     /// The training budget of creating this model, expressed in milli node
     /// hours i.e. 1,000 value in this field means 1 node hour. The actual
@@ -225,10 +219,7 @@ pub struct AutoMlImageSegmentation {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlImageSegmentationInputs {
-    #[prost(
-        enumeration = "auto_ml_image_segmentation_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_image_segmentation_inputs::ModelType", tag = "1")]
     pub model_type: i32,
     /// The training budget of creating this model, expressed in milli node
     /// hours i.e. 1,000 value in this field means 1 node hour. The actual
@@ -284,10 +275,7 @@ pub struct AutoMlImageSegmentationMetadata {
     pub cost_milli_node_hours: i64,
     /// For successful job completions, this is the reason why the job has
     /// finished.
-    #[prost(
-        enumeration = "auto_ml_image_segmentation_metadata::SuccessfulStopReason",
-        tag = "2"
-    )]
+    #[prost(enumeration = "auto_ml_image_segmentation_metadata::SuccessfulStopReason", tag = "2")]
     pub successful_stop_reason: i32,
 }
 /// Nested message and enum types in `AutoMlImageSegmentationMetadata`.
@@ -416,10 +404,7 @@ pub struct AutoMlTablesInputs {
     /// Additional optimization objective configuration. Required for
     /// `maximize-precision-at-recall` and `maximize-recall-at-precision`,
     /// otherwise unused.
-    #[prost(
-        oneof = "auto_ml_tables_inputs::AdditionalOptimizationObjectiveConfig",
-        tags = "5, 6"
-    )]
+    #[prost(oneof = "auto_ml_tables_inputs::AdditionalOptimizationObjectiveConfig", tags = "5, 6")]
     pub additional_optimization_objective_config:
         ::core::option::Option<auto_ml_tables_inputs::AdditionalOptimizationObjectiveConfig>,
 }
@@ -429,10 +414,7 @@ pub mod auto_ml_tables_inputs {
     pub struct Transformation {
         /// The transformation that the training pipeline will apply to the input
         /// columns.
-        #[prost(
-            oneof = "transformation::TransformationDetail",
-            tags = "1, 2, 3, 4, 5, 6, 7, 8"
-        )]
+        #[prost(oneof = "transformation::TransformationDetail", tags = "1, 2, 3, 4, 5, 6, 7, 8")]
         pub transformation_detail: ::core::option::Option<transformation::TransformationDetail>,
     }
     /// Nested message and enum types in `Transformation`.
@@ -663,10 +645,7 @@ pub struct AutoMlVideoActionRecognition {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlVideoActionRecognitionInputs {
-    #[prost(
-        enumeration = "auto_ml_video_action_recognition_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_video_action_recognition_inputs::ModelType", tag = "1")]
     pub model_type: i32,
 }
 /// Nested message and enum types in `AutoMlVideoActionRecognitionInputs`.
@@ -702,10 +681,7 @@ pub struct AutoMlVideoClassification {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlVideoClassificationInputs {
-    #[prost(
-        enumeration = "auto_ml_video_classification_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_video_classification_inputs::ModelType", tag = "1")]
     pub model_type: i32,
 }
 /// Nested message and enum types in `AutoMlVideoClassificationInputs`.
@@ -737,10 +713,7 @@ pub struct AutoMlVideoObjectTracking {
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AutoMlVideoObjectTrackingInputs {
-    #[prost(
-        enumeration = "auto_ml_video_object_tracking_inputs::ModelType",
-        tag = "1"
-    )]
+    #[prost(enumeration = "auto_ml_video_object_tracking_inputs::ModelType", tag = "1")]
     pub model_type: i32,
 }
 /// Nested message and enum types in `AutoMlVideoObjectTrackingInputs`.
