@@ -40,27 +40,27 @@ pub struct BoundingPoly {
 pub struct Document {
     /// An IANA published MIME type (also referred to as media type). For more
     /// information, see
-    /// https://www.iana.org/assignments/media-types/media-types.xhtml.
+    /// <https://www.iana.org/assignments/media-types/media-types.xhtml.>
     #[prost(string, tag = "3")]
     pub mime_type: ::prost::alloc::string::String,
     /// UTF-8 encoded text in reading order from the document.
     #[prost(string, tag = "4")]
     pub text: ::prost::alloc::string::String,
     /// Styles for the
-    /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+    /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
     #[prost(message, repeated, tag = "5")]
     pub text_styles: ::prost::alloc::vec::Vec<document::Style>,
     /// Visual page layout for the
-    /// [Document][google.cloud.documentai.v1beta1.Document].
+    /// \[Document][google.cloud.documentai.v1beta1.Document\].
     #[prost(message, repeated, tag = "6")]
     pub pages: ::prost::alloc::vec::Vec<document::Page>,
     /// A list of entities detected on
-    /// [Document.text][google.cloud.documentai.v1beta1.Document.text]. For
+    /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\]. For
     /// document shards, entities in this list may cross shard boundaries.
     #[prost(message, repeated, tag = "7")]
     pub entities: ::prost::alloc::vec::Vec<document::Entity>,
     /// Relationship among
-    /// [Document.entities][google.cloud.documentai.v1beta1.Document.entities].
+    /// \[Document.entities][google.cloud.documentai.v1beta1.Document.entities\].
     #[prost(message, repeated, tag = "8")]
     pub entity_relations: ::prost::alloc::vec::Vec<document::EntityRelation>,
     /// Information about the sharding if this document is sharded part of a larger
@@ -88,7 +88,7 @@ pub mod document {
         #[prost(int64, tag = "2")]
         pub shard_count: i64,
         /// The index of the first character in
-        /// [Document.text][google.cloud.documentai.v1beta1.Document.text] in the
+        /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\] in the
         /// overall document global text.
         #[prost(int64, tag = "3")]
         pub text_offset: i64,
@@ -98,7 +98,7 @@ pub mod document {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Style {
         /// Text anchor indexing into the
-        /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+        /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Text color.
@@ -108,16 +108,16 @@ pub mod document {
         #[prost(message, optional, tag = "3")]
         pub background_color: ::core::option::Option<super::super::super::super::r#type::Color>,
         /// Font weight. Possible values are normal, bold, bolder, and lighter.
-        /// https://www.w3schools.com/cssref/pr_font_weight.asp
+        /// <https://www.w3schools.com/cssref/pr_font_weight.asp>
         #[prost(string, tag = "4")]
         pub font_weight: ::prost::alloc::string::String,
         /// Text style. Possible values are normal, italic, and oblique.
-        /// https://www.w3schools.com/cssref/pr_font_font-style.asp
+        /// <https://www.w3schools.com/cssref/pr_font_font-style.asp>
         #[prost(string, tag = "5")]
         pub text_style: ::prost::alloc::string::String,
         /// Text decoration. Follows CSS standard.
         /// <text-decoration-line> <text-decoration-color> <text-decoration-style>
-        /// https://www.w3schools.com/cssref/pr_text_text-decoration.asp
+        /// <https://www.w3schools.com/cssref/pr_text_text-decoration.asp>
         #[prost(string, tag = "6")]
         pub text_decoration: ::prost::alloc::string::String,
         /// Font size.
@@ -137,20 +137,20 @@ pub mod document {
             pub unit: ::prost::alloc::string::String,
         }
     }
-    /// A page in a [Document][google.cloud.documentai.v1beta1.Document].
+    /// A page in a \[Document][google.cloud.documentai.v1beta1.Document\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Page {
         /// 1-based index for current
-        /// [Page][google.cloud.documentai.v1beta1.Document.Page] in a parent
-        /// [Document][google.cloud.documentai.v1beta1.Document]. Useful when a page
-        /// is taken out of a [Document][google.cloud.documentai.v1beta1.Document]
+        /// \[Page][google.cloud.documentai.v1beta1.Document.Page\] in a parent
+        /// \[Document][google.cloud.documentai.v1beta1.Document\]. Useful when a page
+        /// is taken out of a \[Document][google.cloud.documentai.v1beta1.Document\]
         /// for individual processing.
         #[prost(int32, tag = "1")]
         pub page_number: i32,
         /// Physical dimension of the page.
         #[prost(message, optional, tag = "2")]
         pub dimension: ::core::option::Option<page::Dimension>,
-        /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for the
+        /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for the
         /// page.
         #[prost(message, optional, tag = "3")]
         pub layout: ::core::option::Option<page::Layout>,
@@ -203,22 +203,22 @@ pub mod document {
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Layout {
             /// Text anchor indexing into the
-            /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+            /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
             #[prost(message, optional, tag = "1")]
             pub text_anchor: ::core::option::Option<super::TextAnchor>,
             /// Confidence of the current
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] within
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] within
             /// context of the object this layout is for. e.g. confidence can be for a
             /// single token, a table, a visual element, etc. depending on context.
             /// Range [0, 1].
             #[prost(float, tag = "2")]
             pub confidence: f32,
             /// The bounding polygon for the
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\].
             #[prost(message, optional, tag = "3")]
             pub bounding_poly: ::core::option::Option<super::super::BoundingPoly>,
             /// Detected orientation for the
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\].
             #[prost(enumeration = "layout::Orientation", tag = "4")]
             pub orientation: i32,
         }
@@ -249,8 +249,8 @@ pub mod document {
         /// common line-spacing and orientation.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Block {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Block][google.cloud.documentai.v1beta1.Document.Page.Block].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Block][google.cloud.documentai.v1beta1.Document.Page.Block\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -260,8 +260,8 @@ pub mod document {
         /// A collection of lines that a human would perceive as a paragraph.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Paragraph {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Paragraph][google.cloud.documentai.v1beta1.Document.Page.Paragraph].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Paragraph][google.cloud.documentai.v1beta1.Document.Page.Paragraph\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -272,8 +272,8 @@ pub mod document {
         /// Does not cross column boundaries, can be horizontal, vertical, etc.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Line {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Line][google.cloud.documentai.v1beta1.Document.Page.Line].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Line][google.cloud.documentai.v1beta1.Document.Page.Line\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -283,12 +283,12 @@ pub mod document {
         /// A detected token.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Token {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Token][google.cloud.documentai.v1beta1.Document.Page.Token].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Token][google.cloud.documentai.v1beta1.Document.Page.Token\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// Detected break at the end of a
-            /// [Token][google.cloud.documentai.v1beta1.Document.Page.Token].
+            /// \[Token][google.cloud.documentai.v1beta1.Document.Page.Token\].
             #[prost(message, optional, tag = "2")]
             pub detected_break: ::core::option::Option<token::DetectedBreak>,
             /// A list of detected languages together with confidence.
@@ -298,7 +298,7 @@ pub mod document {
         /// Nested message and enum types in `Token`.
         pub mod token {
             /// Detected break at the end of a
-            /// [Token][google.cloud.documentai.v1beta1.Document.Page.Token].
+            /// \[Token][google.cloud.documentai.v1beta1.Document.Page.Token\].
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct DetectedBreak {
                 /// Detected break type.
@@ -328,12 +328,12 @@ pub mod document {
         /// page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct VisualElement {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Token][google.cloud.documentai.v1beta1.Document.Page.Token].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Token][google.cloud.documentai.v1beta1.Document.Page.Token\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// Type of the
-            /// [VisualElement][google.cloud.documentai.v1beta1.Document.Page.VisualElement].
+            /// \[VisualElement][google.cloud.documentai.v1beta1.Document.Page.VisualElement\].
             #[prost(string, tag = "2")]
             pub r#type: ::prost::alloc::string::String,
             /// A list of detected languages together with confidence.
@@ -343,8 +343,8 @@ pub mod document {
         /// A table representation similar to HTML table structure.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Table {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-            /// [Table][google.cloud.documentai.v1beta1.Document.Page.Table].
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+            /// \[Table][google.cloud.documentai.v1beta1.Document.Page.Table\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// Header rows of the table.
@@ -369,8 +369,8 @@ pub mod document {
             /// A cell representation inside the table.
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct TableCell {
-                /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for
-                /// [TableCell][google.cloud.documentai.v1beta1.Document.Page.Table.TableCell].
+                /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for
+                /// \[TableCell][google.cloud.documentai.v1beta1.Document.Page.Table.TableCell\].
                 #[prost(message, optional, tag = "1")]
                 pub layout: ::core::option::Option<super::Layout>,
                 /// How many rows this cell spans.
@@ -387,13 +387,13 @@ pub mod document {
         /// A form field detected on the page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct FormField {
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for the
-            /// [FormField][google.cloud.documentai.v1beta1.Document.Page.FormField]
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for the
+            /// \[FormField][google.cloud.documentai.v1beta1.Document.Page.FormField\]
             /// name. e.g. `Address`, `Email`, `Grand total`, `Phone number`, etc.
             #[prost(message, optional, tag = "1")]
             pub field_name: ::core::option::Option<Layout>,
-            /// [Layout][google.cloud.documentai.v1beta1.Document.Page.Layout] for the
-            /// [FormField][google.cloud.documentai.v1beta1.Document.Page.FormField]
+            /// \[Layout][google.cloud.documentai.v1beta1.Document.Page.Layout\] for the
+            /// \[FormField][google.cloud.documentai.v1beta1.Document.Page.FormField\]
             /// value.
             #[prost(message, optional, tag = "2")]
             pub field_value: ::core::option::Option<Layout>,
@@ -409,7 +409,7 @@ pub mod document {
         pub struct DetectedLanguage {
             /// The BCP-47 language code, such as "en-US" or "sr-Latn". For more
             /// information, see
-            /// http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
+            /// <http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.>
             #[prost(string, tag = "1")]
             pub language_code: ::prost::alloc::string::String,
             /// Confidence of detected language. Range [0, 1].
@@ -423,7 +423,7 @@ pub mod document {
     pub struct Entity {
         /// Provenance of the entity.
         /// Text anchor indexing into the
-        /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+        /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Entity type from a schema e.g. `Address`.
@@ -438,7 +438,7 @@ pub mod document {
         pub mention_id: ::prost::alloc::string::String,
     }
     /// Relationship between
-    /// [Entities][google.cloud.documentai.v1beta1.Document.Entity].
+    /// \[Entities][google.cloud.documentai.v1beta1.Document.Entity\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct EntityRelation {
         /// Subject entity mention_id.
@@ -452,31 +452,31 @@ pub mod document {
         pub relation: ::prost::alloc::string::String,
     }
     /// Text reference indexing into the
-    /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+    /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct TextAnchor {
         /// The text segments from the
-        /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+        /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
         #[prost(message, repeated, tag = "1")]
         pub text_segments: ::prost::alloc::vec::Vec<text_anchor::TextSegment>,
     }
     /// Nested message and enum types in `TextAnchor`.
     pub mod text_anchor {
         /// A text segment in the
-        /// [Document.text][google.cloud.documentai.v1beta1.Document.text]. The
+        /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\]. The
         /// indices may be out of bounds which indicate that the text extends into
         /// another document shard for large sharded documents. See
-        /// [ShardInfo.text_offset][google.cloud.documentai.v1beta1.Document.ShardInfo.text_offset]
+        /// \[ShardInfo.text_offset][google.cloud.documentai.v1beta1.Document.ShardInfo.text_offset\]
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct TextSegment {
-            /// [TextSegment][google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment]
+            /// \[TextSegment][google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment\]
             /// start UTF-8 char index in the
-            /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+            /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
             #[prost(int64, tag = "1")]
             pub start_index: i64,
-            /// [TextSegment][google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment]
+            /// \[TextSegment][google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment\]
             /// half open end UTF-8 char index in the
-            /// [Document.text][google.cloud.documentai.v1beta1.Document.text].
+            /// \[Document.text][google.cloud.documentai.v1beta1.Document.text\].
             #[prost(int64, tag = "2")]
             pub end_index: i64,
         }
@@ -487,7 +487,7 @@ pub mod document {
         /// Currently supports Google Cloud Storage URI of the form
         ///    `gs://bucket_name/object_name`. Object versioning is not supported.
         ///    See [Google Cloud Storage Request
-        ///    URIs](https://cloud.google.com/storage/docs/reference-uris) for more
+        ///    URIs](<https://cloud.google.com/storage/docs/reference-uris>) for more
         ///    info.
         #[prost(string, tag = "1")]
         Uri(::prost::alloc::string::String),
@@ -605,7 +605,7 @@ pub struct TableBoundHint {
     #[prost(int32, tag = "1")]
     pub page_number: i32,
     /// Bounding box hint for a table on this page. The coordinates must be
-    /// normalized to [0,1] and the bounding box must be an axis-aligned rectangle.
+    /// normalized to \[0,1\] and the bounding box must be an axis-aligned rectangle.
     #[prost(message, optional, tag = "2")]
     pub bounding_box: ::core::option::Option<BoundingPoly>,
 }
@@ -691,7 +691,7 @@ pub struct OutputConfig {
     /// For example, for one pdf file with 100 pages, 100 parsed pages will be
     /// produced. If `pages_per_shard` = 20, then 5 Document shard JSON files each
     /// containing 20 parsed pages will be written under the prefix
-    /// [OutputConfig.gcs_destination.uri][] and suffix pages-x-to-y.json where
+    /// \[OutputConfig.gcs_destination.uri][\] and suffix pages-x-to-y.json where
     /// x and y are 1-indexed page numbers.
     ///
     /// Example GCS outputs with 157 pages and pages_per_shard = 50:
@@ -779,7 +779,7 @@ pub mod document_understanding_service_client {
     impl<T> DocumentUnderstandingServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -792,7 +792,7 @@ pub mod document_understanding_service_client {
             interceptor: F,
         ) -> DocumentUnderstandingServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
