@@ -40,30 +40,30 @@ pub struct BoundingPoly {
 pub struct Document {
     /// An IANA published MIME type (also referred to as media type). For more
     /// information, see
-    /// https://www.iana.org/assignments/media-types/media-types.xhtml.
+    /// <https://www.iana.org/assignments/media-types/media-types.xhtml.>
     #[prost(string, tag = "3")]
     pub mime_type: ::prost::alloc::string::String,
     /// UTF-8 encoded text in reading order from the document.
     #[prost(string, tag = "4")]
     pub text: ::prost::alloc::string::String,
-    /// Styles for the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+    /// Styles for the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
     #[prost(message, repeated, tag = "5")]
     pub text_styles: ::prost::alloc::vec::Vec<document::Style>,
-    /// Visual page layout for the [Document][google.cloud.documentai.v1beta2.Document].
+    /// Visual page layout for the \[Document][google.cloud.documentai.v1beta2.Document\].
     #[prost(message, repeated, tag = "6")]
     pub pages: ::prost::alloc::vec::Vec<document::Page>,
-    /// A list of entities detected on [Document.text][google.cloud.documentai.v1beta2.Document.text]. For document shards,
+    /// A list of entities detected on \[Document.text][google.cloud.documentai.v1beta2.Document.text\]. For document shards,
     /// entities in this list may cross shard boundaries.
     #[prost(message, repeated, tag = "7")]
     pub entities: ::prost::alloc::vec::Vec<document::Entity>,
-    /// Relationship among [Document.entities][google.cloud.documentai.v1beta2.Document.entities].
+    /// Relationship among \[Document.entities][google.cloud.documentai.v1beta2.Document.entities\].
     #[prost(message, repeated, tag = "8")]
     pub entity_relations: ::prost::alloc::vec::Vec<document::EntityRelation>,
     /// Information about the sharding if this document is sharded part of a larger
     /// document. If the document is not sharded, this message is not specified.
     #[prost(message, optional, tag = "9")]
     pub shard_info: ::core::option::Option<document::ShardInfo>,
-    /// [Label][google.cloud.documentai.v1beta2.Document.Label]s for this document.
+    /// \[Label][google.cloud.documentai.v1beta2.Document.Label\]s for this document.
     #[prost(message, repeated, tag = "11")]
     pub labels: ::prost::alloc::vec::Vec<document::Label>,
     /// Any error that occurred while processing this document.
@@ -86,13 +86,13 @@ pub mod document {
         /// Total number of shards.
         #[prost(int64, tag = "2")]
         pub shard_count: i64,
-        /// The index of the first character in [Document.text][google.cloud.documentai.v1beta2.Document.text] in the overall
+        /// The index of the first character in \[Document.text][google.cloud.documentai.v1beta2.Document.text\] in the overall
         /// document global text.
         #[prost(int64, tag = "3")]
         pub text_offset: i64,
     }
     /// Label attaches schema information and/or other metadata to segments within
-    /// a [Document][google.cloud.documentai.v1beta2.Document]. Multiple [Label][google.cloud.documentai.v1beta2.Document.Label]s on a single field can denote either
+    /// a \[Document][google.cloud.documentai.v1beta2.Document\]. Multiple \[Label][google.cloud.documentai.v1beta2.Document.Label\]s on a single field can denote either
     /// different labels, different instances of the same label created at
     /// different times, or some combination of both.
     #[derive(Clone, PartialEq, ::prost::Message)]
@@ -128,7 +128,7 @@ pub mod document {
     /// conventions as much as possible.
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Style {
-        /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+        /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Text color.
@@ -138,16 +138,16 @@ pub mod document {
         #[prost(message, optional, tag = "3")]
         pub background_color: ::core::option::Option<super::super::super::super::r#type::Color>,
         /// Font weight. Possible values are normal, bold, bolder, and lighter.
-        /// https://www.w3schools.com/cssref/pr_font_weight.asp
+        /// <https://www.w3schools.com/cssref/pr_font_weight.asp>
         #[prost(string, tag = "4")]
         pub font_weight: ::prost::alloc::string::String,
         /// Text style. Possible values are normal, italic, and oblique.
-        /// https://www.w3schools.com/cssref/pr_font_font-style.asp
+        /// <https://www.w3schools.com/cssref/pr_font_font-style.asp>
         #[prost(string, tag = "5")]
         pub text_style: ::prost::alloc::string::String,
         /// Text decoration. Follows CSS standard.
         /// <text-decoration-line> <text-decoration-color> <text-decoration-style>
-        /// https://www.w3schools.com/cssref/pr_text_text-decoration.asp
+        /// <https://www.w3schools.com/cssref/pr_text_text-decoration.asp>
         #[prost(string, tag = "6")]
         pub text_decoration: ::prost::alloc::string::String,
         /// Font size.
@@ -167,18 +167,18 @@ pub mod document {
             pub unit: ::prost::alloc::string::String,
         }
     }
-    /// A page in a [Document][google.cloud.documentai.v1beta2.Document].
+    /// A page in a \[Document][google.cloud.documentai.v1beta2.Document\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Page {
-        /// 1-based index for current [Page][google.cloud.documentai.v1beta2.Document.Page] in a parent [Document][google.cloud.documentai.v1beta2.Document].
-        /// Useful when a page is taken out of a [Document][google.cloud.documentai.v1beta2.Document] for individual
+        /// 1-based index for current \[Page][google.cloud.documentai.v1beta2.Document.Page\] in a parent \[Document][google.cloud.documentai.v1beta2.Document\].
+        /// Useful when a page is taken out of a \[Document][google.cloud.documentai.v1beta2.Document\] for individual
         /// processing.
         #[prost(int32, tag = "1")]
         pub page_number: i32,
         /// Physical dimension of the page.
         #[prost(message, optional, tag = "2")]
         pub dimension: ::core::option::Option<page::Dimension>,
-        /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for the page.
+        /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for the page.
         #[prost(message, optional, tag = "3")]
         pub layout: ::core::option::Option<page::Layout>,
         /// A list of detected languages together with confidence.
@@ -229,21 +229,21 @@ pub mod document {
         /// Visual element describing a layout unit on a page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Layout {
-            /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+            /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
             #[prost(message, optional, tag = "1")]
             pub text_anchor: ::core::option::Option<super::TextAnchor>,
-            /// Confidence of the current [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] within context of the object this
+            /// Confidence of the current \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] within context of the object this
             /// layout is for. e.g. confidence can be for a single token, a table,
             /// a visual element, etc. depending on context. Range [0, 1].
             #[prost(float, tag = "2")]
             pub confidence: f32,
-            /// The bounding polygon for the [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout].
+            /// The bounding polygon for the \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\].
             #[prost(message, optional, tag = "3")]
             pub bounding_poly: ::core::option::Option<super::super::BoundingPoly>,
-            /// Detected orientation for the [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout].
+            /// Detected orientation for the \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\].
             #[prost(enumeration = "layout::Orientation", tag = "4")]
             pub orientation: i32,
-            /// Optional. This is the identifier used by referencing [PageAnchor][google.cloud.documentai.v1beta2.Document.PageAnchor]s.
+            /// Optional. This is the identifier used by referencing \[PageAnchor][google.cloud.documentai.v1beta2.Document.PageAnchor\]s.
             #[prost(string, tag = "5")]
             pub id: ::prost::alloc::string::String,
         }
@@ -274,7 +274,7 @@ pub mod document {
         /// common line-spacing and orientation.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Block {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [Block][google.cloud.documentai.v1beta2.Document.Page.Block].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[Block][google.cloud.documentai.v1beta2.Document.Page.Block\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -284,7 +284,7 @@ pub mod document {
         /// A collection of lines that a human would perceive as a paragraph.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Paragraph {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [Paragraph][google.cloud.documentai.v1beta2.Document.Page.Paragraph].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[Paragraph][google.cloud.documentai.v1beta2.Document.Page.Paragraph\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -295,7 +295,7 @@ pub mod document {
         /// Does not cross column boundaries, can be horizontal, vertical, etc.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Line {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [Line][google.cloud.documentai.v1beta2.Document.Page.Line].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[Line][google.cloud.documentai.v1beta2.Document.Page.Line\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -305,10 +305,10 @@ pub mod document {
         /// A detected token.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Token {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[Token][google.cloud.documentai.v1beta2.Document.Page.Token\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
-            /// Detected break at the end of a [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
+            /// Detected break at the end of a \[Token][google.cloud.documentai.v1beta2.Document.Page.Token\].
             #[prost(message, optional, tag = "2")]
             pub detected_break: ::core::option::Option<token::DetectedBreak>,
             /// A list of detected languages together with confidence.
@@ -317,7 +317,7 @@ pub mod document {
         }
         /// Nested message and enum types in `Token`.
         pub mod token {
-            /// Detected break at the end of a [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
+            /// Detected break at the end of a \[Token][google.cloud.documentai.v1beta2.Document.Page.Token\].
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct DetectedBreak {
                 /// Detected break type.
@@ -347,10 +347,10 @@ pub mod document {
         /// page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct VisualElement {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
-            /// Type of the [VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement].
+            /// Type of the \[VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement\].
             #[prost(string, tag = "2")]
             pub r#type: ::prost::alloc::string::String,
             /// A list of detected languages together with confidence.
@@ -360,7 +360,7 @@ pub mod document {
         /// A table representation similar to HTML table structure.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Table {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [Table][google.cloud.documentai.v1beta2.Document.Page.Table].
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[Table][google.cloud.documentai.v1beta2.Document.Page.Table\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// Header rows of the table.
@@ -385,7 +385,7 @@ pub mod document {
             /// A cell representation inside the table.
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct TableCell {
-                /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for [TableCell][google.cloud.documentai.v1beta2.Document.Page.Table.TableCell].
+                /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for \[TableCell][google.cloud.documentai.v1beta2.Document.Page.Table.TableCell\].
                 #[prost(message, optional, tag = "1")]
                 pub layout: ::core::option::Option<super::Layout>,
                 /// How many rows this cell spans.
@@ -402,11 +402,11 @@ pub mod document {
         /// A form field detected on the page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct FormField {
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for the [FormField][google.cloud.documentai.v1beta2.Document.Page.FormField] name. e.g. `Address`, `Email`,
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for the \[FormField][google.cloud.documentai.v1beta2.Document.Page.FormField\] name. e.g. `Address`, `Email`,
             /// `Grand total`, `Phone number`, etc.
             #[prost(message, optional, tag = "1")]
             pub field_name: ::core::option::Option<Layout>,
-            /// [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout] for the [FormField][google.cloud.documentai.v1beta2.Document.Page.FormField] value.
+            /// \[Layout][google.cloud.documentai.v1beta2.Document.Page.Layout\] for the \[FormField][google.cloud.documentai.v1beta2.Document.Page.FormField\] value.
             #[prost(message, optional, tag = "2")]
             pub field_value: ::core::option::Option<Layout>,
             /// A list of detected languages for name together with confidence.
@@ -434,7 +434,7 @@ pub mod document {
         pub struct DetectedLanguage {
             /// The BCP-47 language code, such as "en-US" or "sr-Latn". For more
             /// information, see
-            /// http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
+            /// <http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.>
             #[prost(string, tag = "1")]
             pub language_code: ::prost::alloc::string::String,
             /// Confidence of detected language. Range [0, 1].
@@ -447,7 +447,7 @@ pub mod document {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Entity {
         /// Provenance of the entity.
-        /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+        /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Entity type from a schema e.g. `Address`.
@@ -475,7 +475,7 @@ pub mod document {
         #[prost(message, optional, tag = "8")]
         pub bounding_poly_for_demo_frontend: ::core::option::Option<super::BoundingPoly>,
     }
-    /// Relationship between [Entities][google.cloud.documentai.v1beta2.Document.Entity].
+    /// Relationship between \[Entities][google.cloud.documentai.v1beta2.Document.Entity\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct EntityRelation {
         /// Subject entity id.
@@ -488,30 +488,30 @@ pub mod document {
         #[prost(string, tag = "3")]
         pub relation: ::prost::alloc::string::String,
     }
-    /// Text reference indexing into the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+    /// Text reference indexing into the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct TextAnchor {
-        /// The text segments from the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+        /// The text segments from the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
         #[prost(message, repeated, tag = "1")]
         pub text_segments: ::prost::alloc::vec::Vec<text_anchor::TextSegment>,
     }
     /// Nested message and enum types in `TextAnchor`.
     pub mod text_anchor {
-        /// A text segment in the [Document.text][google.cloud.documentai.v1beta2.Document.text]. The indices may be out of bounds
+        /// A text segment in the \[Document.text][google.cloud.documentai.v1beta2.Document.text\]. The indices may be out of bounds
         /// which indicate that the text extends into another document shard for
-        /// large sharded documents. See [ShardInfo.text_offset][google.cloud.documentai.v1beta2.Document.ShardInfo.text_offset]
+        /// large sharded documents. See \[ShardInfo.text_offset][google.cloud.documentai.v1beta2.Document.ShardInfo.text_offset\]
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct TextSegment {
-            /// [TextSegment][google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment] start UTF-8 char index in the [Document.text][google.cloud.documentai.v1beta2.Document.text].
+            /// \[TextSegment][google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment\] start UTF-8 char index in the \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
             #[prost(int64, tag = "1")]
             pub start_index: i64,
-            /// [TextSegment][google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment] half open end UTF-8 char index in the
-            /// [Document.text][google.cloud.documentai.v1beta2.Document.text].
+            /// \[TextSegment][google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment\] half open end UTF-8 char index in the
+            /// \[Document.text][google.cloud.documentai.v1beta2.Document.text\].
             #[prost(int64, tag = "2")]
             pub end_index: i64,
         }
     }
-    /// Referencing elements in [Document.pages][google.cloud.documentai.v1beta2.Document.pages].
+    /// Referencing elements in \[Document.pages][google.cloud.documentai.v1beta2.Document.pages\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct PageAnchor {
         /// One or more references to visual page elements
@@ -523,15 +523,15 @@ pub mod document {
         /// Represents a weak reference to a page element within a document.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct PageRef {
-            /// Required. Index into the [Document.pages][google.cloud.documentai.v1beta2.Document.pages] element
+            /// Required. Index into the \[Document.pages][google.cloud.documentai.v1beta2.Document.pages\] element
             #[prost(int64, tag = "1")]
             pub page: i64,
             /// Optional. The type of the layout element that is being referenced.  If not
             /// specified the whole page is assumed to be referenced.
             #[prost(enumeration = "page_ref::LayoutType", tag = "2")]
             pub layout_type: i32,
-            /// Optional. The [Page.Layout.id][google.cloud.documentai.v1beta2.Document.Page.Layout.id] on the page that this element
-            /// references.  If [LayoutRef.type][] is specified this id must also be
+            /// Optional. The \[Page.Layout.id][google.cloud.documentai.v1beta2.Document.Page.Layout.id\] on the page that this element
+            /// references.  If \[LayoutRef.type][\] is specified this id must also be
             /// specified.
             #[prost(string, tag = "3")]
             pub layout_id: ::prost::alloc::string::String,
@@ -546,19 +546,19 @@ pub mod document {
             pub enum LayoutType {
                 /// Layout Unspecified.
                 Unspecified = 0,
-                /// References a [Page.blocks][google.cloud.documentai.v1beta2.Document.Page.blocks] element.
+                /// References a \[Page.blocks][google.cloud.documentai.v1beta2.Document.Page.blocks\] element.
                 Block = 1,
-                /// References a [Page.paragraphs][google.cloud.documentai.v1beta2.Document.Page.paragraphs] element.
+                /// References a \[Page.paragraphs][google.cloud.documentai.v1beta2.Document.Page.paragraphs\] element.
                 Paragraph = 2,
-                /// References a [Page.lines][google.cloud.documentai.v1beta2.Document.Page.lines] element.
+                /// References a \[Page.lines][google.cloud.documentai.v1beta2.Document.Page.lines\] element.
                 Line = 3,
-                /// References a [Page.tokens][google.cloud.documentai.v1beta2.Document.Page.tokens] element.
+                /// References a \[Page.tokens][google.cloud.documentai.v1beta2.Document.Page.tokens\] element.
                 Token = 4,
-                /// References a [Page.visual_elements][google.cloud.documentai.v1beta2.Document.Page.visual_elements] element.
+                /// References a \[Page.visual_elements][google.cloud.documentai.v1beta2.Document.Page.visual_elements\] element.
                 VisualElement = 5,
-                /// Refrrences a [Page.tables][google.cloud.documentai.v1beta2.Document.Page.tables] element.
+                /// Refrrences a \[Page.tables][google.cloud.documentai.v1beta2.Document.Page.tables\] element.
                 Table = 6,
-                /// References a [Page.form_fields][google.cloud.documentai.v1beta2.Document.Page.form_fields] element.
+                /// References a \[Page.form_fields][google.cloud.documentai.v1beta2.Document.Page.form_fields\] element.
                 FormField = 7,
             }
         }
@@ -569,7 +569,7 @@ pub mod document {
         /// Currently supports Google Cloud Storage URI of the form
         ///    `gs://bucket_name/object_name`. Object versioning is not supported.
         ///    See [Google Cloud Storage Request
-        ///    URIs](https://cloud.google.com/storage/docs/reference-uris) for more
+        ///    URIs](<https://cloud.google.com/storage/docs/reference-uris>) for more
         ///    info.
         #[prost(string, tag = "1")]
         Uri(::prost::alloc::string::String),
@@ -581,7 +581,7 @@ pub mod document {
     }
 }
 /// Request to batch process documents as an asynchronous operation. The output
-/// is written to Cloud Storage as JSON in the [Document] format.
+/// is written to Cloud Storage as JSON in the \[Document\] format.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchProcessDocumentsRequest {
     /// Required. Individual requests for each document.
@@ -701,7 +701,7 @@ pub struct TableBoundHint {
     #[prost(int32, tag = "1")]
     pub page_number: i32,
     /// Bounding box hint for a table on this page. The coordinates must be
-    /// normalized to [0,1] and the bounding box must be an axis-aligned rectangle.
+    /// normalized to \[0,1\] and the bounding box must be an axis-aligned rectangle.
     #[prost(message, optional, tag = "2")]
     pub bounding_box: ::core::option::Option<BoundingPoly>,
 }
@@ -772,8 +772,8 @@ pub struct InputConfig {
     /// Required. Mimetype of the input. Current supported mimetypes are application/pdf,
     /// image/tiff, and image/gif.
     /// In addition, application/json type is supported for requests with
-    /// [ProcessDocumentRequest.automl_params][google.cloud.documentai.v1beta2.ProcessDocumentRequest.automl_params] field set. The JSON file needs to
-    /// be in [Document][google.cloud.documentai.v1beta2.Document] format.
+    /// \[ProcessDocumentRequest.automl_params][google.cloud.documentai.v1beta2.ProcessDocumentRequest.automl_params\] field set. The JSON file needs to
+    /// be in \[Document][google.cloud.documentai.v1beta2.Document\] format.
     #[prost(string, tag = "2")]
     pub mime_type: ::prost::alloc::string::String,
     /// Required.
@@ -809,7 +809,7 @@ pub struct OutputConfig {
     /// For example, for one pdf file with 100 pages, 100 parsed pages will be
     /// produced. If `pages_per_shard` = 20, then 5 Document shard JSON files each
     /// containing 20 parsed pages will be written under the prefix
-    /// [OutputConfig.gcs_destination.uri][] and suffix pages-x-to-y.json where
+    /// \[OutputConfig.gcs_destination.uri][\] and suffix pages-x-to-y.json where
     /// x and y are 1-indexed page numbers.
     ///
     /// Example GCS outputs with 157 pages and pages_per_shard = 50:
@@ -897,7 +897,7 @@ pub mod document_understanding_service_client {
     impl<T> DocumentUnderstandingServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -910,7 +910,7 @@ pub mod document_understanding_service_client {
             interceptor: F,
         ) -> DocumentUnderstandingServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
