@@ -40,26 +40,26 @@ pub struct BoundingPoly {
 pub struct Document {
     /// An IANA published MIME type (also referred to as media type). For more
     /// information, see
-    /// https://www.iana.org/assignments/media-types/media-types.xhtml.
+    /// <https://www.iana.org/assignments/media-types/media-types.xhtml.>
     #[prost(string, tag = "3")]
     pub mime_type: ::prost::alloc::string::String,
     /// Optional. UTF-8 encoded text in reading order from the document.
     #[prost(string, tag = "4")]
     pub text: ::prost::alloc::string::String,
-    /// Styles for the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+    /// Styles for the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
     #[prost(message, repeated, tag = "5")]
     pub text_styles: ::prost::alloc::vec::Vec<document::Style>,
-    /// Visual page layout for the [Document][google.cloud.documentai.v1beta3.Document].
+    /// Visual page layout for the \[Document][google.cloud.documentai.v1beta3.Document\].
     #[prost(message, repeated, tag = "6")]
     pub pages: ::prost::alloc::vec::Vec<document::Page>,
-    /// A list of entities detected on [Document.text][google.cloud.documentai.v1beta3.Document.text]. For document shards,
+    /// A list of entities detected on \[Document.text][google.cloud.documentai.v1beta3.Document.text\]. For document shards,
     /// entities in this list may cross shard boundaries.
     #[prost(message, repeated, tag = "7")]
     pub entities: ::prost::alloc::vec::Vec<document::Entity>,
-    /// Relationship among [Document.entities][google.cloud.documentai.v1beta3.Document.entities].
+    /// Relationship among \[Document.entities][google.cloud.documentai.v1beta3.Document.entities\].
     #[prost(message, repeated, tag = "8")]
     pub entity_relations: ::prost::alloc::vec::Vec<document::EntityRelation>,
-    /// A list of text corrections made to [Document.text].  This is usually
+    /// A list of text corrections made to \[Document.text\].  This is usually
     /// used for annotating corrections to OCR mistakes.  Text changes for a given
     /// revision may not overlap with each other.
     #[prost(message, repeated, tag = "14")]
@@ -91,7 +91,7 @@ pub mod document {
         /// Total number of shards.
         #[prost(int64, tag = "2")]
         pub shard_count: i64,
-        /// The index of the first character in [Document.text][google.cloud.documentai.v1beta3.Document.text] in the overall
+        /// The index of the first character in \[Document.text][google.cloud.documentai.v1beta3.Document.text\] in the overall
         /// document global text.
         #[prost(int64, tag = "3")]
         pub text_offset: i64,
@@ -100,7 +100,7 @@ pub mod document {
     /// conventions as much as possible.
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Style {
-        /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+        /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Text color.
@@ -110,16 +110,16 @@ pub mod document {
         #[prost(message, optional, tag = "3")]
         pub background_color: ::core::option::Option<super::super::super::super::r#type::Color>,
         /// Font weight. Possible values are normal, bold, bolder, and lighter.
-        /// https://www.w3schools.com/cssref/pr_font_weight.asp
+        /// <https://www.w3schools.com/cssref/pr_font_weight.asp>
         #[prost(string, tag = "4")]
         pub font_weight: ::prost::alloc::string::String,
         /// Text style. Possible values are normal, italic, and oblique.
-        /// https://www.w3schools.com/cssref/pr_font_font-style.asp
+        /// <https://www.w3schools.com/cssref/pr_font_font-style.asp>
         #[prost(string, tag = "5")]
         pub text_style: ::prost::alloc::string::String,
         /// Text decoration. Follows CSS standard.
         /// <text-decoration-line> <text-decoration-color> <text-decoration-style>
-        /// https://www.w3schools.com/cssref/pr_text_text-decoration.asp
+        /// <https://www.w3schools.com/cssref/pr_text_text-decoration.asp>
         #[prost(string, tag = "6")]
         pub text_decoration: ::prost::alloc::string::String,
         /// Font size.
@@ -139,11 +139,11 @@ pub mod document {
             pub unit: ::prost::alloc::string::String,
         }
     }
-    /// A page in a [Document][google.cloud.documentai.v1beta3.Document].
+    /// A page in a \[Document][google.cloud.documentai.v1beta3.Document\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Page {
-        /// 1-based index for current [Page][google.cloud.documentai.v1beta3.Document.Page] in a parent [Document][google.cloud.documentai.v1beta3.Document].
-        /// Useful when a page is taken out of a [Document][google.cloud.documentai.v1beta3.Document] for individual
+        /// 1-based index for current \[Page][google.cloud.documentai.v1beta3.Document.Page\] in a parent \[Document][google.cloud.documentai.v1beta3.Document\].
+        /// Useful when a page is taken out of a \[Document][google.cloud.documentai.v1beta3.Document\] for individual
         /// processing.
         #[prost(int32, tag = "1")]
         pub page_number: i32,
@@ -153,13 +153,13 @@ pub mod document {
         #[prost(message, optional, tag = "13")]
         pub image: ::core::option::Option<page::Image>,
         /// Transformation matrices that were applied to the original document image
-        /// to produce [Page.image][google.cloud.documentai.v1beta3.Document.Page.image].
+        /// to produce \[Page.image][google.cloud.documentai.v1beta3.Document.Page.image\].
         #[prost(message, repeated, tag = "14")]
         pub transforms: ::prost::alloc::vec::Vec<page::Matrix>,
         /// Physical dimension of the page.
         #[prost(message, optional, tag = "2")]
         pub dimension: ::core::option::Option<page::Dimension>,
-        /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for the page.
+        /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for the page.
         #[prost(message, optional, tag = "3")]
         pub layout: ::core::option::Option<page::Layout>,
         /// A list of detected languages together with confidence.
@@ -239,7 +239,7 @@ pub mod document {
             /// This encodes information about what data type the matrix uses.
             /// For example, 0 (CV_8U) is an unsigned 8-bit image. For the full list
             /// of OpenCV primitive data types, please refer to
-            /// https://docs.opencv.org/4.3.0/d1/d1b/group__core__hal__interface.html
+            /// <https://docs.opencv.org/4.3.0/d1/d1b/group__core__hal__interface.html>
             #[prost(int32, tag = "3")]
             pub r#type: i32,
             /// The matrix data.
@@ -249,18 +249,18 @@ pub mod document {
         /// Visual element describing a layout unit on a page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Layout {
-            /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+            /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
             #[prost(message, optional, tag = "1")]
             pub text_anchor: ::core::option::Option<super::TextAnchor>,
-            /// Confidence of the current [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] within context of the object this
+            /// Confidence of the current \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] within context of the object this
             /// layout is for. e.g. confidence can be for a single token, a table,
             /// a visual element, etc. depending on context. Range [0, 1].
             #[prost(float, tag = "2")]
             pub confidence: f32,
-            /// The bounding polygon for the [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout].
+            /// The bounding polygon for the \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\].
             #[prost(message, optional, tag = "3")]
             pub bounding_poly: ::core::option::Option<super::super::BoundingPoly>,
-            /// Detected orientation for the [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout].
+            /// Detected orientation for the \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\].
             #[prost(enumeration = "layout::Orientation", tag = "4")]
             pub orientation: i32,
         }
@@ -291,7 +291,7 @@ pub mod document {
         /// common line-spacing and orientation.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Block {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [Block][google.cloud.documentai.v1beta3.Document.Page.Block].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[Block][google.cloud.documentai.v1beta3.Document.Page.Block\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -304,7 +304,7 @@ pub mod document {
         /// A collection of lines that a human would perceive as a paragraph.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Paragraph {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [Paragraph][google.cloud.documentai.v1beta3.Document.Page.Paragraph].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[Paragraph][google.cloud.documentai.v1beta3.Document.Page.Paragraph\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -318,7 +318,7 @@ pub mod document {
         /// Does not cross column boundaries, can be horizontal, vertical, etc.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Line {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [Line][google.cloud.documentai.v1beta3.Document.Page.Line].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[Line][google.cloud.documentai.v1beta3.Document.Page.Line\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// A list of detected languages together with confidence.
@@ -331,10 +331,10 @@ pub mod document {
         /// A detected token.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Token {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [Token][google.cloud.documentai.v1beta3.Document.Page.Token].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[Token][google.cloud.documentai.v1beta3.Document.Page.Token\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
-            /// Detected break at the end of a [Token][google.cloud.documentai.v1beta3.Document.Page.Token].
+            /// Detected break at the end of a \[Token][google.cloud.documentai.v1beta3.Document.Page.Token\].
             #[prost(message, optional, tag = "2")]
             pub detected_break: ::core::option::Option<token::DetectedBreak>,
             /// A list of detected languages together with confidence.
@@ -346,7 +346,7 @@ pub mod document {
         }
         /// Nested message and enum types in `Token`.
         pub mod token {
-            /// Detected break at the end of a [Token][google.cloud.documentai.v1beta3.Document.Page.Token].
+            /// Detected break at the end of a \[Token][google.cloud.documentai.v1beta3.Document.Page.Token\].
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct DetectedBreak {
                 /// Detected break type.
@@ -376,10 +376,10 @@ pub mod document {
         /// page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct VisualElement {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [VisualElement][google.cloud.documentai.v1beta3.Document.Page.VisualElement].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[VisualElement][google.cloud.documentai.v1beta3.Document.Page.VisualElement\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
-            /// Type of the [VisualElement][google.cloud.documentai.v1beta3.Document.Page.VisualElement].
+            /// Type of the \[VisualElement][google.cloud.documentai.v1beta3.Document.Page.VisualElement\].
             #[prost(string, tag = "2")]
             pub r#type: ::prost::alloc::string::String,
             /// A list of detected languages together with confidence.
@@ -389,7 +389,7 @@ pub mod document {
         /// A table representation similar to HTML table structure.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Table {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [Table][google.cloud.documentai.v1beta3.Document.Page.Table].
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[Table][google.cloud.documentai.v1beta3.Document.Page.Table\].
             #[prost(message, optional, tag = "1")]
             pub layout: ::core::option::Option<Layout>,
             /// Header rows of the table.
@@ -414,7 +414,7 @@ pub mod document {
             /// A cell representation inside the table.
             #[derive(Clone, PartialEq, ::prost::Message)]
             pub struct TableCell {
-                /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for [TableCell][google.cloud.documentai.v1beta3.Document.Page.Table.TableCell].
+                /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for \[TableCell][google.cloud.documentai.v1beta3.Document.Page.Table.TableCell\].
                 #[prost(message, optional, tag = "1")]
                 pub layout: ::core::option::Option<super::Layout>,
                 /// How many rows this cell spans.
@@ -431,11 +431,11 @@ pub mod document {
         /// A form field detected on the page.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct FormField {
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for the [FormField][google.cloud.documentai.v1beta3.Document.Page.FormField] name. e.g. `Address`, `Email`,
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for the \[FormField][google.cloud.documentai.v1beta3.Document.Page.FormField\] name. e.g. `Address`, `Email`,
             /// `Grand total`, `Phone number`, etc.
             #[prost(message, optional, tag = "1")]
             pub field_name: ::core::option::Option<Layout>,
-            /// [Layout][google.cloud.documentai.v1beta3.Document.Page.Layout] for the [FormField][google.cloud.documentai.v1beta3.Document.Page.FormField] value.
+            /// \[Layout][google.cloud.documentai.v1beta3.Document.Page.Layout\] for the \[FormField][google.cloud.documentai.v1beta3.Document.Page.FormField\] value.
             #[prost(message, optional, tag = "2")]
             pub field_value: ::core::option::Option<Layout>,
             /// A list of detected languages for name together with confidence.
@@ -460,7 +460,7 @@ pub mod document {
         pub struct DetectedLanguage {
             /// The BCP-47 language code, such as "en-US" or "sr-Latn". For more
             /// information, see
-            /// http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
+            /// <http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.>
             #[prost(string, tag = "1")]
             pub language_code: ::prost::alloc::string::String,
             /// Confidence of detected language. Range [0, 1].
@@ -473,7 +473,7 @@ pub mod document {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct Entity {
         /// Optional. Provenance of the entity.
-        /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+        /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
         #[prost(message, optional, tag = "1")]
         pub text_anchor: ::core::option::Option<TextAnchor>,
         /// Entity type from a schema e.g. `Address`.
@@ -539,19 +539,19 @@ pub mod document {
             #[derive(Clone, PartialEq, ::prost::Oneof)]
             pub enum StructuredValue {
                 /// Money value. See also:
-                /// https://github.com/googleapis/googleapis/blob/master/google/type/money.proto
+                /// <https://github.com/googleapis/googleapis/blob/master/google/type/money.proto>
                 #[prost(message, tag = "2")]
                 MoneyValue(super::super::super::super::super::super::r#type::Money),
                 /// Date value. Includes year, month, day. See also:
-                /// https://github.com/googleapis/googleapis/blob/master/google/type/date.proto
+                /// <https://github.com/googleapis/googleapis/blob/master/google/type/date.proto>
                 #[prost(message, tag = "3")]
                 DateValue(super::super::super::super::super::super::r#type::Date),
                 /// DateTime value. Includes date, time, and timezone. See also:
-                /// https://github.com/googleapis/googleapis/blob/master/google/type/datetime.proto
+                /// <https://github.com/googleapis/googleapis/blob/master/google/type/datetime.proto>
                 #[prost(message, tag = "4")]
                 DatetimeValue(super::super::super::super::super::super::r#type::DateTime),
                 /// Postal address. See also:
-                /// https://github.com/googleapis/googleapis/blob/master/google/type/postal_address.proto
+                /// <https://github.com/googleapis/googleapis/blob/master/google/type/postal_address.proto>
                 #[prost(message, tag = "5")]
                 AddressValue(super::super::super::super::super::super::r#type::PostalAddress),
                 /// Boolean value. Can be used for entities with binary values, or for
@@ -561,7 +561,7 @@ pub mod document {
             }
         }
     }
-    /// Relationship between [Entities][google.cloud.documentai.v1beta3.Document.Entity].
+    /// Relationship between \[Entities][google.cloud.documentai.v1beta3.Document.Entity\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct EntityRelation {
         /// Subject entity id.
@@ -574,10 +574,10 @@ pub mod document {
         #[prost(string, tag = "3")]
         pub relation: ::prost::alloc::string::String,
     }
-    /// Text reference indexing into the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+    /// Text reference indexing into the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct TextAnchor {
-        /// The text segments from the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+        /// The text segments from the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
         #[prost(message, repeated, tag = "1")]
         pub text_segments: ::prost::alloc::vec::Vec<text_anchor::TextSegment>,
         /// Contains the content of the text span so that users do
@@ -587,21 +587,21 @@ pub mod document {
     }
     /// Nested message and enum types in `TextAnchor`.
     pub mod text_anchor {
-        /// A text segment in the [Document.text][google.cloud.documentai.v1beta3.Document.text]. The indices may be out of bounds
+        /// A text segment in the \[Document.text][google.cloud.documentai.v1beta3.Document.text\]. The indices may be out of bounds
         /// which indicate that the text extends into another document shard for
-        /// large sharded documents. See [ShardInfo.text_offset][google.cloud.documentai.v1beta3.Document.ShardInfo.text_offset]
+        /// large sharded documents. See \[ShardInfo.text_offset][google.cloud.documentai.v1beta3.Document.ShardInfo.text_offset\]
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct TextSegment {
-            /// [TextSegment][google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment] start UTF-8 char index in the [Document.text][google.cloud.documentai.v1beta3.Document.text].
+            /// \[TextSegment][google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment\] start UTF-8 char index in the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
             #[prost(int64, tag = "1")]
             pub start_index: i64,
-            /// [TextSegment][google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment] half open end UTF-8 char index in the
-            /// [Document.text][google.cloud.documentai.v1beta3.Document.text].
+            /// \[TextSegment][google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment\] half open end UTF-8 char index in the
+            /// \[Document.text][google.cloud.documentai.v1beta3.Document.text\].
             #[prost(int64, tag = "2")]
             pub end_index: i64,
         }
     }
-    /// Referencing the visual context of the entity in the [Document.pages][google.cloud.documentai.v1beta3.Document.pages].
+    /// Referencing the visual context of the entity in the \[Document.pages][google.cloud.documentai.v1beta3.Document.pages\].
     /// Page anchors can be cross-page, consist of multiple bounding polygons and
     /// optionally reference specific layout element types.
     #[derive(Clone, PartialEq, ::prost::Message)]
@@ -615,16 +615,16 @@ pub mod document {
         /// Represents a weak reference to a page element within a document.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct PageRef {
-            /// Required. Index into the [Document.pages][google.cloud.documentai.v1beta3.Document.pages] element, for example using
-            /// [Document.pages][page_refs.page] to locate the related page element.
+            /// Required. Index into the \[Document.pages][google.cloud.documentai.v1beta3.Document.pages\] element, for example using
+            /// \[Document.pages][page_refs.page\] to locate the related page element.
             /// This field is skipped when its value is the default 0. See
-            /// https://developers.google.com/protocol-buffers/docs/proto3#json.
+            /// <https://developers.google.com/protocol-buffers/docs/proto3#json.>
             #[prost(int64, tag = "1")]
             pub page: i64,
             /// Optional. The type of the layout element that is being referenced if any.
             #[prost(enumeration = "page_ref::LayoutType", tag = "2")]
             pub layout_type: i32,
-            /// Optional. Deprecated.  Use [PageRef.bounding_poly][google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.bounding_poly] instead.
+            /// Optional. Deprecated.  Use \[PageRef.bounding_poly][google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.bounding_poly\] instead.
             #[deprecated]
             #[prost(string, tag = "3")]
             pub layout_id: ::prost::alloc::string::String,
@@ -645,19 +645,19 @@ pub mod document {
             pub enum LayoutType {
                 /// Layout Unspecified.
                 Unspecified = 0,
-                /// References a [Page.blocks][google.cloud.documentai.v1beta3.Document.Page.blocks] element.
+                /// References a \[Page.blocks][google.cloud.documentai.v1beta3.Document.Page.blocks\] element.
                 Block = 1,
-                /// References a [Page.paragraphs][google.cloud.documentai.v1beta3.Document.Page.paragraphs] element.
+                /// References a \[Page.paragraphs][google.cloud.documentai.v1beta3.Document.Page.paragraphs\] element.
                 Paragraph = 2,
-                /// References a [Page.lines][google.cloud.documentai.v1beta3.Document.Page.lines] element.
+                /// References a \[Page.lines][google.cloud.documentai.v1beta3.Document.Page.lines\] element.
                 Line = 3,
-                /// References a [Page.tokens][google.cloud.documentai.v1beta3.Document.Page.tokens] element.
+                /// References a \[Page.tokens][google.cloud.documentai.v1beta3.Document.Page.tokens\] element.
                 Token = 4,
-                /// References a [Page.visual_elements][google.cloud.documentai.v1beta3.Document.Page.visual_elements] element.
+                /// References a \[Page.visual_elements][google.cloud.documentai.v1beta3.Document.Page.visual_elements\] element.
                 VisualElement = 5,
-                /// Refrrences a [Page.tables][google.cloud.documentai.v1beta3.Document.Page.tables] element.
+                /// Refrrences a \[Page.tables][google.cloud.documentai.v1beta3.Document.Page.tables\] element.
                 Table = 6,
-                /// References a [Page.form_fields][google.cloud.documentai.v1beta3.Document.Page.form_fields] element.
+                /// References a \[Page.form_fields][google.cloud.documentai.v1beta3.Document.Page.form_fields\] element.
                 FormField = 7,
             }
         }
@@ -688,7 +688,7 @@ pub mod document {
         /// are replaced.
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct Parent {
-            /// The index of the [Document.revisions] identifying the parent revision.
+            /// The index of the \[Document.revisions\] identifying the parent revision.
             #[prost(int32, tag = "1")]
             pub revision: i32,
             /// The index of the parent revisions corresponding collection of items
@@ -774,7 +774,7 @@ pub mod document {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct TextChange {
         /// Provenance of the correction.
-        /// Text anchor indexing into the [Document.text][google.cloud.documentai.v1beta3.Document.text].  There can only be a
+        /// Text anchor indexing into the \[Document.text][google.cloud.documentai.v1beta3.Document.text\].  There can only be a
         /// single `TextAnchor.text_segments` element.  If the start and
         /// end index of the text segment are the same, the text change is inserted
         /// before that index.
@@ -793,7 +793,7 @@ pub mod document {
         /// Optional. Currently supports Google Cloud Storage URI of the form
         ///    `gs://bucket_name/object_name`. Object versioning is not supported.
         ///    See [Google Cloud Storage Request
-        ///    URIs](https://cloud.google.com/storage/docs/reference-uris) for more
+        ///    URIs](<https://cloud.google.com/storage/docs/reference-uris>) for more
         ///    info.
         #[prost(string, tag = "1")]
         Uri(::prost::alloc::string::String),
@@ -811,7 +811,7 @@ pub struct RawDocument {
     #[prost(bytes = "vec", tag = "1")]
     pub content: ::prost::alloc::vec::Vec<u8>,
     /// An IANA MIME type (RFC6838) indicating the nature and format of the
-    /// [content].
+    /// \[content\].
     #[prost(string, tag = "2")]
     pub mime_type: ::prost::alloc::string::String,
 }
@@ -851,7 +851,7 @@ pub mod batch_documents_input_config {
     /// The source.
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Source {
-        /// The set of documents that match the specified Cloud Storage [gcs_prefix].
+        /// The set of documents that match the specified Cloud Storage \[gcs_prefix\].
         #[prost(message, tag = "1")]
         GcsPrefix(super::GcsPrefix),
         /// The set of documents individually specified on Cloud Storage.
@@ -947,7 +947,7 @@ pub struct Processor {
     #[prost(message, optional, tag = "7")]
     pub create_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The KMS key used for encryption/decryption in CMEK scenarios.
-    /// See https://cloud.google.com/security-key-management.
+    /// See <https://cloud.google.com/security-key-management.>
     #[prost(string, tag = "8")]
     pub kms_key_name: ::prost::alloc::string::String,
 }
@@ -1013,7 +1013,7 @@ pub struct ProcessRequest {
     /// Required. The processor resource name.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
-    /// The document payload, the [content] and [mime_type] fields must be set.
+    /// The document payload, the \[content\] and \[mime_type\] fields must be set.
     #[deprecated]
     #[prost(message, optional, tag = "2")]
     pub document: ::core::option::Option<Document>,
@@ -1048,9 +1048,9 @@ pub struct HumanReviewStatus {
     #[prost(string, tag = "2")]
     pub state_message: ::prost::alloc::string::String,
     /// The name of the operation triggered by the processed document. This field
-    /// is populated only when the [state] is [HUMAN_REVIEW_IN_PROGRESS]. It has
+    /// is populated only when the \[state\] is \[HUMAN_REVIEW_IN_PROGRESS\]. It has
     /// the same response type and metadata as the long running operation returned
-    /// by [ReviewDocument] method.
+    /// by \[ReviewDocument\] method.
     #[prost(string, tag = "3")]
     pub human_review_operation: ::prost::alloc::string::String,
 }
@@ -1071,7 +1071,7 @@ pub mod human_review_status {
         /// Human review validation is triggered and the document is under review.
         InProgress = 3,
         /// Some error happened during triggering human review, see the
-        /// [state_message] for details.
+        /// \[state_message\] for details.
         Error = 4,
     }
 }
@@ -1128,7 +1128,7 @@ pub mod batch_process_request {
         pub gcs_source: ::prost::alloc::string::String,
         /// Mimetype of the input. If the input is a raw document, the supported
         /// mimetypes are application/pdf, image/tiff, and image/gif.
-        /// If the input is a [Document] proto, the type should be application/json.
+        /// If the input is a \[Document\] proto, the type should be application/json.
         #[prost(string, tag = "2")]
         pub mime_type: ::prost::alloc::string::String,
     }
@@ -1169,7 +1169,7 @@ pub mod batch_process_metadata {
     /// The status of a each individual document in the batch process.
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct IndividualProcessStatus {
-        /// The source of the document, same as the [input_gcs_source] field in the
+        /// The source of the document, same as the \[input_gcs_source\] field in the
         /// request when the batch process started. The batch process is started by
         /// take snapshot of that document, since a user can move or change that
         /// document during the process.
@@ -1264,7 +1264,7 @@ pub struct CreateProcessorRequest {
     /// Format: projects/{project}/locations/{location}
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
-    /// Required. The processor to be created, requires [processor_type] and [display_name]
+    /// Required. The processor to be created, requires \[processor_type\] and \[display_name\]
     /// to be set. Also, the processor is under CMEK if CMEK fields are set.
     #[prost(message, optional, tag = "2")]
     pub processor: ::core::option::Option<Processor>,
@@ -1421,7 +1421,7 @@ pub mod document_processor_service_client {
     impl<T> DocumentProcessorServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -1434,7 +1434,7 @@ pub mod document_processor_service_client {
             interceptor: F,
         ) -> DocumentProcessorServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
