@@ -2,7 +2,7 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NetworkConfig {
     /// The name of the Google Compute Engine
-    /// [VPC network](/compute/docs/networks-and-firewalls#networks) to which the
+    /// [VPC network](<https://cloud.google.com/vpc/docs/vpc>) to which the
     /// instance is connected.
     #[prost(string, tag = "1")]
     pub network: ::prost::alloc::string::String,
@@ -12,17 +12,17 @@ pub struct NetworkConfig {
     pub modes: ::prost::alloc::vec::Vec<i32>,
     /// A /29 CIDR block in one of the
     /// [internal IP address
-    /// ranges](https://www.arin.net/knowledge/address_filters.html) that
-    /// identifies the range of IP addresses reserved for this instance. For
+    /// ranges](<https://www.arin.net/reference/research/statistics/address_filters/>)
+    /// that identifies the range of IP addresses reserved for this instance. For
     /// example, 10.0.0.0/29 or 192.168.0.0/29. The range you specify can't overlap
     /// with either existing subnets or assigned IP address ranges for other Cloud
     /// Filestore instances in the selected VPC network.
     #[prost(string, tag = "4")]
     pub reserved_ip_range: ::prost::alloc::string::String,
     /// Output only. IPv4 addresses in the format
-    /// {octet 1}.{octet 2}.{octet 3}.{octet 4} or IPv6 addresses in the format
-    /// {block 1}:{block 2}:{block 3}:{block 4}:{block 5}:{block 6}:{block
-    /// 7}:{block 8}.
+    /// IPv4 addresses in the format `{octet1}.{octet2}.{octet3}.{octet4}` or
+    /// IPv6 addresses in the format
+    /// `{block1}:{block2}:{block3}:{block4}:{block5}:{block6}:{block7}:{block8}`.
     #[prost(string, repeated, tag = "5")]
     pub ip_addresses: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
@@ -64,7 +64,7 @@ pub mod file_share_config {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Source {
         /// The resource name of the backup, in the format
-        /// projects/{project_number}/locations/{location_id}/backups/{backup_id},
+        /// `projects/{project_number}/locations/{location_id}/backups/{backup_id}`,
         /// that this file share has been restored from.
         #[prost(string, tag = "8")]
         SourceBackup(::prost::alloc::string::String),
@@ -74,8 +74,8 @@ pub mod file_share_config {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NfsExportOptions {
     /// List of either an IPv4 addresses in the format
-    /// {octet 1}.{octet 2}.{octet 3}.{octet 4} or CIDR ranges in the format
-    /// {octet 1}.{octet 2}.{octet 3}.{octet 4}/{mask size} which may mount the
+    /// `{octet1}.{octet2}.{octet3}.{octet4}` or CIDR ranges in the format
+    /// `{octet1}.{octet2}.{octet3}.{octet4}/{mask size}` which may mount the
     /// file share.
     /// Overlapping IP ranges are not allowed, both within and across
     /// NfsExportOptions. An error will be returned.
@@ -135,7 +135,7 @@ pub mod nfs_export_options {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Instance {
     /// Output only. The resource name of the instance, in the format
-    /// projects/{project}/locations/{location}/instances/{instance}.
+    /// `projects/{project}/locations/{location}/instances/{instance}`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// The description of the instance (2048 characters or less).
@@ -225,7 +225,7 @@ pub mod instance {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateInstanceRequest {
     /// Required. The instance's project and location, in the format
-    /// projects/{project_id}/locations/{location}. In Cloud Filestore,
+    /// `projects/{project_id}/locations/{location}`. In Cloud Filestore,
     /// locations map to GCP zones, for example **us-west1-b**.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
@@ -233,8 +233,7 @@ pub struct CreateInstanceRequest {
     /// The name must be unique for the specified project and location.
     #[prost(string, tag = "2")]
     pub instance_id: ::prost::alloc::string::String,
-    /// Required. A [instance resource]
-    /// (/cloud-filestore/reference/rest/v1/projects.locations.instances)
+    /// Required. An [instance resource]\[google.cloud.filestore.v1.Instance\]
     #[prost(message, optional, tag = "3")]
     pub instance: ::core::option::Option<Instance>,
 }
@@ -242,7 +241,7 @@ pub struct CreateInstanceRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetInstanceRequest {
     /// Required. The instance resource name, in the format
-    /// projects/{project_id}/locations/{location}/instances/{instance_id}.
+    /// `projects/{project_id}/locations/{location}/instances/{instance_id}`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
@@ -267,11 +266,11 @@ pub struct UpdateInstanceRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RestoreInstanceRequest {
     /// Required. The resource name of the instance, in the format
-    /// projects/{project_number}/locations/{location_id}/instances/{instance_id}.
+    /// `projects/{project_number}/locations/{location_id}/instances/{instance_id}`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
-    /// Required. Name of the file share in the Cloud Filestore instance that the backup
-    /// is being restored to.
+    /// Required. Name of the file share in the Cloud Filestore instance that the
+    /// backup is being restored to.
     #[prost(string, tag = "2")]
     pub file_share: ::prost::alloc::string::String,
     #[prost(oneof = "restore_instance_request::Source", tags = "3")]
@@ -282,7 +281,7 @@ pub mod restore_instance_request {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Source {
         /// The resource name of the backup, in the format
-        /// projects/{project_number}/locations/{location_id}/backups/{backup_id}.
+        /// `projects/{project_number}/locations/{location_id}/backups/{backup_id}`.
         #[prost(string, tag = "3")]
         SourceBackup(::prost::alloc::string::String),
     }
@@ -291,18 +290,18 @@ pub mod restore_instance_request {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteInstanceRequest {
     /// Required. The instance resource name, in the format
-    /// projects/{project_id}/locations/{location}/instances/{instance_id}
+    /// `projects/{project_id}/locations/{location}/instances/{instance_id}`
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
 /// ListInstancesRequest lists instances.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListInstancesRequest {
-    /// Required. The project and location for which to retrieve instance information,
-    /// in the format projects/{project_id}/locations/{location}. In Cloud
-    /// Filestore, locations map to GCP zones, for example **us-west1-b**. To
-    /// retrieve instance information for all locations, use "-" for the {location}
-    /// value.
+    /// Required. The project and location for which to retrieve instance
+    /// information, in the format `projects/{project_id}/locations/{location}`. In
+    /// Cloud Filestore, locations map to GCP zones, for example **us-west1-b**. To
+    /// retrieve instance information for all locations, use "-" for the
+    /// `{location}` value.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// The maximum number of items to return.
@@ -324,8 +323,8 @@ pub struct ListInstancesRequest {
 pub struct ListInstancesResponse {
     /// A list of instances in the project for the specified location.
     ///
-    /// If the {location} value in the request is "-", the response contains a list
-    /// of instances from all locations. If any location is unreachable, the
+    /// If the `{location}` value in the request is "-", the response contains a
+    /// list of instances from all locations. If any location is unreachable, the
     /// response will only return instances in reachable locations and the
     /// "unreachable" field will be populated with a list of unreachable locations.
     #[prost(message, repeated, tag = "1")]
@@ -342,7 +341,7 @@ pub struct ListInstancesResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Backup {
     /// Output only. The resource name of the backup, in the format
-    /// projects/{project_number}/locations/{location_id}/backups/{backup_id}.
+    /// `projects/{project_number}/locations/{location_id}/backups/{backup_id}`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// A description of the backup with 2048 characters or less.
@@ -362,12 +361,12 @@ pub struct Backup {
     /// Output only. Capacity of the source file share when the backup was created.
     #[prost(int64, tag = "6")]
     pub capacity_gb: i64,
-    /// Output only. The size of the storage used by the backup. As backups share storage,
-    /// this number is expected to change with backup creation/deletion.
+    /// Output only. The size of the storage used by the backup. As backups share
+    /// storage, this number is expected to change with backup creation/deletion.
     #[prost(int64, tag = "7")]
     pub storage_bytes: i64,
     /// The resource name of the source Cloud Filestore instance, in the format
-    /// projects/{project_number}/locations/{location_id}/instances/{instance_id},
+    /// `projects/{project_number}/locations/{location_id}/instances/{instance_id}`,
     /// used to create this backup.
     #[prost(string, tag = "8")]
     pub source_instance: ::prost::alloc::string::String,
@@ -375,13 +374,13 @@ pub struct Backup {
     /// backup is created from.
     #[prost(string, tag = "9")]
     pub source_file_share: ::prost::alloc::string::String,
-    /// Output only. The service tier of the source Cloud Filestore instance that this backup
-    /// is created from.
+    /// Output only. The service tier of the source Cloud Filestore instance that
+    /// this backup is created from.
     #[prost(enumeration = "instance::Tier", tag = "10")]
     pub source_instance_tier: i32,
-    /// Output only. Amount of bytes that will be downloaded if the backup is restored. This
-    /// may be different than storage bytes, since sequential backups of the same
-    /// disk will share storage.
+    /// Output only. Amount of bytes that will be downloaded if the backup is
+    /// restored. This may be different than storage bytes, since sequential
+    /// backups of the same disk will share storage.
     #[prost(int64, tag = "11")]
     pub download_bytes: i64,
     /// Output only. Reserved for future use.
@@ -411,12 +410,11 @@ pub mod backup {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateBackupRequest {
     /// Required. The backup's project and location, in the format
-    /// projects/{project_number}/locations/{location}. In Cloud Filestore,
+    /// `projects/{project_number}/locations/{location}`. In Cloud Filestore,
     /// backup locations map to GCP regions, for example **us-west1**.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
-    /// Required. A [backup resource]
-    /// (/cloud-filestore/reference/rest/v1/projects.locations.backups)
+    /// Required. A [backup resource]\[google.cloud.filestore.v1.Backup\]
     #[prost(message, optional, tag = "2")]
     pub backup: ::core::option::Option<Backup>,
     /// Required. The ID to use for the backup.
@@ -433,19 +431,18 @@ pub struct CreateBackupRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteBackupRequest {
     /// Required. The backup resource name, in the format
-    /// projects/{project_number}/locations/{location}/backups/{backup_id}
+    /// `projects/{project_number}/locations/{location}/backups/{backup_id}`
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
 /// UpdateBackupRequest updates description and/or labels for a backup.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateBackupRequest {
-    /// Required. A [backup resource]
-    /// (/cloud-filestore/reference/rest/v1/projects.locations.backups)
+    /// Required. A [backup resource]\[google.cloud.filestore.v1.Backup\]
     #[prost(message, optional, tag = "1")]
     pub backup: ::core::option::Option<Backup>,
-    /// Required. Mask of fields to update.  At least one path must be supplied in this
-    /// field.
+    /// Required. Mask of fields to update.  At least one path must be supplied in
+    /// this field.
     #[prost(message, optional, tag = "2")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
@@ -453,19 +450,19 @@ pub struct UpdateBackupRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetBackupRequest {
     /// Required. The backup resource name, in the format
-    /// projects/{project_number}/locations/{location}/backups/{backup_id}.
+    /// `projects/{project_number}/locations/{location}/backups/{backup_id}`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
 /// ListBackupsRequest lists backups.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListBackupsRequest {
-    /// Required. The project and location for which to retrieve backup information,
-    /// in the format projects/{project_number}/locations/{location}.
-    /// In Cloud Filestore, backup locations map to GCP regions,
-    /// for example **us-west1**.
-    /// To retrieve backup information for all locations, use "-" for the
-    /// {location} value.
+    /// Required. The project and location for which to retrieve backup
+    /// information, in the format
+    /// `projects/{project_number}/locations/{location}`. In Cloud Filestore,
+    /// backup locations map to GCP regions, for example **us-west1**. To retrieve
+    /// backup information for all locations, use "-" for the
+    /// `{location}` value.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// The maximum number of items to return.
@@ -487,8 +484,8 @@ pub struct ListBackupsRequest {
 pub struct ListBackupsResponse {
     /// A list of backups in the project for the specified location.
     ///
-    /// If the {location} value in the request is "-", the response contains a list
-    /// of backups from all locations. If any location is unreachable, the
+    /// If the `{location}` value in the request is "-", the response contains a
+    /// list of backups from all locations. If any location is unreachable, the
     /// response will only return backups in reachable locations and the
     /// "unreachable" field will be populated with a list of unreachable
     /// locations.
@@ -532,7 +529,7 @@ pub mod cloud_filestore_manager_client {
     impl<T> CloudFilestoreManagerClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -545,7 +542,7 @@ pub mod cloud_filestore_manager_client {
             interceptor: F,
         ) -> CloudFilestoreManagerClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
