@@ -190,10 +190,7 @@ pub struct MembershipFeatureState {
     /// The high-level state of this Feature for a single membership.
     #[prost(message, optional, tag = "1")]
     pub state: ::core::option::Option<FeatureState>,
-    #[prost(
-        oneof = "membership_feature_state::FeatureState",
-        tags = "100, 104, 106"
-    )]
+    #[prost(oneof = "membership_feature_state::FeatureState", tags = "100, 104, 106")]
     pub feature_state: ::core::option::Option<membership_feature_state::FeatureState>,
 }
 /// Nested message and enum types in `MembershipFeatureState`.
@@ -229,7 +226,7 @@ pub struct ListFeaturesRequest {
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
     /// Lists Features that match the filter expression, following the syntax
-    /// outlined in https://google.aip.dev/160.
+    /// outlined in <https://google.aip.dev/160.>
     ///
     /// Examples:
     ///
@@ -247,7 +244,7 @@ pub struct ListFeaturesRequest {
     #[prost(string, tag = "4")]
     pub filter: ::prost::alloc::string::String,
     /// One or more fields to compare and use to sort the output.
-    /// See https://google.aip.dev/132#ordering.
+    /// See <https://google.aip.dev/132#ordering.>
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
@@ -384,7 +381,7 @@ pub struct OperationMetadata {
     pub status_detail: ::prost::alloc::string::String,
     /// Output only. Identifies whether the user has requested cancellation
     /// of the operation. Operations that have successfully been cancelled
-    /// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
+    /// have \[Operation.error][\] value with a \[google.rpc.Status.code][google.rpc.Status.code\] of 1,
     /// corresponding to `Code.CANCELLED`.
     #[prost(bool, tag = "6")]
     pub cancel_requested: bool,
@@ -417,7 +414,7 @@ pub mod gke_hub_client {
     impl<T> GkeHubClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -430,7 +427,7 @@ pub mod gke_hub_client {
             interceptor: F,
         ) -> GkeHubClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
