@@ -10,7 +10,7 @@ pub struct Membership {
     ///   2. It must consist of lower case alphanumeric characters or `-`
     ///   3. It must start and end with an alphanumeric character
     ///
-    /// Which can be expressed as the regex: `[a-z0-9]([-a-z0-9]*[a-z0-9])?`,
+    /// Which can be expressed as the regex: `\[a-z0-9]([-a-z0-9]*[a-z0-9\])?`,
     /// with a maximum length of 63 characters.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
@@ -19,7 +19,7 @@ pub struct Membership {
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// Output only. Description of this membership, limited to 63 characters.
-    /// Must match the regex: `[a-zA-Z0-9][a-zA-Z0-9_\-\.\ ]*`
+    /// Must match the regex: `\[a-zA-Z0-9\][a-zA-Z0-9_\-\.\ ]*`
     ///
     /// This field is present for legacy purposes.
     #[prost(string, tag = "3")]
@@ -40,7 +40,7 @@ pub struct Membership {
     /// be modified after creation, but this is not recommended. For GKE clusters,
     /// external_id is managed by the Hub API and updates will be ignored.
     ///
-    /// The ID must match the regex: `[a-zA-Z0-9][a-zA-Z0-9_\-\.]*`
+    /// The ID must match the regex: `\[a-zA-Z0-9][a-zA-Z0-9_\-\.\]*`
     ///
     /// If this Membership represents a Kubernetes cluster, this value should be
     /// set to the UID of the `kube-system` namespace object.
@@ -48,7 +48,7 @@ pub struct Membership {
     pub external_id: ::prost::alloc::string::String,
     /// Optional. How to identify workloads from this Membership.
     /// See the documentation on Workload Identity for more details:
-    /// https://cloud.google.com/kubernetes-engine/docs/how-to/workload-identity
+    /// <https://cloud.google.com/kubernetes-engine/docs/how-to/workload-identity>
     #[prost(message, optional, tag = "10")]
     pub authority: ::core::option::Option<Authority>,
     /// Output only. For clusters using Connect, the timestamp of the most recent connection
@@ -101,9 +101,6 @@ pub mod membership {
 /// endpoint and any additional Kubernetes metadata.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MembershipEndpoint {
-    /// Optional. GKE-specific information. Only present if this Membership is a GKE cluster.
-    #[prost(message, optional, tag = "1")]
-    pub gke_cluster: ::core::option::Option<GkeCluster>,
     /// Output only. Useful Kubernetes-specific metadata.
     #[prost(message, optional, tag = "2")]
     pub kubernetes_metadata: ::core::option::Option<KubernetesMetadata>,
@@ -117,6 +114,25 @@ pub struct MembershipEndpoint {
     ///   * Ensure proper initial configuration of default Hub Features.
     #[prost(message, optional, tag = "3")]
     pub kubernetes_resource: ::core::option::Option<KubernetesResource>,
+    /// Cluster information of the registered cluster.
+    #[prost(oneof = "membership_endpoint::Type", tags = "1, 4, 5")]
+    pub r#type: ::core::option::Option<membership_endpoint::Type>,
+}
+/// Nested message and enum types in `MembershipEndpoint`.
+pub mod membership_endpoint {
+    /// Cluster information of the registered cluster.
+    #[derive(Clone, PartialEq, ::prost::Oneof)]
+    pub enum Type {
+        /// Optional. Specific information for a GKE-on-GCP cluster.
+        #[prost(message, tag = "1")]
+        GkeCluster(super::GkeCluster),
+        /// Optional. Specific information for a GKE On-Prem cluster.
+        #[prost(message, tag = "4")]
+        OnPremCluster(super::OnPremCluster),
+        /// Optional. Specific information for a GKE Multi-Cloud cluster.
+        #[prost(message, tag = "5")]
+        MultiCloudCluster(super::MultiCloudCluster),
+    }
 }
 /// KubernetesResource contains the YAML manifests and configuration for
 /// Membership Kubernetes resources in the cluster. After CreateMembership or
@@ -180,6 +196,44 @@ pub struct GkeCluster {
     /// Zonal clusters are also supported.
     #[prost(string, tag = "1")]
     pub resource_link: ::prost::alloc::string::String,
+    /// Output only. If cluster_missing is set then it denotes that the GKE cluster no longer
+    /// exists in the GKE Control Plane.
+    #[prost(bool, tag = "2")]
+    pub cluster_missing: bool,
+}
+/// OnPremCluster contains information specific to GKE On-Prem clusters.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct OnPremCluster {
+    /// Immutable. Self-link of the GCP resource for the GKE On-Prem cluster. For example:
+    ///
+    ///  //gkeonprem.googleapis.com/projects/my-project/locations/us-west1-a/vmwareClusters/my-cluster
+    ///  //gkeonprem.googleapis.com/projects/my-project/locations/us-west1-a/bareMetalClusters/my-cluster
+    #[prost(string, tag = "1")]
+    pub resource_link: ::prost::alloc::string::String,
+    /// Output only. If cluster_missing is set then it denotes that
+    /// API(gkeonprem.googleapis.com) resource for this GKE On-Prem cluster no
+    /// longer exists.
+    #[prost(bool, tag = "2")]
+    pub cluster_missing: bool,
+    /// Immutable. Whether the cluster is an admin cluster.
+    #[prost(bool, tag = "3")]
+    pub admin_cluster: bool,
+}
+/// MultiCloudCluster contains information specific to GKE Multi-Cloud clusters.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct MultiCloudCluster {
+    /// Immutable. Self-link of the GCP resource for the GKE Multi-Cloud cluster. For
+    /// example:
+    ///
+    ///  //gkemulticloud.googleapis.com/projects/my-project/locations/us-west1-a/awsClusters/my-cluster
+    ///  //gkemulticloud.googleapis.com/projects/my-project/locations/us-west1-a/azureClusters/my-cluster
+    #[prost(string, tag = "1")]
+    pub resource_link: ::prost::alloc::string::String,
+    /// Output only. If cluster_missing is set then it denotes that
+    /// API(gkemulticloud.googleapis.com) resource for this GKE Multi-Cloud cluster
+    /// no longer exists.
+    #[prost(bool, tag = "2")]
+    pub cluster_missing: bool,
 }
 /// KubernetesMetadata provides informational metadata for Memberships
 /// that are created from Kubernetes Endpoints (currently, these are equivalent
@@ -213,10 +267,10 @@ pub struct KubernetesMetadata {
 }
 /// Authority encodes how Google will recognize identities from this Membership.
 /// See the workload identity documentation for more details:
-/// https://cloud.google.com/kubernetes-engine/docs/how-to/workload-identity
+/// <https://cloud.google.com/kubernetes-engine/docs/how-to/workload-identity>
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Authority {
-    /// Optional. A JSON Web Token (JWT) issuer URI. `issuer` must start with `https://` and
+    /// Optional. A JSON Web Token (JWT) issuer URI. `issuer` must start with `<https://`> and
     /// be a valid URL with length <2000 characters.
     ///
     /// If set, then Google will allow valid OIDC tokens from this issuer to
@@ -294,7 +348,7 @@ pub struct ListMembershipsRequest {
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
     /// Optional. Lists Memberships that match the filter expression, following the syntax
-    /// outlined in https://google.aip.dev/160.
+    /// outlined in <https://google.aip.dev/160.>
     ///
     /// Examples:
     ///
@@ -316,7 +370,7 @@ pub struct ListMembershipsRequest {
     #[prost(string, tag = "4")]
     pub filter: ::prost::alloc::string::String,
     /// Optional. One or more fields to compare and use to sort the output.
-    /// See https://google.aip.dev/132#ordering.
+    /// See <https://google.aip.dev/132#ordering.>
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
@@ -357,7 +411,7 @@ pub struct CreateMembershipRequest {
     ///   2. It must consist of lower case alphanumeric characters or `-`
     ///   3. It must start and end with an alphanumeric character
     ///
-    /// Which can be expressed as the regex: `[a-z0-9]([-a-z0-9]*[a-z0-9])?`,
+    /// Which can be expressed as the regex: `\[a-z0-9]([-a-z0-9]*[a-z0-9\])?`,
     /// with a maximum length of 63 characters.
     #[prost(string, tag = "2")]
     pub membership_id: ::prost::alloc::string::String,
@@ -389,6 +443,8 @@ pub struct UpdateMembershipRequest {
     /// If you are updating a map field, set the value of a key to null or empty
     /// string to delete the key from the map. It's not possible to update a key's
     /// value to the empty string.
+    /// If you specify the update_mask to be a special path "*", fully replaces all
+    /// user-modifiable fields to match `resource`.
     #[prost(message, optional, tag = "3")]
     pub resource: ::core::option::Option<Membership>,
 }
@@ -519,7 +575,7 @@ pub struct OperationMetadata {
     pub status_detail: ::prost::alloc::string::String,
     /// Output only. Identifies whether the user has requested cancellation
     /// of the operation. Operations that have successfully been cancelled
-    /// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
+    /// have \[Operation.error][\] value with a \[google.rpc.Status.code][google.rpc.Status.code\] of 1,
     /// corresponding to `Code.CANCELLED`.
     #[prost(bool, tag = "6")]
     pub cancel_requested: bool,
@@ -531,8 +587,14 @@ pub struct OperationMetadata {
 pub mod gke_hub_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " GKE Hub CRUD API for the Membership resource."]
-    #[doc = " The Membership service is currently only available in the global location."]
+    #[doc = " The GKE Hub service handles the registration of many Kubernetes"]
+    #[doc = " clusters to Google Cloud, represented with the [Membership][google.cloud.gkehub.v1alpha2.Membership] resource."]
+    #[doc = ""]
+    #[doc = " GKE Hub is currently only available in the global region."]
+    #[doc = ""]
+    #[doc = " **Membership management may be non-trivial:** it is recommended to use one"]
+    #[doc = " of the Google-provided client libraries or tools where possible when working"]
+    #[doc = " with Membership resources."]
     #[derive(Debug, Clone)]
     pub struct GkeHubClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -540,7 +602,7 @@ pub mod gke_hub_client {
     impl<T> GkeHubClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -553,7 +615,7 @@ pub mod gke_hub_client {
             interceptor: F,
         ) -> GkeHubClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -612,7 +674,11 @@ pub mod gke_hub_client {
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Adds a new Membership."]
+        #[doc = " Creates a new Membership."]
+        #[doc = ""]
+        #[doc = " **This is currently only supported for GKE clusters on Google Cloud**."]
+        #[doc = " To register other clusters, follow the instructions at"]
+        #[doc = " https://cloud.google.com/anthos/multicluster-management/connect/registering-a-cluster."]
         pub async fn create_membership(
             &mut self,
             request: impl tonic::IntoRequest<super::CreateMembershipRequest>,
@@ -633,6 +699,10 @@ pub mod gke_hub_client {
             self.inner.unary(request.into_request(), path, codec).await
         }
         #[doc = " Removes a Membership."]
+        #[doc = ""]
+        #[doc = " **This is currently only supported for GKE clusters on Google Cloud**."]
+        #[doc = " To unregister other clusters, follow the instructions at"]
+        #[doc = " https://cloud.google.com/anthos/multicluster-management/connect/unregistering-a-cluster."]
         pub async fn delete_membership(
             &mut self,
             request: impl tonic::IntoRequest<super::DeleteMembershipRequest>,
@@ -673,6 +743,9 @@ pub mod gke_hub_client {
             self.inner.unary(request.into_request(), path, codec).await
         }
         #[doc = " Generates the manifest for deployment of the GKE connect agent."]
+        #[doc = ""]
+        #[doc = " **This method is used internally by Google-provided libraries.**"]
+        #[doc = " Most clients should not need to call this method directly."]
         pub async fn generate_connect_manifest(
             &mut self,
             request: impl tonic::IntoRequest<super::GenerateConnectManifestRequest>,
