@@ -10,7 +10,7 @@ pub struct Document {
     /// automatically detected). Both ISO and BCP-47 language codes are
     /// accepted.<br>
     /// [Language
-    /// Support](https://cloud.google.com/natural-language/docs/languages) lists
+    /// Support](<https://cloud.google.com/natural-language/docs/languages>) lists
     /// currently supported languages for each API method. If the language (either
     /// specified by the caller or automatically detected) is not supported by the
     /// called API method, an `INVALID_ARGUMENT` error is returned.
@@ -44,7 +44,7 @@ pub mod document {
         Content(::prost::alloc::string::String),
         /// The Google Cloud Storage URI where the file content is located.
         /// This URI must be of the form: gs://bucket_name/object_name. For more
-        /// details, see https://cloud.google.com/storage/docs/reference-uris.
+        /// details, see <https://cloud.google.com/storage/docs/reference-uris.>
         /// NOTE: Cloud Storage object versioning is not supported.
         #[prost(string, tag = "3")]
         GcsContentUri(::prost::alloc::string::String),
@@ -56,8 +56,8 @@ pub struct Sentence {
     /// The sentence text.
     #[prost(message, optional, tag = "1")]
     pub text: ::core::option::Option<TextSpan>,
-    /// For calls to [AnalyzeSentiment][] or if
-    /// [AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment] is set to
+    /// For calls to \[AnalyzeSentiment][\] or if
+    /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment\] is set to
     /// true, this field will contain the sentiment for the sentence.
     #[prost(message, optional, tag = "2")]
     pub sentiment: ::core::option::Option<Sentiment>,
@@ -93,8 +93,8 @@ pub struct Entity {
     /// supports proper noun mentions.
     #[prost(message, repeated, tag = "5")]
     pub mentions: ::prost::alloc::vec::Vec<EntityMention>,
-    /// For calls to [AnalyzeEntitySentiment][] or if
-    /// [AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment] is set to
+    /// For calls to \[AnalyzeEntitySentiment][\] or if
+    /// \[AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment\] is set to
     /// true, this field will contain the aggregate sentiment expressed for this
     /// entity in the provided document.
     #[prost(message, optional, tag = "6")]
@@ -174,7 +174,7 @@ pub struct Token {
     /// Dependency tree parse for this token.
     #[prost(message, optional, tag = "3")]
     pub dependency_edge: ::core::option::Option<DependencyEdge>,
-    /// [Lemma](https://en.wikipedia.org/wiki/Lemma_%28morphology%29) of the token.
+    /// \[Lemma\](<https://en.wikipedia.org/wiki/Lemma_%28morphology%29>) of the token.
     #[prost(string, tag = "4")]
     pub lemma: ::prost::alloc::string::String,
 }
@@ -194,7 +194,7 @@ pub struct Sentiment {
 }
 /// Represents part of speech information for a token. Parts of speech
 /// are as defined in
-/// http://www.lrec-conf.org/proceedings/lrec2012/pdf/274_Paper.pdf
+/// <http://www.lrec-conf.org/proceedings/lrec2012/pdf/274_Paper.pdf>
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PartOfSpeech {
     /// The part of speech tag.
@@ -470,7 +470,7 @@ pub mod part_of_speech {
 }
 /// Represents dependency parse tree information for a token. (For more
 /// information on dependency labels, see
-/// http://www.aclweb.org/anthology/P13-2017
+/// <http://www.aclweb.org/anthology/P13-2017>
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DependencyEdge {
     /// Represents the head of this token in the dependency tree.
@@ -668,8 +668,8 @@ pub struct EntityMention {
     /// The type of the entity mention.
     #[prost(enumeration = "entity_mention::Type", tag = "2")]
     pub r#type: i32,
-    /// For calls to [AnalyzeEntitySentiment][] or if
-    /// [AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment] is set to
+    /// For calls to \[AnalyzeEntitySentiment][\] or if
+    /// \[AnnotateTextRequest.Features.extract_entity_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entity_sentiment\] is set to
     /// true, this field will contain the sentiment expressed for this mention of
     /// the entity in the provided document.
     #[prost(message, optional, tag = "3")]
@@ -696,7 +696,7 @@ pub struct TextSpan {
     #[prost(string, tag = "1")]
     pub content: ::prost::alloc::string::String,
     /// The API calculates the beginning offset of the content in the original
-    /// document according to the [EncodingType][google.cloud.language.v1.EncodingType] specified in the API request.
+    /// document according to the \[EncodingType][google.cloud.language.v1.EncodingType\] specified in the API request.
     #[prost(int32, tag = "2")]
     pub begin_offset: i32,
 }
@@ -704,7 +704,7 @@ pub struct TextSpan {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ClassificationCategory {
     /// The name of the category representing the document, from the [predefined
-    /// taxonomy](https://cloud.google.com/natural-language/docs/categories).
+    /// taxonomy](<https://cloud.google.com/natural-language/docs/categories>).
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// The classifier's confidence of the category. Number represents how certain
@@ -730,7 +730,7 @@ pub struct AnalyzeSentimentResponse {
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1.Document.language] field for more details.
+    /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
     #[prost(string, tag = "2")]
     pub language: ::prost::alloc::string::String,
     /// The sentiment for all the sentences in the document.
@@ -755,7 +755,7 @@ pub struct AnalyzeEntitySentimentResponse {
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1.Document.language] field for more details.
+    /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
     #[prost(string, tag = "2")]
     pub language: ::prost::alloc::string::String,
 }
@@ -777,7 +777,7 @@ pub struct AnalyzeEntitiesResponse {
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1.Document.language] field for more details.
+    /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
     #[prost(string, tag = "2")]
     pub language: ::prost::alloc::string::String,
 }
@@ -802,7 +802,7 @@ pub struct AnalyzeSyntaxResponse {
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1.Document.language] field for more details.
+    /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
     #[prost(string, tag = "3")]
     pub language: ::prost::alloc::string::String,
 }
@@ -861,26 +861,26 @@ pub mod annotate_text_request {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnnotateTextResponse {
     /// Sentences in the input document. Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax].
+    /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax\].
     #[prost(message, repeated, tag = "1")]
     pub sentences: ::prost::alloc::vec::Vec<Sentence>,
     /// Tokens, along with their syntactic information, in the input document.
     /// Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax].
+    /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1.AnnotateTextRequest.Features.extract_syntax\].
     #[prost(message, repeated, tag = "2")]
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// Entities, along with their semantic information, in the input document.
     /// Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_entities][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entities].
+    /// \[AnnotateTextRequest.Features.extract_entities][google.cloud.language.v1.AnnotateTextRequest.Features.extract_entities\].
     #[prost(message, repeated, tag = "3")]
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The overall sentiment for the document. Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment].
+    /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1.AnnotateTextRequest.Features.extract_document_sentiment\].
     #[prost(message, optional, tag = "4")]
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1.Document.language] field for more details.
+    /// See \[Document.language][google.cloud.language.v1.Document.language\] field for more details.
     #[prost(string, tag = "5")]
     pub language: ::prost::alloc::string::String,
     /// Categories identified in the input document.
@@ -924,7 +924,7 @@ pub mod language_service_client {
     impl<T> LanguageServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -937,7 +937,7 @@ pub mod language_service_client {
             interceptor: F,
         ) -> LanguageServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
