@@ -10,7 +10,7 @@ pub struct Document {
     /// automatically detected). Both ISO and BCP-47 language codes are
     /// accepted.<br>
     /// [Language
-    /// Support](https://cloud.google.com/natural-language/docs/languages) lists
+    /// Support](<https://cloud.google.com/natural-language/docs/languages>) lists
     /// currently supported languages for each API method. If the language (either
     /// specified by the caller or automatically detected) is not supported by the
     /// called API method, an `INVALID_ARGUMENT` error is returned.
@@ -43,7 +43,7 @@ pub mod document {
         Content(::prost::alloc::string::String),
         /// The Google Cloud Storage URI where the file content is located.
         /// This URI must be of the form: gs://bucket_name/object_name. For more
-        /// details, see https://cloud.google.com/storage/docs/reference-uris.
+        /// details, see <https://cloud.google.com/storage/docs/reference-uris.>
         /// NOTE: Cloud Storage object versioning is not supported.
         #[prost(string, tag = "3")]
         GcsContentUri(::prost::alloc::string::String),
@@ -55,8 +55,8 @@ pub struct Sentence {
     /// The sentence text.
     #[prost(message, optional, tag = "1")]
     pub text: ::core::option::Option<TextSpan>,
-    /// For calls to [AnalyzeSentiment][] or if
-    /// [AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_document_sentiment]
+    /// For calls to \[AnalyzeSentiment][\] or if
+    /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_document_sentiment\]
     /// is set to true, this field will contain the sentiment for the sentence.
     #[prost(message, optional, tag = "2")]
     pub sentiment: ::core::option::Option<Sentiment>,
@@ -128,7 +128,7 @@ pub struct Token {
     /// Dependency tree parse for this token.
     #[prost(message, optional, tag = "3")]
     pub dependency_edge: ::core::option::Option<DependencyEdge>,
-    /// [Lemma](https://en.wikipedia.org/wiki/Lemma_%28morphology%29) of the token.
+    /// \[Lemma\](<https://en.wikipedia.org/wiki/Lemma_%28morphology%29>) of the token.
     #[prost(string, tag = "4")]
     pub lemma: ::prost::alloc::string::String,
 }
@@ -138,7 +138,7 @@ pub struct Token {
 pub struct Sentiment {
     /// DEPRECATED FIELD - This field is being deprecated in
     /// favor of score. Please refer to our documentation at
-    /// https://cloud.google.com/natural-language/docs for more information.
+    /// <https://cloud.google.com/natural-language/docs> for more information.
     #[prost(float, tag = "1")]
     pub polarity: f32,
     /// A non-negative number in the [0, +inf) range, which represents
@@ -634,7 +634,7 @@ pub struct TextSpan {
     pub content: ::prost::alloc::string::String,
     /// The API calculates the beginning offset of the content in the original
     /// document according to the
-    /// [EncodingType][google.cloud.language.v1beta1.EncodingType] specified in the
+    /// \[EncodingType][google.cloud.language.v1beta1.EncodingType\] specified in the
     /// API request.
     #[prost(int32, tag = "2")]
     pub begin_offset: i32,
@@ -658,7 +658,7 @@ pub struct AnalyzeSentimentResponse {
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1beta1.Document.language]
+    /// See \[Document.language][google.cloud.language.v1beta1.Document.language\]
     /// field for more details.
     #[prost(string, tag = "2")]
     pub language: ::prost::alloc::string::String,
@@ -684,7 +684,7 @@ pub struct AnalyzeEntitiesResponse {
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1beta1.Document.language]
+    /// See \[Document.language][google.cloud.language.v1beta1.Document.language\]
     /// field for more details.
     #[prost(string, tag = "2")]
     pub language: ::prost::alloc::string::String,
@@ -710,7 +710,7 @@ pub struct AnalyzeSyntaxResponse {
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1beta1.Document.language]
+    /// See \[Document.language][google.cloud.language.v1beta1.Document.language\]
     /// field for more details.
     #[prost(string, tag = "3")]
     pub language: ::prost::alloc::string::String,
@@ -750,26 +750,26 @@ pub mod annotate_text_request {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnnotateTextResponse {
     /// Sentences in the input document. Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_syntax].
+    /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_syntax\].
     #[prost(message, repeated, tag = "1")]
     pub sentences: ::prost::alloc::vec::Vec<Sentence>,
     /// Tokens, along with their syntactic information, in the input document.
     /// Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_syntax].
+    /// \[AnnotateTextRequest.Features.extract_syntax][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_syntax\].
     #[prost(message, repeated, tag = "2")]
     pub tokens: ::prost::alloc::vec::Vec<Token>,
     /// Entities, along with their semantic information, in the input document.
     /// Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_entities][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_entities].
+    /// \[AnnotateTextRequest.Features.extract_entities][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_entities\].
     #[prost(message, repeated, tag = "3")]
     pub entities: ::prost::alloc::vec::Vec<Entity>,
     /// The overall sentiment for the document. Populated if the user enables
-    /// [AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_document_sentiment].
+    /// \[AnnotateTextRequest.Features.extract_document_sentiment][google.cloud.language.v1beta1.AnnotateTextRequest.Features.extract_document_sentiment\].
     #[prost(message, optional, tag = "4")]
     pub document_sentiment: ::core::option::Option<Sentiment>,
     /// The language of the text, which will be the same as the language specified
     /// in the request or, if not specified, the automatically-detected language.
-    /// See [Document.language][google.cloud.language.v1beta1.Document.language]
+    /// See \[Document.language][google.cloud.language.v1beta1.Document.language\]
     /// field for more details.
     #[prost(string, tag = "5")]
     pub language: ::prost::alloc::string::String,
@@ -811,7 +811,7 @@ pub mod language_service_client {
     impl<T> LanguageServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -824,7 +824,7 @@ pub mod language_service_client {
             interceptor: F,
         ) -> LanguageServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
