@@ -10,7 +10,7 @@ pub struct Domain {
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// Optional. The full names of the Google Compute Engine
-    /// [networks](/compute/docs/networks-and-firewalls#networks) the domain
+    /// \[networks\](/compute/docs/networks-and-firewalls#networks) the domain
     /// instance is connected to. Networks can be added using UpdateDomain.
     /// The domain is only available on networks listed in `authorized_networks`.
     /// If CIDR subnets overlap between networks, domain creation will fail.
@@ -19,11 +19,11 @@ pub struct Domain {
     /// Required. The CIDR range of internal addresses that are reserved for this
     /// domain. Reserved networks must be /24 or larger. Ranges must be
     /// unique and non-overlapping with existing subnets in
-    /// [Domain].[authorized_networks].
+    /// \[Domain].[authorized_networks\].
     #[prost(string, tag = "4")]
     pub reserved_ip_range: ::prost::alloc::string::String,
     /// Required. Locations where domain needs to be provisioned.
-    /// [regions][compute/docs/regions-zones/]
+    /// \[regions][compute/docs/regions-zones/\]
     /// e.g. us-west1 or us-east4
     /// Service supports up to 4 locations at once. Each location will use a /26
     /// block.
@@ -158,7 +158,7 @@ pub mod trust {
     }
     /// Represents the direction of trust.
     /// See
-    /// [System.DirectoryServices.ActiveDirectory.TrustDirection](https://docs.microsoft.com/en-us/dotnet/api/system.directoryservices.activedirectory.trustdirection?view=netframework-4.7.2)
+    /// \[System.DirectoryServices.ActiveDirectory.TrustDirection\](<https://docs.microsoft.com/en-us/dotnet/api/system.directoryservices.activedirectory.trustdirection?view=netframework-4.7.2>)
     /// for more information.
     #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
     #[repr(i32)]
@@ -190,7 +190,7 @@ pub struct OpMetadata {
     pub verb: ::prost::alloc::string::String,
     /// Output only. Identifies whether the user has requested cancellation
     /// of the operation. Operations that have successfully been cancelled
-    /// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
+    /// have \[Operation.error][\] value with a \[google.rpc.Status.code][google.rpc.Status.code\] of 1,
     /// corresponding to `Code.CANCELLED`.
     #[prost(bool, tag = "5")]
     pub requested_cancellation: bool,
@@ -199,7 +199,7 @@ pub struct OpMetadata {
     pub api_version: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [CreateMicrosoftAdDomain][google.cloud.managedidentities.v1beta1.CreateMicrosoftAdDomain]
+/// \[CreateMicrosoftAdDomain][google.cloud.managedidentities.v1beta1.CreateMicrosoftAdDomain\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateMicrosoftAdDomainRequest {
     /// The resource project name and location using the form:
@@ -223,7 +223,7 @@ pub struct CreateMicrosoftAdDomainRequest {
     pub domain: ::core::option::Option<Domain>,
 }
 /// Request message for
-/// [ResetAdminPassword][google.cloud.managedidentities.v1beta1.ResetAdminPassword]
+/// \[ResetAdminPassword][google.cloud.managedidentities.v1beta1.ResetAdminPassword\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ResetAdminPasswordRequest {
     /// The domain resource name using the form:
@@ -232,15 +232,15 @@ pub struct ResetAdminPasswordRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Response message for
-/// [ResetAdminPassword][google.cloud.managedidentities.v1beta1.ResetAdminPassword]
+/// \[ResetAdminPassword][google.cloud.managedidentities.v1beta1.ResetAdminPassword\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ResetAdminPasswordResponse {
-    /// A random password. See [admin][google.cloud.managedidentities.v1beta1.Domain.admin] for more information.
+    /// A random password. See \[admin][google.cloud.managedidentities.v1beta1.Domain.admin\] for more information.
     #[prost(string, tag = "1")]
     pub password: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [ListDomains][google.cloud.managedidentities.v1beta1.ListDomains]
+/// \[ListDomains][google.cloud.managedidentities.v1beta1.ListDomains\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListDomainsRequest {
     /// Required. The resource name of the domain location using the form:
@@ -251,7 +251,7 @@ pub struct ListDomainsRequest {
     /// If not specified, a default value of 1000 will be used.
     /// Regardless of the page_size value, the response may include a partial list.
     /// Callers should rely on a response's
-    /// [next_page_token][google.cloud.managedidentities.v1beta1.ListDomainsResponse.next_page_token]
+    /// \[next_page_token][google.cloud.managedidentities.v1beta1.ListDomainsResponse.next_page_token\]
     /// to determine if there are additional results to list.
     #[prost(int32, tag = "2")]
     pub page_size: i32,
@@ -265,13 +265,13 @@ pub struct ListDomainsRequest {
     pub filter: ::prost::alloc::string::String,
     /// Optional. Specifies the ordering of results. See
     /// [Sorting
-    /// order](https://cloud.google.com/apis/design/design_patterns#sorting_order)
+    /// order](<https://cloud.google.com/apis/design/design_patterns#sorting_order>)
     /// for more information.
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
 /// Response message for
-/// [ListDomains][google.cloud.managedidentities.v1beta1.ListDomains]
+/// \[ListDomains][google.cloud.managedidentities.v1beta1.ListDomains\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListDomainsResponse {
     /// A list of Managed Identities Service domains in the project.
@@ -286,7 +286,7 @@ pub struct ListDomainsResponse {
     pub unreachable: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Request message for
-/// [GetDomain][google.cloud.managedidentities.v1beta1.GetDomain]
+/// \[GetDomain][google.cloud.managedidentities.v1beta1.GetDomain\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetDomainRequest {
     /// The domain resource name using the form:
@@ -295,12 +295,12 @@ pub struct GetDomainRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [UpdateDomain][google.cloud.managedidentities.v1beta1.UpdateDomain]
+/// \[UpdateDomain][google.cloud.managedidentities.v1beta1.UpdateDomain\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateDomainRequest {
     /// Mask of fields to update. At least one path must be supplied in this
     /// field. The elements of the repeated paths field may only include
-    /// fields from [Domain][google.cloud.managedidentities.v1beta1.Domain]:
+    /// fields from \[Domain][google.cloud.managedidentities.v1beta1.Domain\]:
     ///  * `labels`
     ///  * `locations`
     ///  * `authorized_networks`
@@ -312,7 +312,7 @@ pub struct UpdateDomainRequest {
     pub domain: ::core::option::Option<Domain>,
 }
 /// Request message for
-/// [DeleteDomain][google.cloud.managedidentities.v1beta1.DeleteDomain]
+/// \[DeleteDomain][google.cloud.managedidentities.v1beta1.DeleteDomain\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteDomainRequest {
     /// The domain resource name using the form:
@@ -321,7 +321,7 @@ pub struct DeleteDomainRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [AttachTrust][google.cloud.managedidentities.v1beta1.AttachTrust]
+/// \[AttachTrust][google.cloud.managedidentities.v1beta1.AttachTrust\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AttachTrustRequest {
     /// The resource domain name, project name and location using the form:
@@ -333,7 +333,7 @@ pub struct AttachTrustRequest {
     pub trust: ::core::option::Option<Trust>,
 }
 /// Request message for
-/// [ReconfigureTrust][google.cloud.managedidentities.v1beta1.ReconfigureTrust]
+/// \[ReconfigureTrust][google.cloud.managedidentities.v1beta1.ReconfigureTrust\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReconfigureTrustRequest {
     /// The resource domain name, project name and location using the form:
@@ -350,7 +350,7 @@ pub struct ReconfigureTrustRequest {
     pub target_dns_ip_addresses: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Request message for
-/// [DetachTrust][google.cloud.managedidentities.v1beta1.DetachTrust]
+/// \[DetachTrust][google.cloud.managedidentities.v1beta1.DetachTrust\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DetachTrustRequest {
     /// The resource domain name, project name, and location using the form:
@@ -362,7 +362,7 @@ pub struct DetachTrustRequest {
     pub trust: ::core::option::Option<Trust>,
 }
 /// Request message for
-/// [ValidateTrust][google.cloud.managedidentities.v1beta1.ValidateTrust]
+/// \[ValidateTrust][google.cloud.managedidentities.v1beta1.ValidateTrust\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ValidateTrustRequest {
     /// The resource domain name, project name, and location using the form:
@@ -384,7 +384,7 @@ pub mod managed_identities_service_client {
     impl<T> ManagedIdentitiesServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -397,7 +397,7 @@ pub mod managed_identities_service_client {
             interceptor: F,
         ) -> ManagedIdentitiesServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
