@@ -7,7 +7,7 @@ pub struct Instance {
     /// Note: Memcached instances are managed and addressed at regional level so
     /// location_id here refers to a GCP region; however, users may choose which
     /// zones Memcached nodes within an instances should be provisioned in.
-    /// Refer to [zones] field for more details.
+    /// Refer to \[zones\] field for more details.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// User provided name for the instance only used for display
@@ -16,12 +16,12 @@ pub struct Instance {
     pub display_name: ::prost::alloc::string::String,
     /// Resource labels to represent user-provided metadata.
     /// Refer to cloud documentation on labels for more details.
-    /// https://cloud.google.com/compute/docs/labeling-resources
+    /// <https://cloud.google.com/compute/docs/labeling-resources>
     #[prost(map = "string, string", tag = "3")]
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// The full name of the Google Compute Engine
-    /// [network](/compute/docs/networks-and-firewalls#networks) to which the
+    /// \[network\](/compute/docs/networks-and-firewalls#networks) to which the
     /// instance is connected. If left unspecified, the `default` network
     /// will be used.
     #[prost(string, tag = "4")]
@@ -50,7 +50,7 @@ pub struct Instance {
     #[prost(message, optional, tag = "11")]
     pub parameters: ::core::option::Option<MemcacheParameters>,
     /// Output only. List of Memcached nodes.
-    /// Refer to [Node] message for more details.
+    /// Refer to \[Node\] message for more details.
     #[prost(message, repeated, tag = "12")]
     pub memcache_nodes: ::prost::alloc::vec::Vec<instance::Node>,
     /// Output only. The time the instance was created.
@@ -168,7 +168,7 @@ pub mod instance {
         PerformingMaintenance = 5,
     }
 }
-/// Request for [ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances].
+/// Request for \[ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListInstancesRequest {
     /// Required. The resource name of the instance location using the form:
@@ -181,7 +181,7 @@ pub struct ListInstancesRequest {
     /// If not specified, a default value of 1000 will be used by the service.
     /// Regardless of the page_size value, the response may include a partial list
     /// and a caller should only rely on response's
-    /// [next_page_token][CloudMemcache.ListInstancesResponse.next_page_token]
+    /// \[next_page_token][CloudMemcache.ListInstancesResponse.next_page_token\]
     /// to determine if there are more instances left to be queried.
     #[prost(int32, tag = "2")]
     pub page_size: i32,
@@ -197,7 +197,7 @@ pub struct ListInstancesRequest {
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
-/// Response for [ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances].
+/// Response for \[ListInstances][google.cloud.memcache.v1.CloudMemcache.ListInstances\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListInstancesResponse {
     /// A list of Memcached instances in the project in the specified location,
@@ -215,7 +215,7 @@ pub struct ListInstancesResponse {
     #[prost(string, repeated, tag = "3")]
     pub unreachable: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
-/// Request for [GetInstance][google.cloud.memcache.v1.CloudMemcache.GetInstance].
+/// Request for \[GetInstance][google.cloud.memcache.v1.CloudMemcache.GetInstance\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetInstanceRequest {
     /// Required. Memcached instance resource name in the format:
@@ -224,7 +224,7 @@ pub struct GetInstanceRequest {
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
-/// Request for [CreateInstance][google.cloud.memcache.v1.CloudMemcache.CreateInstance].
+/// Request for \[CreateInstance][google.cloud.memcache.v1.CloudMemcache.CreateInstance\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateInstanceRequest {
     /// Required. The resource name of the instance location using the form:
@@ -248,7 +248,7 @@ pub struct CreateInstanceRequest {
     #[prost(message, optional, tag = "3")]
     pub instance: ::core::option::Option<Instance>,
 }
-/// Request for [UpdateInstance][google.cloud.memcache.v1.CloudMemcache.UpdateInstance].
+/// Request for \[UpdateInstance][google.cloud.memcache.v1.CloudMemcache.UpdateInstance\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateInstanceRequest {
     /// Required. Mask of fields to update.
@@ -260,7 +260,7 @@ pub struct UpdateInstanceRequest {
     #[prost(message, optional, tag = "2")]
     pub instance: ::core::option::Option<Instance>,
 }
-/// Request for [DeleteInstance][google.cloud.memcache.v1.CloudMemcache.DeleteInstance].
+/// Request for \[DeleteInstance][google.cloud.memcache.v1.CloudMemcache.DeleteInstance\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteInstanceRequest {
     /// Required. Memcached instance resource name in the format:
@@ -269,7 +269,7 @@ pub struct DeleteInstanceRequest {
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
-/// Request for [ApplyParameters][google.cloud.memcache.v1.CloudMemcache.ApplyParameters].
+/// Request for \[ApplyParameters][google.cloud.memcache.v1.CloudMemcache.ApplyParameters\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ApplyParametersRequest {
     /// Required. Resource name of the Memcached instance for which parameter group updates
@@ -285,7 +285,7 @@ pub struct ApplyParametersRequest {
     #[prost(bool, tag = "3")]
     pub apply_all: bool,
 }
-/// Request for [UpdateParameters][google.cloud.memcache.v1.CloudMemcache.UpdateParameters].
+/// Request for \[UpdateParameters][google.cloud.memcache.v1.CloudMemcache.UpdateParameters\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateParametersRequest {
     /// Required. Resource name of the Memcached instance for which the parameters should be
@@ -332,7 +332,7 @@ pub struct OperationMetadata {
     pub status_detail: ::prost::alloc::string::String,
     /// Output only. Identifies whether the user has requested cancellation
     /// of the operation. Operations that have successfully been cancelled
-    /// have [Operation.error][] value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
+    /// have \[Operation.error][\] value with a \[google.rpc.Status.code][google.rpc.Status.code\] of 1,
     /// corresponding to `Code.CANCELLED`.
     #[prost(bool, tag = "6")]
     pub cancel_requested: bool,
@@ -374,7 +374,7 @@ pub mod cloud_memcache_client {
     impl<T> CloudMemcacheClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -387,7 +387,7 @@ pub mod cloud_memcache_client {
             interceptor: F,
         ) -> CloudMemcacheClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
