@@ -454,7 +454,7 @@ pub mod restore {
     }
 }
 /// Request message for
-/// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
+/// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListServicesRequest {
     /// Required. The relative resource name of the location of metastore services
@@ -470,13 +470,13 @@ pub struct ListServicesRequest {
     #[prost(int32, tag = "2")]
     pub page_size: i32,
     /// Optional. A page token, received from a previous
-    /// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices]
+    /// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\]
     /// call. Provide this token to retrieve the subsequent page.
     ///
     /// To retrieve the first page, supply an empty page token.
     ///
     /// When paginating, other parameters provided to
-    /// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices]
+    /// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\]
     /// must match the call that provided the page token.
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
@@ -484,13 +484,13 @@ pub struct ListServicesRequest {
     #[prost(string, tag = "4")]
     pub filter: ::prost::alloc::string::String,
     /// Optional. Specify the ordering of results as described in [Sorting
-    /// Order](https://cloud.google.com/apis/design/design_patterns#sorting_order).
+    /// Order](<https://cloud.google.com/apis/design/design_patterns#sorting_order>).
     /// If not specified, the results will be sorted in the default order.
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
 /// Response message for
-/// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
+/// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListServicesResponse {
     /// The services in the specified location.
@@ -505,7 +505,7 @@ pub struct ListServicesResponse {
     pub unreachable: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Request message for
-/// [DataprocMetastore.GetService][google.cloud.metastore.v1beta.DataprocMetastore.GetService].
+/// \[DataprocMetastore.GetService][google.cloud.metastore.v1beta.DataprocMetastore.GetService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetServiceRequest {
     /// Required. The relative resource name of the metastore service to retrieve,
@@ -516,7 +516,7 @@ pub struct GetServiceRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.CreateService][google.cloud.metastore.v1beta.DataprocMetastore.CreateService].
+/// \[DataprocMetastore.CreateService][google.cloud.metastore.v1beta.DataprocMetastore.CreateService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateServiceRequest {
     /// Required. The relative resource name of the location in which to create a
@@ -548,13 +548,13 @@ pub struct CreateServiceRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "4")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.UpdateService][google.cloud.metastore.v1beta.DataprocMetastore.UpdateService].
+/// \[DataprocMetastore.UpdateService][google.cloud.metastore.v1beta.DataprocMetastore.UpdateService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateServiceRequest {
     /// Required. A field mask used to specify the fields to be overwritten in the
@@ -580,13 +580,13 @@ pub struct UpdateServiceRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "3")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.DeleteService][google.cloud.metastore.v1beta.DataprocMetastore.DeleteService].
+/// \[DataprocMetastore.DeleteService][google.cloud.metastore.v1beta.DataprocMetastore.DeleteService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteServiceRequest {
     /// Required. The relative resource name of the metastore service to delete, in
@@ -605,13 +605,13 @@ pub struct DeleteServiceRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "2")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
+/// \[DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListMetadataImportsRequest {
     /// Required. The relative resource name of the service whose metadata imports
@@ -626,13 +626,13 @@ pub struct ListMetadataImportsRequest {
     #[prost(int32, tag = "2")]
     pub page_size: i32,
     /// Optional. A page token, received from a previous
-    /// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices]
+    /// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\]
     /// call. Provide this token to retrieve the subsequent page.
     ///
     /// To retrieve the first page, supply an empty page token.
     ///
     /// When paginating, other parameters provided to
-    /// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices]
+    /// \[DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices\]
     /// must match the call that provided the page token.
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
@@ -640,13 +640,13 @@ pub struct ListMetadataImportsRequest {
     #[prost(string, tag = "4")]
     pub filter: ::prost::alloc::string::String,
     /// Optional. Specify the ordering of results as described in [Sorting
-    /// Order](https://cloud.google.com/apis/design/design_patterns#sorting_order).
+    /// Order](<https://cloud.google.com/apis/design/design_patterns#sorting_order>).
     /// If not specified, the results will be sorted in the default order.
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
 /// Response message for
-/// [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
+/// \[DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListMetadataImportsResponse {
     /// The imports in the specified service.
@@ -661,7 +661,7 @@ pub struct ListMetadataImportsResponse {
     pub unreachable: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Request message for
-/// [DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.GetMetadataImport].
+/// \[DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.GetMetadataImport\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetMetadataImportRequest {
     /// Required. The relative resource name of the metadata import to retrieve, in
@@ -672,7 +672,7 @@ pub struct GetMetadataImportRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.CreateMetadataImport].
+/// \[DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.CreateMetadataImport\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateMetadataImportRequest {
     /// Required. The relative resource name of the service in which to create a
@@ -704,13 +704,13 @@ pub struct CreateMetadataImportRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "4")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.UpdateMetadataImport].
+/// \[DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.UpdateMetadataImport\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateMetadataImportRequest {
     /// Required. A field mask used to specify the fields to be overwritten in the
@@ -736,13 +736,13 @@ pub struct UpdateMetadataImportRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "3")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
+/// \[DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListBackupsRequest {
     /// Required. The relative resource name of the service whose backups to
@@ -757,13 +757,13 @@ pub struct ListBackupsRequest {
     #[prost(int32, tag = "2")]
     pub page_size: i32,
     /// Optional. A page token, received from a previous
-    /// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups]
+    /// \[DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups\]
     /// call. Provide this token to retrieve the subsequent page.
     ///
     /// To retrieve the first page, supply an empty page token.
     ///
     /// When paginating, other parameters provided to
-    /// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups]
+    /// \[DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups\]
     /// must match the call that provided the page token.
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
@@ -771,13 +771,13 @@ pub struct ListBackupsRequest {
     #[prost(string, tag = "4")]
     pub filter: ::prost::alloc::string::String,
     /// Optional. Specify the ordering of results as described in [Sorting
-    /// Order](https://cloud.google.com/apis/design/design_patterns#sorting_order).
+    /// Order](<https://cloud.google.com/apis/design/design_patterns#sorting_order>).
     /// If not specified, the results will be sorted in the default order.
     #[prost(string, tag = "5")]
     pub order_by: ::prost::alloc::string::String,
 }
 /// Response message for
-/// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
+/// \[DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListBackupsResponse {
     /// The backups of the specified service.
@@ -792,7 +792,7 @@ pub struct ListBackupsResponse {
     pub unreachable: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Request message for
-/// [DataprocMetastore.GetBackup][google.cloud.metastore.v1beta.DataprocMetastore.GetBackup].
+/// \[DataprocMetastore.GetBackup][google.cloud.metastore.v1beta.DataprocMetastore.GetBackup\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetBackupRequest {
     /// Required. The relative resource name of the backup to retrieve, in the
@@ -803,7 +803,7 @@ pub struct GetBackupRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.CreateBackup][google.cloud.metastore.v1beta.DataprocMetastore.CreateBackup].
+/// \[DataprocMetastore.CreateBackup][google.cloud.metastore.v1beta.DataprocMetastore.CreateBackup\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateBackupRequest {
     /// Required. The relative resource name of the service in which to create a
@@ -834,13 +834,13 @@ pub struct CreateBackupRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "4")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.DeleteBackup][google.cloud.metastore.v1beta.DataprocMetastore.DeleteBackup].
+/// \[DataprocMetastore.DeleteBackup][google.cloud.metastore.v1beta.DataprocMetastore.DeleteBackup\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteBackupRequest {
     /// Required. The relative resource name of the backup to delete, in the
@@ -859,13 +859,13 @@ pub struct DeleteBackupRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format)
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>)
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "2")]
     pub request_id: ::prost::alloc::string::String,
 }
 /// Request message for
-/// [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1beta.DataprocMetastore.ExportMetadata].
+/// \[DataprocMetastore.ExportMetadata][google.cloud.metastore.v1beta.DataprocMetastore.ExportMetadata\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ExportMetadataRequest {
     /// Required. The relative resource name of the metastore service to run
@@ -884,7 +884,7 @@ pub struct ExportMetadataRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format).
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>).
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "3")]
     pub request_id: ::prost::alloc::string::String,
@@ -908,7 +908,7 @@ pub mod export_metadata_request {
         DestinationGcsFolder(::prost::alloc::string::String),
     }
 }
-/// Request message for [DataprocMetastore.Restore][].
+/// Request message for \[DataprocMetastore.Restore][\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RestoreServiceRequest {
     /// Required. The relative resource name of the metastore service to run
@@ -936,7 +936,7 @@ pub struct RestoreServiceRequest {
     /// the creation of duplicate commitments.
     ///
     /// The request ID must be a valid
-    /// [UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Format).
+    /// \[UUID\](<https://en.wikipedia.org/wiki/Universally_unique_identifier#Format>).
     /// A zero UUID (00000000-0000-0000-0000-000000000000) is not supported.
     #[prost(string, tag = "4")]
     pub request_id: ::prost::alloc::string::String,
@@ -961,8 +961,8 @@ pub struct OperationMetadata {
     pub status_message: ::prost::alloc::string::String,
     /// Output only. Identifies whether the caller has requested cancellation
     /// of the operation. Operations that have successfully been cancelled
-    /// have [Operation.error][] value with a
-    /// [google.rpc.Status.code][google.rpc.Status.code] of 1, corresponding to
+    /// have \[Operation.error][\] value with a
+    /// \[google.rpc.Status.code][google.rpc.Status.code\] of 1, corresponding to
     /// `Code.CANCELLED`.
     #[prost(bool, tag = "6")]
     pub requested_cancellation: bool,
@@ -1037,7 +1037,7 @@ pub mod dataproc_metastore_client {
     impl<T> DataprocMetastoreClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -1050,7 +1050,7 @@ pub mod dataproc_metastore_client {
             interceptor: F,
         ) -> DataprocMetastoreClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
