@@ -288,12 +288,12 @@ pub struct SoftwareConfig {
     /// The version of the software running in the environment.
     /// This encapsulates both the version of Cloud Composer functionality and the
     /// version of Apache Airflow. It must match the regular expression
-    /// `composer-([0-9]+\.[0-9]+\.[0-9]+|latest)-airflow-[0-9]+\.[0-9]+(\.[0-9]+.*)?`.
+    /// `composer-(\[0-9]+\.[0-9]+\.[0-9]+|latest)-airflow-[0-9]+\.[0-9]+(\.[0-9\]+.*)?`.
     /// When used as input, the server also checks if the provided version is
     /// supported and denies the request for an unsupported version.
     ///
     /// The Cloud Composer portion of the version is a
-    /// [semantic version](https://semver.org) or `latest`. When the patch version
+    /// [semantic version](<https://semver.org>) or `latest`. When the patch version
     /// is omitted, the current Cloud Composer patch version is selected.
     /// When `latest` is provided instead of an explicit version number,
     /// the server replaces `latest` with the current Cloud Composer version
@@ -301,7 +301,7 @@ pub struct SoftwareConfig {
     ///
     /// The portion of the image version that follows *airflow-* is an
     /// official Apache Airflow repository
-    /// [release name](https://github.com/apache/incubator-airflow/releases).
+    /// [release name](<https://github.com/apache/incubator-airflow/releases>).
     ///
     /// See also [Version
     /// List](/composer/docs/concepts/versioning/composer-versions).
@@ -316,11 +316,11 @@ pub struct SoftwareConfig {
     /// contain an equals sign ("=") or semicolon (";"). Section and property names
     /// must not contain a period ("."). Apache Airflow configuration property
     /// names must be written in
-    /// [snake_case](https://en.wikipedia.org/wiki/Snake_case). Property values can
+    /// \[snake_case\](<https://en.wikipedia.org/wiki/Snake_case>). Property values can
     /// contain any character, and can be written in any lower/upper case format.
     ///
     /// Certain Apache Airflow configuration property values are
-    /// [blocked](/composer/docs/concepts/airflow-configurations),
+    /// \[blocked\](/composer/docs/concepts/airflow-configurations),
     /// and cannot be overridden.
     #[prost(map = "string, string", tag = "2")]
     pub airflow_config_overrides:
@@ -330,7 +330,7 @@ pub struct SoftwareConfig {
     ///
     /// Keys refer to the lowercase package name such as "numpy"
     /// and values are the lowercase extras and version specifier such as
-    /// "==1.12.0", "[devel,gcp_api]", or "[devel]>=1.8.2, <1.9.2". To specify a
+    /// "==1.12.0", "\[devel,gcp_api\]", or "\[devel\]>=1.8.2, <1.9.2". To specify a
     /// package without pinning it to a version specifier, use the empty string as
     /// the value.
     #[prost(map = "string, string", tag = "3")]
@@ -340,9 +340,9 @@ pub struct SoftwareConfig {
     /// scheduler, worker, and webserver processes.
     ///
     /// Environment variable names must match the regular expression
-    /// `[a-zA-Z_][a-zA-Z0-9_]*`. They cannot specify Apache Airflow
+    /// `\[a-zA-Z_][a-zA-Z0-9_\]*`. They cannot specify Apache Airflow
     /// software configuration overrides (they cannot match the regular expression
-    /// `AIRFLOW__[A-Z0-9_]+__[A-Z0-9_]+`), and they cannot match any of the
+    /// `AIRFLOW__\[A-Z0-9_]+__[A-Z0-9_\]+`), and they cannot match any of the
     /// following reserved names:
     ///
     /// * `AIRFLOW_HOME`
@@ -406,7 +406,7 @@ pub mod ip_allocation_policy {
         /// netmask.
         ///
         /// Set to a
-        /// [CIDR](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing)
+        /// \[CIDR\](<http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing>)
         /// notation (e.g. `10.96.0.0/14`) from the RFC-1918 private networks (e.g.
         /// `10.0.0.0/8`, `172.16.0.0/12`, `192.168.0.0/16`) to pick a specific range
         /// to use.
@@ -433,7 +433,7 @@ pub mod ip_allocation_policy {
         /// netmask.
         ///
         /// Set to a
-        /// [CIDR](http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing)
+        /// \[CIDR\](<http://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing>)
         /// notation (e.g. `10.96.0.0/14`) from the RFC-1918 private networks (e.g.
         /// `10.0.0.0/8`, `172.16.0.0/12`, `192.168.0.0/16`) to pick a specific range
         /// to use.
@@ -445,7 +445,7 @@ pub mod ip_allocation_policy {
 /// the Apache Airflow software.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NodeConfig {
-    /// Optional. The Compute Engine [zone](/compute/docs/regions-zones) in which
+    /// Optional. The Compute Engine \[zone\](/compute/docs/regions-zones) in which
     /// to deploy the VMs used to run the Apache Airflow software, specified as a
     /// [relative resource
     /// name](/apis/design/resource_names#relative_resource_name). For example:
@@ -514,7 +514,7 @@ pub struct NodeConfig {
     pub disk_size_gb: i32,
     /// Optional. The set of Google API scopes to be made available on all
     /// node VMs. If `oauth_scopes` is empty, defaults to
-    /// ["https://www.googleapis.com/auth/cloud-platform"]. Cannot be updated.
+    /// \["<https://www.googleapis.com/auth/cloud-platform"\].> Cannot be updated.
     #[prost(string, repeated, tag = "6")]
     pub oauth_scopes: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// Optional. The Google Cloud Platform Service Account to be used by the node
@@ -524,7 +524,7 @@ pub struct NodeConfig {
     pub service_account: ::prost::alloc::string::String,
     /// Optional. The list of instance tags applied to all node VMs. Tags are used
     /// to identify valid sources or targets for network firewalls. Each tag within
-    /// the list must comply with [RFC1035](https://www.ietf.org/rfc/rfc1035.txt).
+    /// the list must comply with \[RFC1035\](<https://www.ietf.org/rfc/rfc1035.txt>).
     /// Cannot be updated.
     #[prost(string, repeated, tag = "8")]
     pub tags: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
@@ -608,8 +608,8 @@ pub struct Environment {
     /// The labels map can contain no more than 64 entries. Entries of the labels
     /// map are UTF8 strings that comply with the following restrictions:
     ///
-    /// * Keys must conform to regexp: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
-    /// * Values must conform to regexp:  [\p{Ll}\p{Lo}\p{N}_-]{0,63}
+    /// * Keys must conform to regexp: \[\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-\]{0,62}
+    /// * Values must conform to regexp:  \[\p{Ll}\p{Lo}\p{N}_-\]{0,63}
     /// * Both keys and values are additionally constrained to be <= 128 bytes in
     /// size.
     #[prost(map = "string, string", tag = "7")]
@@ -686,7 +686,7 @@ pub mod environments_client {
     impl<T> EnvironmentsClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -699,7 +699,7 @@ pub mod environments_client {
             interceptor: F,
         ) -> EnvironmentsClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -884,7 +884,7 @@ pub mod image_versions_client {
     impl<T> ImageVersionsClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -897,7 +897,7 @@ pub mod image_versions_client {
             interceptor: F,
         ) -> ImageVersionsClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
