@@ -1,5 +1,5 @@
 /// Http target. The job will be pushed to the job handler by means of
-/// an HTTP request via an [http_method][google.cloud.scheduler.v1.HttpTarget.http_method] such as HTTP
+/// an HTTP request via an \[http_method][google.cloud.scheduler.v1.HttpTarget.http_method\] such as HTTP
 /// POST, HTTP GET, etc. The job is acknowledged by means of an HTTP
 /// response code in the range [200 - 299]. A failure to receive a response
 /// constitutes a failed execution. For a redirected request, the response
@@ -7,9 +7,9 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct HttpTarget {
     /// Required. The full URI path that the request will be sent to. This string
-    /// must begin with either "http://" or "https://". Some examples of
-    /// valid values for [uri][google.cloud.scheduler.v1.HttpTarget.uri] are:
-    /// `http://acme.com` and `https://acme.com/sales:8080`. Cloud Scheduler will
+    /// must begin with either "<http://"> or "<https://".> Some examples of
+    /// valid values for \[uri][google.cloud.scheduler.v1.HttpTarget.uri\] are:
+    /// `<http://acme.com`> and `<https://acme.com/sales:8080`.> Cloud Scheduler will
     /// encode some characters for safety and compatibility. The maximum allowed
     /// URL length is 2083 characters after encoding.
     #[prost(string, tag = "1")]
@@ -25,7 +25,7 @@ pub struct HttpTarget {
     /// headers will be ignored or replaced. A partial list of headers that
     /// will be ignored or replaced is below:
     /// - Host: This will be computed by Cloud Scheduler and derived from
-    /// [uri][google.cloud.scheduler.v1.HttpTarget.uri].
+    /// \[uri][google.cloud.scheduler.v1.HttpTarget.uri\].
     /// * `Content-Length`: This will be computed by Cloud Scheduler.
     /// * `User-Agent`: This will be set to `"Google-Cloud-Scheduler"`.
     /// * `X-Google-*`: Google internal use only.
@@ -37,12 +37,12 @@ pub struct HttpTarget {
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
     /// HTTP request body. A request body is allowed only if the HTTP
     /// method is POST, PUT, or PATCH. It is an error to set body on a job with an
-    /// incompatible [HttpMethod][google.cloud.scheduler.v1.HttpMethod].
+    /// incompatible \[HttpMethod][google.cloud.scheduler.v1.HttpMethod\].
     #[prost(bytes = "vec", tag = "4")]
     pub body: ::prost::alloc::vec::Vec<u8>,
     /// The mode for generating an `Authorization` header for HTTP requests.
     ///
-    /// If specified, all `Authorization` headers in the [HttpTarget.headers][google.cloud.scheduler.v1.HttpTarget.headers]
+    /// If specified, all `Authorization` headers in the \[HttpTarget.headers][google.cloud.scheduler.v1.HttpTarget.headers\]
     /// field will be overridden.
     #[prost(oneof = "http_target::AuthorizationHeader", tags = "5, 6")]
     pub authorization_header: ::core::option::Option<http_target::AuthorizationHeader>,
@@ -51,12 +51,12 @@ pub struct HttpTarget {
 pub mod http_target {
     /// The mode for generating an `Authorization` header for HTTP requests.
     ///
-    /// If specified, all `Authorization` headers in the [HttpTarget.headers][google.cloud.scheduler.v1.HttpTarget.headers]
+    /// If specified, all `Authorization` headers in the \[HttpTarget.headers][google.cloud.scheduler.v1.HttpTarget.headers\]
     /// field will be overridden.
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum AuthorizationHeader {
         /// If specified, an
-        /// [OAuth token](https://developers.google.com/identity/protocols/OAuth2)
+        /// [OAuth token](<https://developers.google.com/identity/protocols/OAuth2>)
         /// will be generated and attached as an `Authorization` header in the HTTP
         /// request.
         ///
@@ -65,7 +65,7 @@ pub mod http_target {
         #[prost(message, tag = "5")]
         OauthToken(super::OAuthToken),
         /// If specified, an
-        /// [OIDC](https://developers.google.com/identity/protocols/OpenIDConnect)
+        /// \[OIDC\](<https://developers.google.com/identity/protocols/OpenIDConnect>)
         /// token will be generated and attached as an `Authorization` header in the
         /// HTTP request.
         ///
@@ -77,7 +77,7 @@ pub mod http_target {
     }
 }
 /// App Engine target. The job will be pushed to a job handler by means
-/// of an HTTP request via an [http_method][google.cloud.scheduler.v1.AppEngineHttpTarget.http_method] such
+/// of an HTTP request via an \[http_method][google.cloud.scheduler.v1.AppEngineHttpTarget.http_method\] such
 /// as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an
 /// HTTP response code in the range [200 - 299]. Error 503 is
 /// considered an App Engine system error instead of an application
@@ -110,13 +110,13 @@ pub struct AppEngineHttpTarget {
     /// Cloud Scheduler sets some headers to default values:
     ///
     /// * `User-Agent`: By default, this header is
-    ///   `"AppEngine-Google; (+http://code.google.com/appengine)"`.
+    ///   `"AppEngine-Google; (+<http://code.google.com/appengine>)"`.
     ///   This header can be modified, but Cloud Scheduler will append
-    ///   `"AppEngine-Google; (+http://code.google.com/appengine)"` to the
+    ///   `"AppEngine-Google; (+<http://code.google.com/appengine>)"` to the
     ///   modified `User-Agent`.
     /// * `X-CloudScheduler`: This header will be set to true.
     ///
-    /// If the job has an [body][google.cloud.scheduler.v1.AppEngineHttpTarget.body], Cloud Scheduler sets
+    /// If the job has an \[body][google.cloud.scheduler.v1.AppEngineHttpTarget.body\], Cloud Scheduler sets
     /// the following headers:
     ///
     /// * `Content-Type`: By default, the `Content-Type` header is set to
@@ -141,7 +141,7 @@ pub struct AppEngineHttpTarget {
     ///
     /// HTTP request body. A request body is allowed only if the HTTP method is
     /// POST or PUT. It will result in invalid argument error to set a body on a
-    /// job with an incompatible [HttpMethod][google.cloud.scheduler.v1.HttpMethod].
+    /// job with an incompatible \[HttpMethod][google.cloud.scheduler.v1.HttpMethod\].
     #[prost(bytes = "vec", tag = "5")]
     pub body: ::prost::alloc::vec::Vec<u8>,
 }
@@ -152,7 +152,7 @@ pub struct PubsubTarget {
     /// Required. The name of the Cloud Pub/Sub topic to which messages will
     /// be published when a job is delivered. The topic name must be in the
     /// same format as required by PubSub's
-    /// [PublishRequest.name](https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#publishrequest),
+    /// \[PublishRequest.name\](<https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#publishrequest>),
     /// for example `projects/PROJECT_ID/topics/TOPIC_ID`.
     ///
     /// The topic must be in the same project as the Cloud Scheduler job.
@@ -176,13 +176,13 @@ pub struct PubsubTarget {
 ///
 /// For more information about services, versions, and instances see
 /// [An Overview of App
-/// Engine](https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine),
+/// Engine](<https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine>),
 /// [Microservices Architecture on Google App
-/// Engine](https://cloud.google.com/appengine/docs/python/microservices-on-app-engine),
+/// Engine](<https://cloud.google.com/appengine/docs/python/microservices-on-app-engine>),
 /// [App Engine Standard request
-/// routing](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed),
+/// routing](<https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed>),
 /// and [App Engine Flex request
-/// routing](https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed).
+/// routing](<https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed>).
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AppEngineRouting {
     /// App service.
@@ -204,102 +204,102 @@ pub struct AppEngineRouting {
     ///
     /// Requests can only be sent to a specific instance if
     /// [manual scaling is used in App Engine
-    /// Standard](https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine?hl=en_US#scaling_types_and_instance_classes).
+    /// Standard](<https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine?hl=en_US#scaling_types_and_instance_classes>).
     /// App Engine Flex does not support instances. For more information, see
     /// [App Engine Standard request
-    /// routing](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed)
+    /// routing](<https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed>)
     /// and [App Engine Flex request
-    /// routing](https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed).
+    /// routing](<https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed>).
     #[prost(string, tag = "3")]
     pub instance: ::prost::alloc::string::String,
     /// Output only. The host that the job is sent to.
     ///
     /// For more information about how App Engine requests are routed, see
-    /// [here](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed).
+    /// \[here\](<https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed>).
     ///
     /// The host is constructed as:
     ///
     ///
-    /// * `host = [application_domain_name]`</br>
-    ///   `| [service] + '.' + [application_domain_name]`</br>
-    ///   `| [version] + '.' + [application_domain_name]`</br>
-    ///   `| [version_dot_service]+ '.' + [application_domain_name]`</br>
-    ///   `| [instance] + '.' + [application_domain_name]`</br>
-    ///   `| [instance_dot_service] + '.' + [application_domain_name]`</br>
-    ///   `| [instance_dot_version] + '.' + [application_domain_name]`</br>
-    ///   `| [instance_dot_version_dot_service] + '.' + [application_domain_name]`
+    /// * `host = \[application_domain_name\]`</br>
+    ///   `| \[service\] + '.' + \[application_domain_name\]`</br>
+    ///   `| \[version\] + '.' + \[application_domain_name\]`</br>
+    ///   `| \[version_dot_service\]+ '.' + \[application_domain_name\]`</br>
+    ///   `| \[instance\] + '.' + \[application_domain_name\]`</br>
+    ///   `| \[instance_dot_service\] + '.' + \[application_domain_name\]`</br>
+    ///   `| \[instance_dot_version\] + '.' + \[application_domain_name\]`</br>
+    ///   `| \[instance_dot_version_dot_service\] + '.' + \[application_domain_name\]`
     ///
     /// * `application_domain_name` = The domain name of the app, for
     ///   example <app-id>.appspot.com, which is associated with the
     ///   job's project ID.
     ///
-    /// * `service =` [service][google.cloud.scheduler.v1.AppEngineRouting.service]
+    /// * `service =` \[service][google.cloud.scheduler.v1.AppEngineRouting.service\]
     ///
-    /// * `version =` [version][google.cloud.scheduler.v1.AppEngineRouting.version]
+    /// * `version =` \[version][google.cloud.scheduler.v1.AppEngineRouting.version\]
     ///
     /// * `version_dot_service =`
-    ///   [version][google.cloud.scheduler.v1.AppEngineRouting.version] `+ '.' +`
-    ///   [service][google.cloud.scheduler.v1.AppEngineRouting.service]
+    ///   \[version][google.cloud.scheduler.v1.AppEngineRouting.version\] `+ '.' +`
+    ///   \[service][google.cloud.scheduler.v1.AppEngineRouting.service\]
     ///
-    /// * `instance =` [instance][google.cloud.scheduler.v1.AppEngineRouting.instance]
+    /// * `instance =` \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\]
     ///
     /// * `instance_dot_service =`
-    ///   [instance][google.cloud.scheduler.v1.AppEngineRouting.instance] `+ '.' +`
-    ///   [service][google.cloud.scheduler.v1.AppEngineRouting.service]
+    ///   \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\] `+ '.' +`
+    ///   \[service][google.cloud.scheduler.v1.AppEngineRouting.service\]
     ///
     /// * `instance_dot_version =`
-    ///   [instance][google.cloud.scheduler.v1.AppEngineRouting.instance] `+ '.' +`
-    ///   [version][google.cloud.scheduler.v1.AppEngineRouting.version]
+    ///   \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\] `+ '.' +`
+    ///   \[version][google.cloud.scheduler.v1.AppEngineRouting.version\]
     ///
     /// * `instance_dot_version_dot_service =`
-    ///   [instance][google.cloud.scheduler.v1.AppEngineRouting.instance] `+ '.' +`
-    ///   [version][google.cloud.scheduler.v1.AppEngineRouting.version] `+ '.' +`
-    ///   [service][google.cloud.scheduler.v1.AppEngineRouting.service]
+    ///   \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\] `+ '.' +`
+    ///   \[version][google.cloud.scheduler.v1.AppEngineRouting.version\] `+ '.' +`
+    ///   \[service][google.cloud.scheduler.v1.AppEngineRouting.service\]
     ///
     ///
-    /// If [service][google.cloud.scheduler.v1.AppEngineRouting.service] is empty, then the job will be sent
+    /// If \[service][google.cloud.scheduler.v1.AppEngineRouting.service\] is empty, then the job will be sent
     /// to the service which is the default service when the job is attempted.
     ///
-    /// If [version][google.cloud.scheduler.v1.AppEngineRouting.version] is empty, then the job will be sent
+    /// If \[version][google.cloud.scheduler.v1.AppEngineRouting.version\] is empty, then the job will be sent
     /// to the version which is the default version when the job is attempted.
     ///
-    /// If [instance][google.cloud.scheduler.v1.AppEngineRouting.instance] is empty, then the job will be
+    /// If \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\] is empty, then the job will be
     /// sent to an instance which is available when the job is attempted.
     ///
-    /// If [service][google.cloud.scheduler.v1.AppEngineRouting.service],
-    /// [version][google.cloud.scheduler.v1.AppEngineRouting.version], or
-    /// [instance][google.cloud.scheduler.v1.AppEngineRouting.instance] is invalid, then the job will be sent
+    /// If \[service][google.cloud.scheduler.v1.AppEngineRouting.service\],
+    /// \[version][google.cloud.scheduler.v1.AppEngineRouting.version\], or
+    /// \[instance][google.cloud.scheduler.v1.AppEngineRouting.instance\] is invalid, then the job will be sent
     /// to the default version of the default service when the job is attempted.
     #[prost(string, tag = "4")]
     pub host: ::prost::alloc::string::String,
 }
 /// Contains information needed for generating an
-/// [OAuth token](https://developers.google.com/identity/protocols/OAuth2).
+/// [OAuth token](<https://developers.google.com/identity/protocols/OAuth2>).
 /// This type of authorization should generally only be used when calling Google
 /// APIs hosted on *.googleapis.com.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct OAuthToken {
-    /// [Service account email](https://cloud.google.com/iam/docs/service-accounts)
+    /// [Service account email](<https://cloud.google.com/iam/docs/service-accounts>)
     /// to be used for generating OAuth token.
     /// The service account must be within the same project as the job. The caller
     /// must have iam.serviceAccounts.actAs permission for the service account.
     #[prost(string, tag = "1")]
     pub service_account_email: ::prost::alloc::string::String,
     /// OAuth scope to be used for generating OAuth access token.
-    /// If not specified, "https://www.googleapis.com/auth/cloud-platform"
+    /// If not specified, "<https://www.googleapis.com/auth/cloud-platform">
     /// will be used.
     #[prost(string, tag = "2")]
     pub scope: ::prost::alloc::string::String,
 }
 /// Contains information needed for generating an
 /// [OpenID Connect
-/// token](https://developers.google.com/identity/protocols/OpenIDConnect).
+/// token](<https://developers.google.com/identity/protocols/OpenIDConnect>).
 /// This type of authorization can be used for many scenarios, including
 /// calling Cloud Run, or endpoints where you intend to validate the token
 /// yourself.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct OidcToken {
-    /// [Service account email](https://cloud.google.com/iam/docs/service-accounts)
+    /// [Service account email](<https://cloud.google.com/iam/docs/service-accounts>)
     /// to be used for generating OIDC token.
     /// The service account must be within the same project as the job. The caller
     /// must have iam.serviceAccounts.actAs permission for the service account.
@@ -335,41 +335,41 @@ pub enum HttpMethod {
 /// The maximum allowed size for a job is 100KB.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Job {
-    /// Optionally caller-specified in [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob], after
+    /// Optionally caller-specified in \[CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob\], after
     /// which it becomes output only.
     ///
     /// The job name. For example:
     /// `projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID`.
     ///
-    /// * `PROJECT_ID` can contain letters ([A-Za-z]), numbers ([0-9]),
+    /// * `PROJECT_ID` can contain letters (\[A-Za-z\]), numbers (\[0-9\]),
     ///    hyphens (-), colons (:), or periods (.).
     ///    For more information, see
     ///    [Identifying
-    ///    projects](https://cloud.google.com/resource-manager/docs/creating-managing-projects#identifying_projects)
+    ///    projects](<https://cloud.google.com/resource-manager/docs/creating-managing-projects#identifying_projects>)
     /// * `LOCATION_ID` is the canonical ID for the job's location.
     ///    The list of available locations can be obtained by calling
-    ///    [ListLocations][google.cloud.location.Locations.ListLocations].
-    ///    For more information, see https://cloud.google.com/about/locations/.
-    /// * `JOB_ID` can contain only letters ([A-Za-z]), numbers ([0-9]),
+    ///    \[ListLocations][google.cloud.location.Locations.ListLocations\].
+    ///    For more information, see <https://cloud.google.com/about/locations/.>
+    /// * `JOB_ID` can contain only letters (\[A-Za-z\]), numbers (\[0-9\]),
     ///    hyphens (-), or underscores (_). The maximum length is 500 characters.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
-    /// Optionally caller-specified in [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob] or
-    /// [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
+    /// Optionally caller-specified in \[CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob\] or
+    /// \[UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob\].
     ///
     /// A human-readable description for the job. This string must not contain
     /// more than 500 characters.
     #[prost(string, tag = "2")]
     pub description: ::prost::alloc::string::String,
-    /// Required, except when used with [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
+    /// Required, except when used with \[UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob\].
     ///
     /// Describes the schedule on which the job will be executed.
     ///
     /// The schedule can be either of the following types:
     ///
-    /// * [Crontab](http://en.wikipedia.org/wiki/Cron#Overview)
+    /// * \[Crontab\](<http://en.wikipedia.org/wiki/Cron#Overview>)
     /// * English-like
-    /// [schedule](https://cloud.google.com/scheduler/docs/configuring/cron-job-schedules)
+    /// \[schedule\](<https://cloud.google.com/scheduler/docs/configuring/cron-job-schedules>)
     ///
     /// As a general rule, execution `n + 1` of a job will not begin
     /// until execution `n` has finished. Cloud Scheduler will never
@@ -380,15 +380,15 @@ pub struct Job {
     /// A scheduled start time will be delayed if the previous
     /// execution has not ended when its scheduled time occurs.
     ///
-    /// If [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count] > 0 and a job attempt fails,
-    /// the job will be tried a total of [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count]
+    /// If \[retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count\] > 0 and a job attempt fails,
+    /// the job will be tried a total of \[retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count\]
     /// times, with exponential backoff, until the next scheduled start
     /// time.
     #[prost(string, tag = "20")]
     pub schedule: ::prost::alloc::string::String,
     /// Specifies the time zone to be used in interpreting
-    /// [schedule][google.cloud.scheduler.v1.Job.schedule]. The value of this field must be a time
-    /// zone name from the [tz database](http://en.wikipedia.org/wiki/Tz_database).
+    /// \[schedule][google.cloud.scheduler.v1.Job.schedule\]. The value of this field must be a time
+    /// zone name from the [tz database](<http://en.wikipedia.org/wiki/Tz_database>).
     ///
     /// Note that some time zones include a provision for
     /// daylight savings time. The rules for daylight saving time are
@@ -421,11 +421,11 @@ pub struct Job {
     /// this deadline then the request is cancelled and the attempt is marked as a
     /// `DEADLINE_EXCEEDED` failure. The failed attempt can be viewed in
     /// execution logs. Cloud Scheduler will retry the job according
-    /// to the [RetryConfig][google.cloud.scheduler.v1.RetryConfig].
+    /// to the \[RetryConfig][google.cloud.scheduler.v1.RetryConfig\].
     ///
     /// The allowed duration for this deadline is:
-    /// * For [HTTP targets][google.cloud.scheduler.v1.Job.http_target], between 15 seconds and 30 minutes.
-    /// * For [App Engine HTTP targets][google.cloud.scheduler.v1.Job.app_engine_http_target], between 15
+    /// * For [HTTP targets]\[google.cloud.scheduler.v1.Job.http_target\], between 15 seconds and 30 minutes.
+    /// * For [App Engine HTTP targets]\[google.cloud.scheduler.v1.Job.app_engine_http_target\], between 15
     ///   seconds and 24 hours.
     #[prost(message, optional, tag = "22")]
     pub attempt_deadline: ::core::option::Option<::prost_types::Duration>,
@@ -447,14 +447,14 @@ pub mod job {
         Enabled = 1,
         /// The job is paused by the user. It will not execute. A user can
         /// intentionally pause the job using
-        /// [PauseJobRequest][google.cloud.scheduler.v1.PauseJobRequest].
+        /// \[PauseJobRequest][google.cloud.scheduler.v1.PauseJobRequest\].
         Paused = 2,
         /// The job is disabled by the system due to error. The user
         /// cannot directly set a job to be disabled.
         Disabled = 3,
-        /// The job state resulting from a failed [CloudScheduler.UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob]
+        /// The job state resulting from a failed \[CloudScheduler.UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob\]
         /// operation. To recover a job from this state, retry
-        /// [CloudScheduler.UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob] until a successful response is received.
+        /// \[CloudScheduler.UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob\] until a successful response is received.
         UpdateFailed = 4,
     }
     /// Required.
@@ -477,12 +477,12 @@ pub mod job {
 ///
 /// By default, if a job does not complete successfully (meaning that
 /// an acknowledgement is not received from the handler, then it will be retried
-/// with exponential backoff according to the settings in [RetryConfig][google.cloud.scheduler.v1.RetryConfig].
+/// with exponential backoff according to the settings in \[RetryConfig][google.cloud.scheduler.v1.RetryConfig\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RetryConfig {
     /// The number of attempts that the system will make to run a job using the
     /// exponential backoff procedure described by
-    /// [max_doublings][google.cloud.scheduler.v1.RetryConfig.max_doublings].
+    /// \[max_doublings][google.cloud.scheduler.v1.RetryConfig.max_doublings\].
     ///
     /// The default value of retry_count is zero.
     ///
@@ -500,7 +500,7 @@ pub struct RetryConfig {
     pub retry_count: i32,
     /// The time limit for retrying a failed job, measured from time when an
     /// execution was first attempted. If specified with
-    /// [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count], the job will be retried until both
+    /// \[retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count\], the job will be retried until both
     /// limits are reached.
     ///
     /// The default value for max_retry_duration is zero, which means retry
@@ -522,26 +522,26 @@ pub struct RetryConfig {
     /// The time between retries will double `max_doublings` times.
     ///
     /// A job's retry interval starts at
-    /// [min_backoff_duration][google.cloud.scheduler.v1.RetryConfig.min_backoff_duration], then doubles
+    /// \[min_backoff_duration][google.cloud.scheduler.v1.RetryConfig.min_backoff_duration\], then doubles
     /// `max_doublings` times, then increases linearly, and finally
     /// retries retries at intervals of
-    /// [max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration] up to
-    /// [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count] times.
+    /// \[max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration\] up to
+    /// \[retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count\] times.
     ///
-    /// For example, if [min_backoff_duration][google.cloud.scheduler.v1.RetryConfig.min_backoff_duration] is
-    /// 10s, [max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration] is 300s, and
+    /// For example, if \[min_backoff_duration][google.cloud.scheduler.v1.RetryConfig.min_backoff_duration\] is
+    /// 10s, \[max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration\] is 300s, and
     /// `max_doublings` is 3, then the a job will first be retried in 10s. The
     /// retry interval will double three times, and then increase linearly by
     /// 2^3 * 10s.  Finally, the job will retry at intervals of
-    /// [max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration] until the job has
-    /// been attempted [retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count] times. Thus, the
+    /// \[max_backoff_duration][google.cloud.scheduler.v1.RetryConfig.max_backoff_duration\] until the job has
+    /// been attempted \[retry_count][google.cloud.scheduler.v1.RetryConfig.retry_count\] times. Thus, the
     /// requests will retry at 10s, 20s, 40s, 80s, 160s, 240s, 300s, 300s, ....
     ///
     /// The default value of this field is 5.
     #[prost(int32, tag = "5")]
     pub max_doublings: i32,
 }
-/// Request message for listing jobs using [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
+/// Request message for listing jobs using \[ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListJobsRequest {
     /// Required. The location name. For example:
@@ -559,22 +559,22 @@ pub struct ListJobsRequest {
     /// A token identifying a page of results the server will return. To
     /// request the first page results, page_token must be empty. To
     /// request the next page of results, page_token must be the value of
-    /// [next_page_token][google.cloud.scheduler.v1.ListJobsResponse.next_page_token] returned from
-    /// the previous call to [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs]. It is an error to
-    /// switch the value of [filter][google.cloud.scheduler.v1.ListJobsRequest.filter] or
-    /// [order_by][google.cloud.scheduler.v1.ListJobsRequest.order_by] while iterating through pages.
+    /// \[next_page_token][google.cloud.scheduler.v1.ListJobsResponse.next_page_token\] returned from
+    /// the previous call to \[ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs\]. It is an error to
+    /// switch the value of \[filter][google.cloud.scheduler.v1.ListJobsRequest.filter\] or
+    /// \[order_by][google.cloud.scheduler.v1.ListJobsRequest.order_by\] while iterating through pages.
     #[prost(string, tag = "6")]
     pub page_token: ::prost::alloc::string::String,
 }
-/// Response message for listing jobs using [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
+/// Response message for listing jobs using \[ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListJobsResponse {
     /// The list of jobs.
     #[prost(message, repeated, tag = "1")]
     pub jobs: ::prost::alloc::vec::Vec<Job>,
     /// A token to retrieve next page of results. Pass this value in the
-    /// [page_token][google.cloud.scheduler.v1.ListJobsRequest.page_token] field in the subsequent call to
-    /// [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs] to retrieve the next page of results.
+    /// \[page_token][google.cloud.scheduler.v1.ListJobsRequest.page_token\] field in the subsequent call to
+    /// \[ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs\] to retrieve the next page of results.
     /// If this is empty it indicates that there are no more results
     /// through which to paginate.
     ///
@@ -582,7 +582,7 @@ pub struct ListJobsResponse {
     #[prost(string, tag = "2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
-/// Request message for [GetJob][google.cloud.scheduler.v1.CloudScheduler.GetJob].
+/// Request message for \[GetJob][google.cloud.scheduler.v1.CloudScheduler.GetJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetJobRequest {
     /// Required. The job name. For example:
@@ -590,7 +590,7 @@ pub struct GetJobRequest {
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
-/// Request message for [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob].
+/// Request message for \[CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateJobRequest {
     /// Required. The location name. For example:
@@ -598,17 +598,17 @@ pub struct CreateJobRequest {
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. The job to add. The user can optionally specify a name for the
-    /// job in [name][google.cloud.scheduler.v1.Job.name]. [name][google.cloud.scheduler.v1.Job.name] cannot be the same as an
+    /// job in \[name][google.cloud.scheduler.v1.Job.name\]. \[name][google.cloud.scheduler.v1.Job.name\] cannot be the same as an
     /// existing job. If a name is not specified then the system will
     /// generate a random unique name that will be returned
-    /// ([name][google.cloud.scheduler.v1.Job.name]) in the response.
+    /// (\[name][google.cloud.scheduler.v1.Job.name\]) in the response.
     #[prost(message, optional, tag = "2")]
     pub job: ::core::option::Option<Job>,
 }
-/// Request message for [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
+/// Request message for \[UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateJobRequest {
-    /// Required. The new job properties. [name][google.cloud.scheduler.v1.Job.name] must be specified.
+    /// Required. The new job properties. \[name][google.cloud.scheduler.v1.Job.name\] must be specified.
     ///
     /// Output only fields cannot be modified using UpdateJob.
     /// Any value specified for an output only field will be ignored.
@@ -619,7 +619,7 @@ pub struct UpdateJobRequest {
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// Request message for deleting a job using
-/// [DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob].
+/// \[DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteJobRequest {
     /// Required. The job name. For example:
@@ -627,7 +627,7 @@ pub struct DeleteJobRequest {
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
-/// Request message for [PauseJob][google.cloud.scheduler.v1.CloudScheduler.PauseJob].
+/// Request message for \[PauseJob][google.cloud.scheduler.v1.CloudScheduler.PauseJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PauseJobRequest {
     /// Required. The job name. For example:
@@ -635,7 +635,7 @@ pub struct PauseJobRequest {
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
 }
-/// Request message for [ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob].
+/// Request message for \[ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ResumeJobRequest {
     /// Required. The job name. For example:
@@ -644,7 +644,7 @@ pub struct ResumeJobRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// Request message for forcing a job to run now using
-/// [RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob].
+/// \[RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunJobRequest {
     /// Required. The job name. For example:
@@ -665,7 +665,7 @@ pub mod cloud_scheduler_client {
     impl<T> CloudSchedulerClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -678,7 +678,7 @@ pub mod cloud_scheduler_client {
             interceptor: F,
         ) -> CloudSchedulerClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
