@@ -1,10 +1,10 @@
 /// An individual endpoint that provides a
-/// [service][google.cloud.servicedirectory.v1.Service]. The service must
+/// \[service][google.cloud.servicedirectory.v1.Service\]. The service must
 /// already exist to create an endpoint.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Endpoint {
     /// Immutable. The resource name for the endpoint in the format
-    /// 'projects/*/locations/*/namespaces/*/services/*/endpoints/*'.
+    /// `projects/*/locations/*/namespaces/*/services/*/endpoints/*`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// Optional. An IPv4 or IPv6 address. Service Directory will reject bad
@@ -12,8 +12,8 @@ pub struct Endpoint {
     ///   "8.8.8"
     ///   "8.8.8.8:53"
     ///   "test:bad:address"
-    ///   "[::1]"
-    ///   "[::1]:8080"
+    ///   "\[::1\]"
+    ///   "\[::1\]:8080"
     /// Limited to 45 characters.
     #[prost(string, tag = "2")]
     pub address: ::prost::alloc::string::String,
@@ -28,7 +28,7 @@ pub struct Endpoint {
     ///  - Valid annotation keys have two segments: an optional prefix and name,
     ///    separated by a slash (/). The name segment is required and must be 63
     ///    characters or less, beginning and ending with an alphanumeric character
-    ///    ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and
+    ///    (\[a-z0-9A-Z\]) with dashes (-), underscores (_), dots (.), and
     ///    alphanumerics between. The prefix is optional. If specified, the prefix
     ///    must be a DNS subdomain: a series of DNS labels separated by dots (.),
     ///    not longer than 253 characters in total, followed by a slash (/).
@@ -46,12 +46,12 @@ pub struct Endpoint {
 }
 /// An individual service. A service contains a name and optional metadata.
 /// A service must exist before
-/// [endpoints][google.cloud.servicedirectory.v1.Endpoint] can be
+/// \[endpoints][google.cloud.servicedirectory.v1.Endpoint\] can be
 /// added to it.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Service {
     /// Immutable. The resource name for the service in the format
-    /// 'projects/*/locations/*/namespaces/*/services/*'.
+    /// `projects/*/locations/*/namespaces/*/services/*`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// Optional. Annotations for the service. This data can be consumed by service
@@ -63,7 +63,7 @@ pub struct Service {
     ///  - Valid annotation keys have two segments: an optional prefix and name,
     ///    separated by a slash (/). The name segment is required and must be 63
     ///    characters or less, beginning and ending with an alphanumeric character
-    ///    ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and
+    ///    (\[a-z0-9A-Z\]) with dashes (-), underscores (_), dots (.), and
     ///    alphanumerics between. The prefix is optional. If specified, the prefix
     ///    must be a DNS subdomain: a series of DNS labels separated by dots (.),
     ///    not longer than 253 characters in total, followed by a slash (/).
@@ -85,7 +85,7 @@ pub struct Service {
     pub endpoints: ::prost::alloc::vec::Vec<Endpoint>,
 }
 /// The request message for
-/// [LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService].
+/// \[LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService\].
 /// Looks up a service by its name, returns the service and its endpoints.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ResolveServiceRequest {
@@ -119,7 +119,7 @@ pub struct ResolveServiceRequest {
     pub endpoint_filter: ::prost::alloc::string::String,
 }
 /// The response message for
-/// [LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService].
+/// \[LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ResolveServiceResponse {
     #[prost(message, optional, tag = "1")]
@@ -137,7 +137,7 @@ pub mod lookup_service_client {
     impl<T> LookupServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -150,7 +150,7 @@ pub mod lookup_service_client {
             interceptor: F,
         ) -> LookupServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -196,13 +196,13 @@ pub mod lookup_service_client {
         }
     }
 }
-/// A container for [services][google.cloud.servicedirectory.v1.Service].
+/// A container for \[services][google.cloud.servicedirectory.v1.Service\].
 /// Namespaces allow administrators to group services together and define
 /// permissions for a collection of services.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Namespace {
     /// Immutable. The resource name for the namespace in the format
-    /// 'projects/*/locations/*/namespaces/*'.
+    /// `projects/*/locations/*/namespaces/*`.
     #[prost(string, tag = "1")]
     pub name: ::prost::alloc::string::String,
     /// Optional. Resource labels associated with this Namespace.
@@ -213,7 +213,7 @@ pub struct Namespace {
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
 /// The request message for
-/// [RegistrationService.CreateNamespace][google.cloud.servicedirectory.v1.RegistrationService.CreateNamespace].
+/// \[RegistrationService.CreateNamespace][google.cloud.servicedirectory.v1.RegistrationService.CreateNamespace\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateNamespaceRequest {
     /// Required. The resource name of the project and location the namespace
@@ -221,9 +221,9 @@ pub struct CreateNamespaceRequest {
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. The Resource ID must be 1-63 characters long, and comply with
-    /// <a href="https://www.ietf.org/rfc/rfc1035.txt" target="_blank">RFC1035</a>.
+    /// <a href="<https://www.ietf.org/rfc/rfc1035.txt"> target="_blank">RFC1035</a>.
     /// Specifically, the name must be 1-63 characters long and match the regular
-    /// expression `[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?` which means the first
+    /// expression `\[a-z](?:[-a-z0-9]{0,61}[a-z0-9\])?` which means the first
     /// character must be a lowercase letter, and all following characters must
     /// be a dash, lowercase letter, or digit, except the last character, which
     /// cannot be a dash.
@@ -234,7 +234,7 @@ pub struct CreateNamespaceRequest {
     pub namespace: ::core::option::Option<Namespace>,
 }
 /// The request message for
-/// [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces].
+/// \[RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListNamespacesRequest {
     /// Required. The resource name of the project and location whose namespaces
@@ -286,7 +286,7 @@ pub struct ListNamespacesRequest {
     pub order_by: ::prost::alloc::string::String,
 }
 /// The response message for
-/// [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces].
+/// \[RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListNamespacesResponse {
     /// The list of namespaces.
@@ -298,7 +298,7 @@ pub struct ListNamespacesResponse {
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.GetNamespace][google.cloud.servicedirectory.v1.RegistrationService.GetNamespace].
+/// \[RegistrationService.GetNamespace][google.cloud.servicedirectory.v1.RegistrationService.GetNamespace\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetNamespaceRequest {
     /// Required. The name of the namespace to retrieve.
@@ -306,7 +306,7 @@ pub struct GetNamespaceRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.UpdateNamespace][google.cloud.servicedirectory.v1.RegistrationService.UpdateNamespace].
+/// \[RegistrationService.UpdateNamespace][google.cloud.servicedirectory.v1.RegistrationService.UpdateNamespace\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateNamespaceRequest {
     /// Required. The updated namespace.
@@ -317,7 +317,7 @@ pub struct UpdateNamespaceRequest {
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// The request message for
-/// [RegistrationService.DeleteNamespace][google.cloud.servicedirectory.v1.RegistrationService.DeleteNamespace].
+/// \[RegistrationService.DeleteNamespace][google.cloud.servicedirectory.v1.RegistrationService.DeleteNamespace\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteNamespaceRequest {
     /// Required. The name of the namespace to delete.
@@ -325,16 +325,16 @@ pub struct DeleteNamespaceRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.CreateService][google.cloud.servicedirectory.v1.RegistrationService.CreateService].
+/// \[RegistrationService.CreateService][google.cloud.servicedirectory.v1.RegistrationService.CreateService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateServiceRequest {
     /// Required. The resource name of the namespace this service will belong to.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. The Resource ID must be 1-63 characters long, and comply with
-    /// <a href="https://www.ietf.org/rfc/rfc1035.txt" target="_blank">RFC1035</a>.
+    /// <a href="<https://www.ietf.org/rfc/rfc1035.txt"> target="_blank">RFC1035</a>.
     /// Specifically, the name must be 1-63 characters long and match the regular
-    /// expression `[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?` which means the first
+    /// expression `\[a-z](?:[-a-z0-9]{0,61}[a-z0-9\])?` which means the first
     /// character must be a lowercase letter, and all following characters must
     /// be a dash, lowercase letter, or digit, except the last character, which
     /// cannot be a dash.
@@ -345,7 +345,7 @@ pub struct CreateServiceRequest {
     pub service: ::core::option::Option<Service>,
 }
 /// The request message for
-/// [RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices].
+/// \[RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListServicesRequest {
     /// Required. The resource name of the namespace whose services we'd
@@ -389,7 +389,7 @@ pub struct ListServicesRequest {
     pub order_by: ::prost::alloc::string::String,
 }
 /// The response message for
-/// [RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices].
+/// \[RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListServicesResponse {
     /// The list of services.
@@ -401,7 +401,7 @@ pub struct ListServicesResponse {
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.GetService][google.cloud.servicedirectory.v1.RegistrationService.GetService].
+/// \[RegistrationService.GetService][google.cloud.servicedirectory.v1.RegistrationService.GetService\].
 /// This should not be used for looking up a service. Insead, use the `resolve`
 /// method as it will contain all endpoints and associated metadata.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -411,7 +411,7 @@ pub struct GetServiceRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.UpdateService][google.cloud.servicedirectory.v1.RegistrationService.UpdateService].
+/// \[RegistrationService.UpdateService][google.cloud.servicedirectory.v1.RegistrationService.UpdateService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateServiceRequest {
     /// Required. The updated service.
@@ -422,7 +422,7 @@ pub struct UpdateServiceRequest {
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// The request message for
-/// [RegistrationService.DeleteService][google.cloud.servicedirectory.v1.RegistrationService.DeleteService].
+/// \[RegistrationService.DeleteService][google.cloud.servicedirectory.v1.RegistrationService.DeleteService\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteServiceRequest {
     /// Required. The name of the service to delete.
@@ -430,16 +430,16 @@ pub struct DeleteServiceRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.CreateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.CreateEndpoint].
+/// \[RegistrationService.CreateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.CreateEndpoint\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateEndpointRequest {
     /// Required. The resource name of the service that this endpoint provides.
     #[prost(string, tag = "1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. The Resource ID must be 1-63 characters long, and comply with
-    /// <a href="https://www.ietf.org/rfc/rfc1035.txt" target="_blank">RFC1035</a>.
+    /// <a href="<https://www.ietf.org/rfc/rfc1035.txt"> target="_blank">RFC1035</a>.
     /// Specifically, the name must be 1-63 characters long and match the regular
-    /// expression `[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?` which means the first
+    /// expression `\[a-z](?:[-a-z0-9]{0,61}[a-z0-9\])?` which means the first
     /// character must be a lowercase letter, and all following characters must
     /// be a dash, lowercase letter, or digit, except the last character, which
     /// cannot be a dash.
@@ -450,7 +450,7 @@ pub struct CreateEndpointRequest {
     pub endpoint: ::core::option::Option<Endpoint>,
 }
 /// The request message for
-/// [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints].
+/// \[RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListEndpointsRequest {
     /// Required. The resource name of the service whose endpoints we'd like to
@@ -496,7 +496,7 @@ pub struct ListEndpointsRequest {
     pub order_by: ::prost::alloc::string::String,
 }
 /// The response message for
-/// [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints].
+/// \[RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListEndpointsResponse {
     /// The list of endpoints.
@@ -508,7 +508,7 @@ pub struct ListEndpointsResponse {
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.GetEndpoint][google.cloud.servicedirectory.v1.RegistrationService.GetEndpoint].
+/// \[RegistrationService.GetEndpoint][google.cloud.servicedirectory.v1.RegistrationService.GetEndpoint\].
 /// This should not be used to lookup endpoints at runtime. Instead, use
 /// the `resolve` method.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -518,7 +518,7 @@ pub struct GetEndpointRequest {
     pub name: ::prost::alloc::string::String,
 }
 /// The request message for
-/// [RegistrationService.UpdateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.UpdateEndpoint].
+/// \[RegistrationService.UpdateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.UpdateEndpoint\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateEndpointRequest {
     /// Required. The updated endpoint.
@@ -529,7 +529,7 @@ pub struct UpdateEndpointRequest {
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// The request message for
-/// [RegistrationService.DeleteEndpoint][google.cloud.servicedirectory.v1.RegistrationService.DeleteEndpoint].
+/// \[RegistrationService.DeleteEndpoint][google.cloud.servicedirectory.v1.RegistrationService.DeleteEndpoint\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteEndpointRequest {
     /// Required. The name of the endpoint to delete.
@@ -562,7 +562,7 @@ pub mod registration_service_client {
     impl<T> RegistrationServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -575,7 +575,7 @@ pub mod registration_service_client {
             interceptor: F,
         ) -> RegistrationServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
