@@ -53,7 +53,7 @@ pub mod phrase_set {
     /// to improve the accuracy for specific words and phrases, for example, if
     /// specific commands are typically spoken by the user. This can also be used
     /// to add additional words to the vocabulary of the recognizer. See
-    /// [usage limits](https://cloud.google.com/speech-to-text/quotas#content).
+    /// [usage limits](<https://cloud.google.com/speech-to-text/quotas#content>).
     ///
     /// List items can also include pre-built or custom classes containing groups
     /// of words that represent common concepts that occur in natural language. For
@@ -104,6 +104,35 @@ pub struct SpeechAdaptation {
     #[prost(message, repeated, tag = "3")]
     pub custom_classes: ::prost::alloc::vec::Vec<CustomClass>,
 }
+/// Transcription normalization configuration. Use transcription normalization
+/// to automatically replace parts of the transcript with phrases of your
+/// choosing. For StreamingRecognize, this normalization only applies to stable
+/// partial transcripts (stability > 0.8) and final transcripts.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct TranscriptNormalization {
+    /// A list of replacement entries. We will perform replacement with one entry
+    /// at a time. For example, the second entry in ["cat" => "dog", "mountain cat"
+    /// => "mountain dog"] will never be applied because we will always process the
+    /// first entry before it. At most 100 entries.
+    #[prost(message, repeated, tag = "1")]
+    pub entries: ::prost::alloc::vec::Vec<transcript_normalization::Entry>,
+}
+/// Nested message and enum types in `TranscriptNormalization`.
+pub mod transcript_normalization {
+    /// A single replacement configuration.
+    #[derive(Clone, PartialEq, ::prost::Message)]
+    pub struct Entry {
+        /// What to replace. Max length is 100 characters.
+        #[prost(string, tag = "1")]
+        pub search: ::prost::alloc::string::String,
+        /// What to replace with. Max length is 100 characters.
+        #[prost(string, tag = "2")]
+        pub replace: ::prost::alloc::string::String,
+        /// Whether the search is case sensitive.
+        #[prost(bool, tag = "3")]
+        pub case_sensitive: bool,
+    }
+}
 /// The top-level message sent by the client for the `Recognize` method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RecognizeRequest {
@@ -175,7 +204,7 @@ pub mod streaming_recognize_request {
         /// `audio_content` data. The audio bytes must be encoded as specified in
         /// `RecognitionConfig`. Note: as with all bytes fields, proto buffers use a
         /// pure binary representation (not base64). See
-        /// [content limits](https://cloud.google.com/speech-to-text/quotas#content).
+        /// [content limits](<https://cloud.google.com/speech-to-text/quotas#content>).
         #[prost(bytes, tag = "2")]
         AudioContent(::prost::alloc::vec::Vec<u8>),
     }
@@ -201,7 +230,7 @@ pub struct StreamingRecognitionConfig {
     /// `true`.
     ///
     /// The `single_utterance` field can only be used with specified models,
-    /// otherwise an error is thrown. The `model` field in [`RecognitionConfig`][]
+    /// otherwise an error is thrown. The `model` field in \[`RecognitionConfig`][\]
     /// must be set to:
     ///
     /// * `command_and_search`
@@ -224,7 +253,7 @@ pub struct StreamingRecognitionConfig {
 pub struct RecognitionConfig {
     /// Encoding of audio data sent in all `RecognitionAudio` messages.
     /// This field is optional for `FLAC` and `WAV` audio files and required
-    /// for all other audio formats. For details, see [AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding].
+    /// for all other audio formats. For details, see \[AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding\].
     #[prost(enumeration = "recognition_config::AudioEncoding", tag = "1")]
     pub encoding: i32,
     /// Sample rate in Hertz of the audio data sent in all
@@ -233,7 +262,7 @@ pub struct RecognitionConfig {
     /// source to 16000 Hz. If that's not possible, use the native sample rate of
     /// the audio source (instead of re-sampling).
     /// This field is optional for FLAC and WAV audio files, but is
-    /// required for all other audio formats. For details, see [AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding].
+    /// required for all other audio formats. For details, see \[AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding\].
     #[prost(int32, tag = "2")]
     pub sample_rate_hertz: i32,
     /// The number of channels in the input audio data.
@@ -256,18 +285,18 @@ pub struct RecognitionConfig {
     #[prost(bool, tag = "12")]
     pub enable_separate_recognition_per_channel: bool,
     /// Required. The language of the supplied audio as a
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag.
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag.
     /// Example: "en-US".
     /// See [Language
-    /// Support](https://cloud.google.com/speech-to-text/docs/languages) for a list
+    /// Support](<https://cloud.google.com/speech-to-text/docs/languages>) for a list
     /// of the currently supported language codes.
     #[prost(string, tag = "3")]
     pub language_code: ::prost::alloc::string::String,
     /// A list of up to 3 additional
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tags,
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tags,
     /// listing possible alternative languages of the supplied audio.
     /// See [Language
-    /// Support](https://cloud.google.com/speech-to-text/docs/languages) for a list
+    /// Support](<https://cloud.google.com/speech-to-text/docs/languages>) for a list
     /// of the currently supported language codes. If alternative languages are
     /// listed, recognition result will contain recognition in the most likely
     /// language detected including the main language_code. The recognition result
@@ -294,15 +323,21 @@ pub struct RecognitionConfig {
     /// Speech adaptation configuration improves the accuracy of speech
     /// recognition. When speech adaptation is set it supersedes the
     /// `speech_contexts` field. For more information, see the [speech
-    /// adaptation](https://cloud.google.com/speech-to-text/docs/adaptation)
+    /// adaptation](<https://cloud.google.com/speech-to-text/docs/adaptation>)
     /// documentation.
     #[prost(message, optional, tag = "20")]
     pub adaptation: ::core::option::Option<SpeechAdaptation>,
-    /// Array of [SpeechContext][google.cloud.speech.v1p1beta1.SpeechContext].
+    /// Use transcription normalization to automatically replace parts of the
+    /// transcript with phrases of your choosing. For StreamingRecognize, this
+    /// normalization only applies to stable partial transcripts (stability > 0.8)
+    /// and final transcripts.
+    #[prost(message, optional, tag = "24")]
+    pub transcript_normalization: ::core::option::Option<TranscriptNormalization>,
+    /// Array of \[SpeechContext][google.cloud.speech.v1p1beta1.SpeechContext\].
     /// A means to provide context to assist the speech recognition. For more
     /// information, see
     /// [speech
-    /// adaptation](https://cloud.google.com/speech-to-text/docs/adaptation).
+    /// adaptation](<https://cloud.google.com/speech-to-text/docs/adaptation>).
     #[prost(message, repeated, tag = "6")]
     pub speech_contexts: ::prost::alloc::vec::Vec<SpeechContext>,
     /// If `true`, the top result includes a list of words and
@@ -327,7 +362,7 @@ pub struct RecognitionConfig {
     /// e.g. command_and_search will enable spoken punctuation by default
     /// If 'true', replaces spoken punctuation with the corresponding symbols in
     /// the request. For example, "how are you question mark" becomes "how are
-    /// you?". See https://cloud.google.com/speech-to-text/docs/spoken-punctuation
+    /// you?". See <https://cloud.google.com/speech-to-text/docs/spoken-punctuation>
     /// for support. If 'false', spoken punctuation is not replaced.
     #[prost(message, optional, tag = "22")]
     pub enable_spoken_punctuation: ::core::option::Option<bool>,
@@ -432,7 +467,7 @@ pub mod recognition_config {
     /// an `AudioEncoding` when you send  send `FLAC` or `WAV` audio, the
     /// encoding configuration must match the encoding described in the audio
     /// header; otherwise the request returns an
-    /// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT] error code.
+    /// \[google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT\] error code.
     #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
     #[repr(i32)]
     pub enum AudioEncoding {
@@ -454,16 +489,16 @@ pub mod recognition_config {
         /// Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.
         AmrWb = 5,
         /// Opus encoded audio frames in Ogg container
-        /// ([OggOpus](https://wiki.xiph.org/OggOpus)).
+        /// (\[OggOpus\](<https://wiki.xiph.org/OggOpus>)).
         /// `sample_rate_hertz` must be one of 8000, 12000, 16000, 24000, or 48000.
         OggOpus = 6,
         /// Although the use of lossy encodings is not recommended, if a very low
         /// bitrate encoding is required, `OGG_OPUS` is highly preferred over
-        /// Speex encoding. The [Speex](https://speex.org/)  encoding supported by
+        /// Speex encoding. The \[Speex\](<https://speex.org/>)  encoding supported by
         /// Cloud Speech API has a header byte in each block, as in MIME type
         /// `audio/x-speex-with-header-byte`.
         /// It is a variant of the RTP Speex encoding defined in
-        /// [RFC 5574](https://tools.ietf.org/html/rfc5574).
+        /// [RFC 5574](<https://tools.ietf.org/html/rfc5574>).
         /// The stream is a sequence of blocks, one block per RTP packet. Each block
         /// starts with a byte containing the length of the block, in bytes, followed
         /// by one or more frames of Speex data, padded to an integral number of
@@ -477,7 +512,7 @@ pub mod recognition_config {
         /// sample rate of the file being used.
         Mp3 = 8,
         /// Opus encoded audio frames in WebM container
-        /// ([OggOpus](https://wiki.xiph.org/OggOpus)). This is a Beta features and
+        /// (\[OggOpus\](<https://wiki.xiph.org/OggOpus>)). This is a Beta features and
         /// only available in v1p1beta1. `sample_rate_hertz` must be one of 8000,
         /// 12000, 16000, 24000, or 48000.
         WebmOpus = 9,
@@ -515,7 +550,7 @@ pub struct RecognitionMetadata {
     /// The industry vertical to which this speech recognition request most
     /// closely applies. This is most indicative of the topics contained
     /// in the audio.  Use the 6-digit NAICS code to identify the industry
-    /// vertical - see https://www.naics.com/search/.
+    /// vertical - see <https://www.naics.com/search/.>
     #[prost(uint32, tag = "3")]
     pub industry_naics_code_of_audio: u32,
     /// The audio type that most closely describes the audio being recognized.
@@ -535,7 +570,7 @@ pub struct RecognitionMetadata {
     /// Mime type of the original audio file.  For example `audio/m4a`,
     /// `audio/x-alaw-basic`, `audio/mp3`, `audio/3gpp`.
     /// A list of possible audio mime types is maintained at
-    /// http://www.iana.org/assignments/media-types/media-types.xhtml#audio
+    /// <http://www.iana.org/assignments/media-types/media-types.xhtml#audio>
     #[prost(string, tag = "8")]
     pub original_mime_type: ::prost::alloc::string::String,
     /// Obfuscated (privacy-protected) ID of the user, to identify number of
@@ -636,7 +671,7 @@ pub struct SpeechContext {
     /// to improve the accuracy for specific words and phrases, for example, if
     /// specific commands are typically spoken by the user. This can also be used
     /// to add additional words to the vocabulary of the recognizer. See
-    /// [usage limits](https://cloud.google.com/speech-to-text/quotas#content).
+    /// [usage limits](<https://cloud.google.com/speech-to-text/quotas#content>).
     ///
     /// List items can also be set to classes for groups of words that represent
     /// common concepts that occur in natural language. For example, rather than
@@ -658,8 +693,8 @@ pub struct SpeechContext {
 }
 /// Contains audio data in the encoding specified in the `RecognitionConfig`.
 /// Either `content` or `uri` must be supplied. Supplying both or neither
-/// returns [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]. See
-/// [content limits](https://cloud.google.com/speech-to-text/quotas#content).
+/// returns \[google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT\]. See
+/// [content limits](<https://cloud.google.com/speech-to-text/quotas#content>).
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RecognitionAudio {
     /// The audio source, which is either inline content or a Google Cloud
@@ -683,8 +718,8 @@ pub mod recognition_audio {
         /// Currently, only Google Cloud Storage URIs are
         /// supported, which must be specified in the following format:
         /// `gs://bucket_name/object_name` (other URI formats return
-        /// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]). For more information, see
-        /// [Request URIs](https://cloud.google.com/storage/docs/reference-uris).
+        /// \[google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT\]). For more information, see
+        /// [Request URIs](<https://cloud.google.com/storage/docs/reference-uris>).
         #[prost(string, tag = "2")]
         Uri(::prost::alloc::string::String),
     }
@@ -797,7 +832,7 @@ pub struct LongRunningRecognizeMetadata {
 ///     one or more (repeated) `results`.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct StreamingRecognizeResponse {
-    /// If set, returns a [google.rpc.Status][google.rpc.Status] message that
+    /// If set, returns a \[google.rpc.Status][google.rpc.Status\] message that
     /// specifies the error for the operation.
     #[prost(message, optional, tag = "1")]
     pub error: ::core::option::Option<super::super::super::rpc::Status>,
@@ -808,10 +843,7 @@ pub struct StreamingRecognizeResponse {
     #[prost(message, repeated, tag = "2")]
     pub results: ::prost::alloc::vec::Vec<StreamingRecognitionResult>,
     /// Indicates the type of speech event.
-    #[prost(
-        enumeration = "streaming_recognize_response::SpeechEventType",
-        tag = "4"
-    )]
+    #[prost(enumeration = "streaming_recognize_response::SpeechEventType", tag = "4")]
     pub speech_event_type: i32,
     /// When available, billed audio seconds for the stream.
     /// Set only if this is the last response in the stream.
@@ -869,7 +901,7 @@ pub struct StreamingRecognitionResult {
     /// For audio_channel_count = N, its output values can range from '1' to 'N'.
     #[prost(int32, tag = "5")]
     pub channel_tag: i32,
-    /// Output only. The [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag
+    /// Output only. The \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag
     /// of the language in this result. This language code was detected to have
     /// the most likelihood of being spoken in the audio.
     #[prost(string, tag = "6")]
@@ -889,7 +921,7 @@ pub struct SpeechRecognitionResult {
     /// For audio_channel_count = N, its output values can range from '1' to 'N'.
     #[prost(int32, tag = "2")]
     pub channel_tag: i32,
-    /// Output only. The [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag
+    /// Output only. The \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag
     /// of the language in this result. This language code was detected to have
     /// the most likelihood of being spoken in the audio.
     #[prost(string, tag = "5")]
@@ -967,7 +999,7 @@ pub mod speech_client {
     impl<T> SpeechClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -980,7 +1012,7 @@ pub mod speech_client {
             interceptor: F,
         ) -> SpeechClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -1067,9 +1099,7 @@ pub mod speech_client {
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.speech.v1p1beta1.Speech/StreamingRecognize",
             );
-            self.inner
-                .streaming(request.into_streaming_request(), path, codec)
-                .await
+            self.inner.streaming(request.into_streaming_request(), path, codec).await
         }
     }
 }
@@ -1085,7 +1115,7 @@ pub struct CreatePhraseSetRequest {
     /// component of the phrase set's resource name.
     ///
     /// This value should be 4-63 characters, and valid characters
-    /// are /[a-z][0-9]-/.
+    /// are /\[a-z][0-9\]-/.
     #[prost(string, tag = "2")]
     pub phrase_set_id: ::prost::alloc::string::String,
     /// Required. The phrase set to create.
@@ -1169,7 +1199,7 @@ pub struct CreateCustomClassRequest {
     /// component of the custom class' resource name.
     ///
     /// This value should be 4-63 characters, and valid characters
-    /// are /[a-z][0-9]-/.
+    /// are /\[a-z][0-9\]-/.
     #[prost(string, tag = "2")]
     pub custom_class_id: ::prost::alloc::string::String,
     /// Required. The custom class to create.
@@ -1253,7 +1283,7 @@ pub mod adaptation_client {
     impl<T> AdaptationClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -1266,7 +1296,7 @@ pub mod adaptation_client {
             interceptor: F,
         ) -> AdaptationClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
