@@ -2,14 +2,14 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListVoicesRequest {
     /// Optional. Recommended.
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag.
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag.
     /// If not specified, the API will return all supported voices.
     /// If specified, the ListVoices call will only return voices that can be used
-    /// to synthesize this language_code. E.g. when specifying "en-NZ", you will
-    /// get supported "en-NZ" voices; when specifying "no", you will get supported
-    /// "no-\*" (Norwegian) and "nb-\*" (Norwegian Bokmal) voices; specifying "zh"
-    /// will also get supported "cmn-\*" voices; specifying "zh-hk" will also get
-    /// supported "yue-hk" voices.
+    /// to synthesize this language_code. E.g. when specifying `"en-NZ"`, you will
+    /// get supported `"en-NZ"` voices; when specifying `"no"`, you will get
+    /// supported `"no-\*"` (Norwegian) and `"nb-\*"` (Norwegian Bokmal) voices;
+    /// specifying `"zh"` will also get supported `"cmn-\*"` voices; specifying
+    /// `"zh-hk"` will also get supported `"yue-hk"` voices.
     #[prost(string, tag = "1")]
     pub language_code: ::prost::alloc::string::String,
 }
@@ -24,7 +24,7 @@ pub struct ListVoicesResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Voice {
     /// The languages that this voice supports, expressed as
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tags (e.g.
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tags (e.g.
     /// "en-US", "es-419", "cmn-tw").
     #[prost(string, repeated, tag = "1")]
     pub language_codes: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
@@ -51,11 +51,7 @@ pub struct SynthesizeSpeechRequest {
     #[prost(message, optional, tag = "3")]
     pub audio_config: ::core::option::Option<AudioConfig>,
     /// Whether and what timepoints are returned in the response.
-    #[prost(
-        enumeration = "synthesize_speech_request::TimepointType",
-        repeated,
-        tag = "4"
-    )]
+    #[prost(enumeration = "synthesize_speech_request::TimepointType", repeated, tag = "4")]
     pub enable_time_pointing: ::prost::alloc::vec::Vec<i32>,
 }
 /// Nested message and enum types in `SynthesizeSpeechRequest`.
@@ -72,7 +68,7 @@ pub mod synthesize_speech_request {
 }
 /// Contains text input to be synthesized. Either `text` or `ssml` must be
 /// supplied. Supplying both or neither returns
-/// [google.rpc.Code.INVALID_ARGUMENT][]. The input size is limited to 5000
+/// \[google.rpc.Code.INVALID_ARGUMENT][\]. The input size is limited to 5000
 /// characters.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SynthesisInput {
@@ -90,8 +86,8 @@ pub mod synthesis_input {
         Text(::prost::alloc::string::String),
         /// The SSML document to be synthesized. The SSML document must be valid
         /// and well-formed. Otherwise the RPC will fail and return
-        /// [google.rpc.Code.INVALID_ARGUMENT][]. For more information, see
-        /// [SSML](https://cloud.google.com/text-to-speech/docs/ssml).
+        /// \[google.rpc.Code.INVALID_ARGUMENT][\]. For more information, see
+        /// \[SSML\](<https://cloud.google.com/text-to-speech/docs/ssml>).
         #[prost(string, tag = "2")]
         Ssml(::prost::alloc::string::String),
     }
@@ -100,7 +96,7 @@ pub mod synthesis_input {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct VoiceSelectionParams {
     /// Required. The language (and potentially also the region) of the voice expressed as a
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag, e.g.
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag, e.g.
     /// "en-US". This should not include a script tag (e.g. use
     /// "cmn-cn" rather than "cmn-Hant-cn"), because the script will be inferred
     /// from the input provided in the SynthesisInput.  The TTS service
@@ -123,6 +119,11 @@ pub struct VoiceSelectionParams {
     /// substitute a voice with a different gender rather than failing the request.
     #[prost(enumeration = "SsmlVoiceGender", tag = "3")]
     pub ssml_gender: i32,
+    /// The configuration for a custom voice. If \[CustomVoiceParams.model\] is set,
+    /// the service will choose the custom voice matching the specified
+    /// configuration.
+    #[prost(message, optional, tag = "4")]
+    pub custom_voice: ::core::option::Option<CustomVoiceParams>,
 }
 /// Description of audio data to be synthesized.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -157,18 +158,47 @@ pub struct AudioConfig {
     /// converting to the desired sample rate (which might result in worse audio
     /// quality), unless the specified sample rate is not supported for the
     /// encoding chosen, in which case it will fail the request and return
-    /// [google.rpc.Code.INVALID_ARGUMENT][].
+    /// \[google.rpc.Code.INVALID_ARGUMENT][\].
     #[prost(int32, tag = "5")]
     pub sample_rate_hertz: i32,
     /// Optional. Input only. An identifier which selects 'audio effects' profiles
     /// that are applied on (post synthesized) text to speech. Effects are applied
     /// on top of each other in the order they are given. See
     /// [audio
-    /// profiles](https://cloud.google.com/text-to-speech/docs/audio-profiles) for
+    /// profiles](<https://cloud.google.com/text-to-speech/docs/audio-profiles>) for
     /// current supported profile ids.
     #[prost(string, repeated, tag = "6")]
     pub effects_profile_id: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
+/// Description of the custom voice to be synthesized.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct CustomVoiceParams {
+    /// Required. The name of the AutoML model that synthesizes the custom voice.
+    #[prost(string, tag = "1")]
+    pub model: ::prost::alloc::string::String,
+    /// Optional. The usage of the synthesized audio to be reported.
+    #[prost(enumeration = "custom_voice_params::ReportedUsage", tag = "3")]
+    pub reported_usage: i32,
+}
+/// Nested message and enum types in `CustomVoiceParams`.
+pub mod custom_voice_params {
+    /// The usage of the synthesized audio. You must report your honest and
+    /// correct usage of the service as it's regulated by contract and will cause
+    /// significant difference in billing.
+    #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
+    #[repr(i32)]
+    pub enum ReportedUsage {
+        /// Request with reported usage unspecified will be rejected.
+        Unspecified = 0,
+        /// For scenarios where the synthesized audio is not downloadable and can
+        /// only be used once. For example, real-time request in IVR system.
+        Realtime = 1,
+        /// For scenarios where the synthesized audio is downloadable and can be
+        /// reused. For example, the synthesized audio is downloaded, stored in
+        /// customer service system and played repeatedly.
+        Offline = 2,
+    }
+}
 /// The message returned to the client by the `SynthesizeSpeech` method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SynthesizeSpeechResponse {
@@ -199,7 +229,7 @@ pub struct Timepoint {
     pub time_seconds: f64,
 }
 /// Gender of the voice as described in
-/// [SSML voice element](https://www.w3.org/TR/speech-synthesis11/#edef_voice).
+/// [SSML voice element](<https://www.w3.org/TR/speech-synthesis11/#edef_voice>).
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
 #[repr(i32)]
 pub enum SsmlVoiceGender {
@@ -221,7 +251,7 @@ pub enum SsmlVoiceGender {
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
 #[repr(i32)]
 pub enum AudioEncoding {
-    /// Not specified. Will return result [google.rpc.Code.INVALID_ARGUMENT][].
+    /// Not specified. Will return result \[google.rpc.Code.INVALID_ARGUMENT][\].
     Unspecified = 0,
     /// Uncompressed 16-bit signed little-endian samples (Linear PCM).
     /// Audio content returned as LINEAR16 also contains a WAV header.
@@ -254,7 +284,7 @@ pub mod text_to_speech_client {
     impl<T> TextToSpeechClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -267,7 +297,7 @@ pub mod text_to_speech_client {
             interceptor: F,
         ) -> TextToSpeechClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
