@@ -60,14 +60,13 @@ pub struct TranslateTextRequest {
     ///
     /// - General (built-in) models:
     ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/nmt`,
-    ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/base`
     ///
     ///
     /// For global (non-regionalized) requests, use `location-id` `global`.
     /// For example,
     /// `projects/{project-number-or-id}/locations/global/models/general/nmt`.
     ///
-    /// If missing, the system decides which google base model to use.
+    /// If not provided, the default Google model (NMT) will be used
     #[prost(string, tag = "6")]
     pub model: ::prost::alloc::string::String,
     /// Optional. Glossary to be applied. The glossary must be
@@ -82,7 +81,7 @@ pub struct TranslateTextRequest {
     /// characters, underscores and dashes. International characters are allowed.
     /// Label values are optional. Label keys must start with a letter.
     ///
-    /// See https://cloud.google.com/translate/docs/labels for more information.
+    /// See <https://cloud.google.com/translate/docs/labels> for more information.
     #[prost(map = "string, string", tag = "10")]
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
@@ -91,14 +90,14 @@ pub struct TranslateTextRequest {
 pub struct TranslateTextResponse {
     /// Text translation responses with no glossary applied.
     /// This field has the same length as
-    /// [`contents`][google.cloud.translation.v3beta1.TranslateTextRequest.contents].
+    /// \[`contents`][google.cloud.translation.v3beta1.TranslateTextRequest.contents\].
     #[prost(message, repeated, tag = "1")]
     pub translations: ::prost::alloc::vec::Vec<Translation>,
     /// Text translation responses if a glossary is provided in the request.
     /// This can be the same as
-    /// [`translations`][google.cloud.translation.v3beta1.TranslateTextResponse.translations]
+    /// \[`translations`][google.cloud.translation.v3beta1.TranslateTextResponse.translations\]
     /// if no terms apply. This field has the same length as
-    /// [`contents`][google.cloud.translation.v3beta1.TranslateTextRequest.contents].
+    /// \[`contents`][google.cloud.translation.v3beta1.TranslateTextRequest.contents\].
     #[prost(message, repeated, tag = "3")]
     pub glossary_translations: ::prost::alloc::vec::Vec<Translation>,
 }
@@ -106,6 +105,8 @@ pub struct TranslateTextResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Translation {
     /// Text translated into the target language.
+    /// If an error occurs during translation, this field might be excluded from
+    /// the response.
     #[prost(string, tag = "1")]
     pub translated_text: ::prost::alloc::string::String,
     /// Only present when `model` is present in the request.
@@ -140,7 +141,7 @@ pub struct DetectLanguageRequest {
     /// For global calls, use `projects/{project-number-or-id}/locations/global` or
     /// `projects/{project-number-or-id}`.
     ///
-    /// Only models within the same region, which have the same location-id, can be used.
+    /// Only models within the same region (has same location-id) can be used.
     /// Otherwise an INVALID_ARGUMENT (400) error is returned.
     #[prost(string, tag = "5")]
     pub parent: ::prost::alloc::string::String,
@@ -166,7 +167,7 @@ pub struct DetectLanguageRequest {
     /// characters, underscores and dashes. International characters are allowed.
     /// Label values are optional. Label keys must start with a letter.
     ///
-    /// See https://cloud.google.com/translate/docs/labels for more information.
+    /// See <https://cloud.google.com/translate/docs/labels> for more information.
     #[prost(map = "string, string", tag = "6")]
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
@@ -235,11 +236,10 @@ pub struct GetSupportedLanguagesRequest {
     ///
     /// - General (built-in) models:
     ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/nmt`,
-    ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/base`
     ///
     ///
     /// Returns languages supported by the specified model.
-    /// If missing, we get supported languages of Google general base (PBMT) model.
+    /// If missing, we get supported languages of Google general NMT model.
     #[prost(string, tag = "2")]
     pub model: ::prost::alloc::string::String,
 }
@@ -309,7 +309,7 @@ pub mod input_config {
         /// otherwise an error might be returned.
         /// Note that the input tsv must be RFC 4180 compliant.
         ///
-        /// You could use https://github.com/Clever/csvlint to check potential
+        /// You could use <https://github.com/Clever/csvlint> to check potential
         /// formatting errors in your tsv file.
         /// csvlint --delimiter='\t' your_input_file.tsv
         ///
@@ -341,7 +341,7 @@ pub mod output_config {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Destination {
         /// Google Cloud Storage destination for output content.
-        /// For every single input file (for example, gs://a/b/c.[extension]), we
+        /// For every single input file (for example, gs://a/b/c.\[extension\]), we
         /// generate at most 2 * n output files. (n is the # of target_language_codes
         /// in the BatchTranslateTextRequest).
         ///
@@ -368,17 +368,17 @@ pub mod output_config {
         /// content to output.
         ///
         /// Once a row is present in index.csv, the input/output matching never
-        /// changes. Callers should also expect the contents in the input_file are
+        /// changes. Callers should also expect all the content in input_file are
         /// processed and ready to be consumed (that is, no partial output file is
         /// written).
         ///
-        /// Since index.csv will be updated during the process, please make
+        /// Since index.csv will be keeping updated during the process, please make
         /// sure there is no custom retention policy applied on the output bucket
-        /// that may prevent file updating.
-        /// (https://cloud.google.com/storage/docs/bucket-lock?hl=en#retention-policy)
+        /// that may avoid file updating.
+        /// (<https://cloud.google.com/storage/docs/bucket-lock?hl=en#retention-policy>)
         ///
         /// The format of translations_file (for target language code 'trg') is:
-        /// gs://translation_test/a_b_c_'trg'_translations.[extension]
+        /// gs://translation_test/a_b_c_'trg'_translations.\[extension\]
         ///
         /// If the input file extension is tsv, the output has the following
         /// columns:
@@ -395,10 +395,10 @@ pub mod output_config {
         /// If input file extension is a txt or html, the translation is directly
         /// written to the output file. If glossary is requested, a separate
         /// glossary_translations_file has format of
-        /// gs://translation_test/a_b_c_'trg'_glossary_translations.[extension]
+        /// gs://translation_test/a_b_c_'trg'_glossary_translations.\[extension\]
         ///
         /// The format of errors file (for target language code 'trg') is:
-        /// gs://translation_test/a_b_c_'trg'_errors.[extension]
+        /// gs://translation_test/a_b_c_'trg'_errors.\[extension\]
         ///
         /// If the input file extension is tsv, errors_file contains the following:
         /// Column 1: ID of the request provided in the input, if it's not
@@ -410,7 +410,7 @@ pub mod output_config {
         ///
         /// If the input file extension is txt or html, glossary_error_file will be
         /// generated that contains error details. glossary_error_file has format of
-        /// gs://translation_test/a_b_c_'trg'_glossary_errors.[extension]
+        /// gs://translation_test/a_b_c_'trg'_glossary_errors.\[extension\]
         #[prost(message, tag = "1")]
         GcsDestination(super::GcsDestination),
     }
@@ -501,34 +501,34 @@ pub mod document_output_config {
         /// already exists in the destination an error will be returned.
         ///
         /// For a DocumentInputConfig.contents provided document, the output file
-        /// will have the name "output_[trg]_translations.[ext]", where
-        /// - [trg] corresponds to the translated file's language code,
-        /// - [ext] corresponds to the translated file's extension according to its
+        /// will have the name "output_\[trg]_translations.[ext\]", where
+        /// - \[trg\] corresponds to the translated file's language code,
+        /// - \[ext\] corresponds to the translated file's extension according to its
         /// mime type.
         ///
         ///
         /// For a DocumentInputConfig.gcs_uri provided document, the output file will
         /// have a name according to its URI. For example: an input file with URI:
-        /// "gs://a/b/c.[extension]" stored in a gcs_destination bucket with name
+        /// "gs://a/b/c.\[extension\]" stored in a gcs_destination bucket with name
         /// "my_bucket" will have an output URI:
-        /// "gs://my_bucket/a_b_c_[trg]_translations.[ext]", where
-        /// - [trg] corresponds to the translated file's language code,
-        /// - [ext] corresponds to the translated file's extension according to its
+        /// "gs://my_bucket/a_b_c_\[trg]_translations.[ext\]", where
+        /// - \[trg\] corresponds to the translated file's language code,
+        /// - \[ext\] corresponds to the translated file's extension according to its
         /// mime type.
         ///
         ///
         /// If the document was directly provided through the request, then the
         /// output document will have the format:
-        /// "gs://my_bucket/translated_document_[trg]_translations.[ext], where
-        /// - [trg] corresponds to the translated file's language code,
-        /// - [ext] corresponds to the translated file's extension according to its
+        /// "gs://my_bucket/translated_document_\[trg]_translations.[ext\], where
+        /// - \[trg\] corresponds to the translated file's language code,
+        /// - \[ext\] corresponds to the translated file's extension according to its
         /// mime type.
         ///
         /// If a glossary was provided, then the output URI for the glossary
         /// translation will be equal to the default output URI but have
         /// `glossary_translations` instead of `translations`. For the previous
         /// example, its glossary URI would be:
-        /// "gs://my_bucket/a_b_c_[trg]_glossary_translations.[ext]".
+        /// "gs://my_bucket/a_b_c_\[trg]_glossary_translations.[ext\]".
         ///
         /// Thus the max number of output files will be 2 (Translated document,
         /// Glossary translated document).
@@ -547,8 +547,7 @@ pub struct TranslateDocumentRequest {
     ///
     /// Format: `projects/{project-number-or-id}/locations/{location-id}`.
     ///
-    /// For global calls, use `projects/{project-number-or-id}/locations/global` or
-    /// `projects/{project-number-or-id}`.
+    /// For global calls, use `projects/{project-number-or-id}/locations/global`.
     ///
     /// Non-global location is required for requests using AutoML models or custom
     /// glossaries.
@@ -588,7 +587,6 @@ pub struct TranslateDocumentRequest {
     ///
     /// - General (built-in) models:
     ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/nmt`,
-    ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/base`
     ///
     ///
     /// If not provided, the default Google model (NMT) will be used for
@@ -607,7 +605,7 @@ pub struct TranslateDocumentRequest {
     /// underscores and dashes. International characters are allowed. Label values
     /// are optional. Label keys must start with a letter.
     ///
-    /// See https://cloud.google.com/translate/docs/advanced/labels for more
+    /// See <https://cloud.google.com/translate/docs/advanced/labels> for more
     /// information.
     #[prost(map = "string, string", tag = "8")]
     pub labels:
@@ -639,7 +637,7 @@ pub struct TranslateDocumentResponse {
     #[prost(message, optional, tag = "1")]
     pub document_translation: ::core::option::Option<DocumentTranslation>,
     /// The document's translation output if a glossary is provided in the request.
-    /// This can be the same as [TranslateDocumentResponse.document_translation]
+    /// This can be the same as \[TranslateDocumentResponse.document_translation\]
     /// if no glossary terms apply.
     #[prost(message, optional, tag = "2")]
     pub glossary_document_translation: ::core::option::Option<DocumentTranslation>,
@@ -678,7 +676,7 @@ pub struct BatchTranslateTextRequest {
     #[prost(string, repeated, tag = "3")]
     pub target_language_codes: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// Optional. The models to use for translation. Map's key is target language
-    /// code. Map's value is the model name. Value can be a built-in general model,
+    /// code. Map's value is model name. Value can be a built-in general model,
     /// or an AutoML Translation model.
     ///
     /// The value format depends on model type:
@@ -688,7 +686,6 @@ pub struct BatchTranslateTextRequest {
     ///
     /// - General (built-in) models:
     ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/nmt`,
-    ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/base`
     ///
     ///
     /// If the map is empty or a specific model is
@@ -719,7 +716,7 @@ pub struct BatchTranslateTextRequest {
     /// characters, underscores and dashes. International characters are allowed.
     /// Label values are optional. Label keys must start with a letter.
     ///
-    /// See https://cloud.google.com/translate/docs/labels for more information.
+    /// See <https://cloud.google.com/translate/docs/labels> for more information.
     #[prost(map = "string, string", tag = "9")]
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
@@ -771,7 +768,7 @@ pub mod batch_translate_metadata {
     }
 }
 /// Stored in the
-/// [google.longrunning.Operation.response][google.longrunning.Operation.response]
+/// \[google.longrunning.Operation.response][google.longrunning.Operation.response\]
 /// field returned by BatchTranslateText if at least one sentence is translated
 /// successfully.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -789,7 +786,7 @@ pub struct BatchTranslateResponse {
     #[prost(message, optional, tag = "4")]
     pub submit_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time when the operation is finished and
-    /// [google.longrunning.Operation.done][google.longrunning.Operation.done] is
+    /// \[google.longrunning.Operation.done][google.longrunning.Operation.done\] is
     /// set to true.
     #[prost(message, optional, tag = "5")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
@@ -808,7 +805,7 @@ pub mod glossary_input_config {
     pub enum Source {
         /// Required. Google Cloud Storage location of glossary data.
         /// File format is determined based on the filename extension. API returns
-        /// [google.rpc.Code.INVALID_ARGUMENT] for unsupported URI-s and file
+        /// \[google.rpc.Code.INVALID_ARGUMENT\] for unsupported URI-s and file
         /// formats. Wildcards are not allowed. This must be a single file in one of
         /// the following formats:
         ///
@@ -827,7 +824,7 @@ pub mod glossary_input_config {
         /// - CSV (`.csv`): Multi-column CSV file defining equivalent glossary terms
         ///   in multiple languages. The format is defined for Google Translation
         ///   Toolkit and documented in [Use a
-        ///   glossary](https://support.google.com/translatortoolkit/answer/6306379?hl=en).
+        ///   glossary](<https://support.google.com/translatortoolkit/answer/6306379?hl=en>).
         #[prost(message, tag = "1")]
         GcsSource(super::GcsSource),
     }
@@ -925,7 +922,7 @@ pub struct ListGlossariesRequest {
     #[prost(int32, tag = "2")]
     pub page_size: i32,
     /// Optional. A token identifying a page of results the server should return.
-    /// Typically, this is the value of [ListGlossariesResponse.next_page_token]
+    /// Typically, this is the value of \[ListGlossariesResponse.next_page_token\]
     /// returned from the previous call to `ListGlossaries` method.
     /// The first page is returned if `page_token`is empty or missing.
     #[prost(string, tag = "3")]
@@ -956,13 +953,13 @@ pub struct ListGlossariesResponse {
     #[prost(message, repeated, tag = "1")]
     pub glossaries: ::prost::alloc::vec::Vec<Glossary>,
     /// A token to retrieve a page of results. Pass this value in the
-    /// [ListGlossariesRequest.page_token] field in the subsequent call to
+    /// \[ListGlossariesRequest.page_token\] field in the subsequent call to
     /// `ListGlossaries` method to retrieve the next page of results.
     #[prost(string, tag = "2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// Stored in the
-/// [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata]
+/// \[google.longrunning.Operation.metadata][google.longrunning.Operation.metadata\]
 /// field returned by CreateGlossary.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateGlossaryMetadata {
@@ -998,7 +995,7 @@ pub mod create_glossary_metadata {
     }
 }
 /// Stored in the
-/// [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata]
+/// \[google.longrunning.Operation.metadata][google.longrunning.Operation.metadata\]
 /// field returned by DeleteGlossary.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteGlossaryMetadata {
@@ -1034,7 +1031,7 @@ pub mod delete_glossary_metadata {
     }
 }
 /// Stored in the
-/// [google.longrunning.Operation.response][google.longrunning.Operation.response]
+/// \[google.longrunning.Operation.response][google.longrunning.Operation.response\]
 /// field returned by DeleteGlossary.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteGlossaryResponse {
@@ -1045,7 +1042,7 @@ pub struct DeleteGlossaryResponse {
     #[prost(message, optional, tag = "2")]
     pub submit_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time when the glossary deletion is finished and
-    /// [google.longrunning.Operation.done][google.longrunning.Operation.done] is
+    /// \[google.longrunning.Operation.done][google.longrunning.Operation.done\] is
     /// set to true.
     #[prost(message, optional, tag = "3")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
@@ -1066,7 +1063,7 @@ pub struct BatchTranslateDocumentRequest {
     pub parent: ::prost::alloc::string::String,
     /// Required. The BCP-47 language code of the input document if known, for
     /// example, "en-US" or "sr-Latn". Supported language codes are listed in
-    /// Language Support (https://cloud.google.com/translate/docs/languages).
+    /// Language Support (<https://cloud.google.com/translate/docs/languages>).
     #[prost(string, tag = "2")]
     pub source_language_code: ::prost::alloc::string::String,
     /// Required. The BCP-47 language code to use for translation of the input
@@ -1095,7 +1092,6 @@ pub struct BatchTranslateDocumentRequest {
     ///
     /// - General (built-in) models:
     ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/nmt`,
-    ///   `projects/{project-number-or-id}/locations/{location-id}/models/general/base`
     ///
     ///
     /// If the map is empty or a specific model is not requested for a language
@@ -1107,6 +1103,19 @@ pub struct BatchTranslateDocumentRequest {
     #[prost(map = "string, message", tag = "7")]
     pub glossaries:
         ::std::collections::HashMap<::prost::alloc::string::String, TranslateTextGlossaryConfig>,
+    /// Optional. File format conversion map to be applied to all input files.
+    /// Map's key is the original mime_type. Map's value is the target mime_type of
+    /// translated documents.
+    ///
+    /// Supported file format conversion includes:
+    /// - `application/pdf` to
+    ///   `application/vnd.openxmlformats-officedocument.wordprocessingml.document`
+    ///
+    /// If nothing specified, output files will be in the same format as the
+    /// original file.
+    #[prost(map = "string, string", tag = "8")]
+    pub format_conversions:
+        ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
 /// Input configuration for BatchTranslateDocument request.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -1135,10 +1144,10 @@ pub mod batch_document_input_config {
         /// - `xlsx`,
         /// application/vnd.openxmlformats-officedocument.spreadsheetml.sheet
         ///
-        /// The max file size supported for `.docx`, `.pptx` and `.xlsx` is 100MB.
-        /// The max file size supported for `.pdf` is 1GB and the max page limit is
+        /// The max file size to support for `.docx`, `.pptx` and `.xlsx` is 100MB.
+        /// The max file size to support for `.pdf` is 1GB and the max page limit is
         /// 1000 pages.
-        /// The max file size supported for all input documents is 1GB.
+        /// The max file size to support for all input documents is 1GB.
         #[prost(message, tag = "1")]
         GcsSource(super::GcsSource),
     }
@@ -1158,7 +1167,7 @@ pub mod batch_document_output_config {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum Destination {
         /// Google Cloud Storage destination for output content.
-        /// For every single input document (for example, gs://a/b/c.[extension]), we
+        /// For every single input document (for example, gs://a/b/c.\[extension\]), we
         /// generate at most 2 * n output files. (n is the # of target_language_codes
         /// in the BatchTranslateDocumentRequest).
         ///
@@ -1188,40 +1197,40 @@ pub mod batch_document_output_config {
         /// Since index.csv will be keeping updated during the process, please make
         /// sure there is no custom retention policy applied on the output bucket
         /// that may avoid file updating.
-        /// (https://cloud.google.com/storage/docs/bucket-lock?hl=en#retention-policy)
+        /// (<https://cloud.google.com/storage/docs/bucket-lock?hl=en#retention-policy>)
         ///
         /// The naming format of translation output files follows (for target
-        /// language code [trg]): `translation_output`:
-        /// gs://translation_output/a_b_c_[trg]_translation.[extension]
+        /// language code \[trg\]): `translation_output`:
+        /// gs://translation_output/a_b_c_\[trg]_translation.[extension\]
         /// `glossary_translation_output`:
-        /// gs://translation_test/a_b_c_[trg]_glossary_translation.[extension] The
+        /// gs://translation_test/a_b_c_\[trg]_glossary_translation.[extension\] The
         /// output document will maintain the same file format as the input document.
         ///
         /// The naming format of error output files follows (for target language code
-        /// [trg]): `error_output`: gs://translation_test/a_b_c_[trg]_errors.txt
+        /// \[trg\]): `error_output`: gs://translation_test/a_b_c_\[trg\]_errors.txt
         /// `glossary_error_output`:
-        /// gs://translation_test/a_b_c_[trg]_glossary_translation.txt The error
+        /// gs://translation_test/a_b_c_\[trg\]_glossary_translation.txt The error
         /// output is a txt file containing error details.
         #[prost(message, tag = "1")]
         GcsDestination(super::GcsDestination),
     }
 }
 /// Stored in the
-/// [google.longrunning.Operation.response][google.longrunning.Operation.response]
+/// \[google.longrunning.Operation.response][google.longrunning.Operation.response\]
 /// field returned by BatchTranslateDocument if at least one document is
 /// translated successfully.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchTranslateDocumentResponse {
-    /// Total number of pages to translate in all documents. Documents without a
+    /// Total number of pages to translate in all documents. Documents without
     /// clear page definition (such as XLSX) are not counted.
     #[prost(int64, tag = "1")]
     pub total_pages: i64,
     /// Number of successfully translated pages in all documents. Documents without
-    /// a clear page definition (such as XLSX) are not counted.
+    /// clear page definition (such as XLSX) are not counted.
     #[prost(int64, tag = "2")]
     pub translated_pages: i64,
     /// Number of pages that failed to process in all documents. Documents without
-    /// a clear page definition (such as XLSX) are not counted.
+    /// clear page definition (such as XLSX) are not counted.
     #[prost(int64, tag = "3")]
     pub failed_pages: i64,
     /// Number of billable pages in documents with clear page definition (such as
@@ -1247,7 +1256,7 @@ pub struct BatchTranslateDocumentResponse {
     #[prost(message, optional, tag = "9")]
     pub submit_time: ::core::option::Option<::prost_types::Timestamp>,
     /// The time when the operation is finished and
-    /// [google.longrunning.Operation.done][google.longrunning.Operation.done] is
+    /// \[google.longrunning.Operation.done][google.longrunning.Operation.done\] is
     /// set to true.
     #[prost(message, optional, tag = "10")]
     pub end_time: ::core::option::Option<::prost_types::Timestamp>,
@@ -1328,7 +1337,7 @@ pub mod translation_service_client {
     impl<T> TranslationServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -1341,7 +1350,7 @@ pub mod translation_service_client {
             interceptor: F,
         ) -> TranslationServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
