@@ -2,12 +2,12 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AnnotateVideoRequest {
     /// Input video location. Currently, only
-    /// [Google Cloud Storage](https://cloud.google.com/storage/) URIs are
+    /// [Google Cloud Storage](<https://cloud.google.com/storage/>) URIs are
     /// supported, which must be specified in the following format:
     /// `gs://bucket-id/object-id` (other URI formats return
-    /// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]). For
+    /// \[google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT\]). For
     /// more information, see [Request
-    /// URIs](https://cloud.google.com/storage/docs/request-endpoints). A video URI
+    /// URIs](<https://cloud.google.com/storage/docs/request-endpoints>). A video URI
     /// may include wildcards in `object-id`, and thus identify multiple videos.
     /// Supported wildcards: '*' to match 0 or more characters;
     /// '?' to match 1 character. If unset, the input video should be embedded
@@ -26,12 +26,12 @@ pub struct AnnotateVideoRequest {
     #[prost(message, optional, tag = "3")]
     pub video_context: ::core::option::Option<VideoContext>,
     /// Optional. Location where the output (in JSON format) should be stored.
-    /// Currently, only [Google Cloud Storage](https://cloud.google.com/storage/)
+    /// Currently, only [Google Cloud Storage](<https://cloud.google.com/storage/>)
     /// URIs are supported, which must be specified in the following format:
     /// `gs://bucket-id/object-id` (other URI formats return
-    /// [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]). For
+    /// \[google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT\]). For
     /// more information, see [Request
-    /// URIs](https://cloud.google.com/storage/docs/request-endpoints).
+    /// URIs](<https://cloud.google.com/storage/docs/request-endpoints>).
     #[prost(string, tag = "4")]
     pub output_uri: ::prost::alloc::string::String,
     /// Optional. Cloud region where annotation should take place. Supported cloud
@@ -136,7 +136,7 @@ pub struct LabelFrame {
 pub struct Entity {
     /// Opaque entity ID. Some IDs may be available in
     /// [Google Knowledge Graph Search
-    /// API](https://developers.google.com/knowledge-graph/).
+    /// API](<https://developers.google.com/knowledge-graph/>).
     #[prost(string, tag = "1")]
     pub entity_id: ::prost::alloc::string::String,
     /// Textual description, e.g. `Fixed-gear bicycle`.
@@ -189,7 +189,7 @@ pub struct ExplicitContentAnnotation {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct VideoAnnotationResults {
     /// Output only. Video file location in
-    /// [Google Cloud Storage](https://cloud.google.com/storage/).
+    /// [Google Cloud Storage](<https://cloud.google.com/storage/>).
     #[prost(string, tag = "1")]
     pub input_uri: ::prost::alloc::string::String,
     /// Label annotations on video level or user specified segment level.
@@ -231,7 +231,7 @@ pub struct AnnotateVideoResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct VideoAnnotationProgress {
     /// Output only. Video file location in
-    /// [Google Cloud Storage](https://cloud.google.com/storage/).
+    /// [Google Cloud Storage](<https://cloud.google.com/storage/>).
     #[prost(string, tag = "1")]
     pub input_uri: ::prost::alloc::string::String,
     /// Output only. Approximate percentage processed thus far. Guaranteed to be
@@ -258,9 +258,9 @@ pub struct AnnotateVideoProgress {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SpeechTranscriptionConfig {
     /// Required. *Required* The language of the supplied audio as a
-    /// [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag.
+    /// \[BCP-47\](<https://www.rfc-editor.org/rfc/bcp/bcp47.txt>) language tag.
     /// Example: "en-US".
-    /// See [Language Support](https://cloud.google.com/speech/docs/languages)
+    /// See [Language Support](<https://cloud.google.com/speech/docs/languages>)
     /// for a list of the currently supported language codes.
     #[prost(string, tag = "1")]
     pub language_code: ::prost::alloc::string::String,
@@ -302,7 +302,7 @@ pub struct SpeechContext {
     /// to improve the accuracy for specific words and phrases, for example, if
     /// specific commands are typically spoken by the user. This can also be used
     /// to add additional words to the vocabulary of the recognizer. See
-    /// [usage limits](https://cloud.google.com/speech/limits#content).
+    /// [usage limits](<https://cloud.google.com/speech/limits#content>).
     #[prost(string, repeated, tag = "1")]
     pub phrases: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
@@ -412,7 +412,7 @@ pub mod video_intelligence_service_client {
     impl<T> VideoIntelligenceServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -425,7 +425,7 @@ pub mod video_intelligence_service_client {
             interceptor: F,
         ) -> VideoIntelligenceServiceClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
