@@ -8,7 +8,7 @@
 ///
 /// - May be `""`.
 /// - Must be valid UTF-8 bytes.
-/// - Must have values that match regex `[A-Za-z\d\.\-_]{1,100}`
+/// - Must have values that match regex `\[A-Za-z\d\.\-_\]{1,100}`
 /// If the value of any dimension matches regex `__.*__`, the partition is
 /// reserved/read-only.
 /// A reserved/read-only partition ID is forbidden in certain documented
@@ -115,10 +115,7 @@ pub struct Value {
     #[prost(bool, tag = "19")]
     pub exclude_from_indexes: bool,
     /// Must have a value set.
-    #[prost(
-        oneof = "value::ValueType",
-        tags = "11, 1, 2, 3, 10, 5, 17, 18, 8, 6, 9"
-    )]
+    #[prost(oneof = "value::ValueType", tags = "11, 1, 2, 3, 10, 5, 17, 18, 8, 6, 9")]
     pub value_type: ::core::option::Option<value::ValueType>,
 }
 /// Nested message and enum types in `Value`.
@@ -209,10 +206,10 @@ pub struct EntityResult {
     /// increases with changes to the entity.
     ///
     /// This field is set for
-    /// [`FULL`][google.datastore.v1beta3.EntityResult.ResultType.FULL] entity
+    /// \[`FULL`][google.datastore.v1beta3.EntityResult.ResultType.FULL\] entity
     /// results.
     ///
-    /// For [missing][google.datastore.v1beta3.LookupResponse.missing] entities in
+    /// For \[missing][google.datastore.v1beta3.LookupResponse.missing\] entities in
     /// `LookupResponse`, this is the version of the snapshot that was used to look
     /// up the entity, and it is always set except for eventually consistent reads.
     #[prost(int64, tag = "4")]
@@ -266,13 +263,13 @@ pub struct Query {
     /// A starting point for the query results. Query cursors are
     /// returned in query result batches and
     /// [can only be used to continue the same
-    /// query](https://cloud.google.com/datastore/docs/concepts/queries#cursors_limits_and_offsets).
+    /// query](<https://cloud.google.com/datastore/docs/concepts/queries#cursors_limits_and_offsets>).
     #[prost(bytes = "vec", tag = "7")]
     pub start_cursor: ::prost::alloc::vec::Vec<u8>,
     /// An ending point for the query results. Query cursors are
     /// returned in query result batches and
     /// [can only be used to limit the same
-    /// query](https://cloud.google.com/datastore/docs/concepts/queries#cursors_limits_and_offsets).
+    /// query](<https://cloud.google.com/datastore/docs/concepts/queries#cursors_limits_and_offsets>).
     #[prost(bytes = "vec", tag = "8")]
     pub end_cursor: ::prost::alloc::vec::Vec<u8>,
     /// The number of results to skip. Applies before limit, but after all other
@@ -411,11 +408,11 @@ pub mod property_filter {
     }
 }
 /// A [GQL
-/// query](https://cloud.google.com/datastore/docs/apis/gql/gql_reference).
+/// query](<https://cloud.google.com/datastore/docs/apis/gql/gql_reference>).
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GqlQuery {
     /// A string of the format described
-    /// [here](https://cloud.google.com/datastore/docs/apis/gql/gql_reference).
+    /// \[here\](<https://cloud.google.com/datastore/docs/apis/gql/gql_reference>).
     #[prost(string, tag = "1")]
     pub query_string: ::prost::alloc::string::String,
     /// When false, the query string must not contain any literals and instead must
@@ -427,7 +424,7 @@ pub struct GqlQuery {
     /// For each non-reserved named binding site in the query string, there must be
     /// a named parameter with that name, but not necessarily the inverse.
     ///
-    /// Key must match regex `[A-Za-z_$][A-Za-z_$0-9]*`, must not match regex
+    /// Key must match regex `\[A-Za-z_$][A-Za-z_$0-9\]*`, must not match regex
     /// `__.*__`, and must not be `""`.
     #[prost(map = "string, message", tag = "5")]
     pub named_bindings:
@@ -515,7 +512,7 @@ pub mod query_result_batch {
     }
 }
 /// The request for
-/// [Datastore.Lookup][google.datastore.v1beta3.Datastore.Lookup].
+/// \[Datastore.Lookup][google.datastore.v1beta3.Datastore.Lookup\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct LookupRequest {
     /// The ID of the project against which to make the request.
@@ -529,7 +526,7 @@ pub struct LookupRequest {
     pub keys: ::prost::alloc::vec::Vec<Key>,
 }
 /// The response for
-/// [Datastore.Lookup][google.datastore.v1beta3.Datastore.Lookup].
+/// \[Datastore.Lookup][google.datastore.v1beta3.Datastore.Lookup\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct LookupResponse {
     /// Entities found as `ResultType.FULL` entities. The order of results in this
@@ -549,7 +546,7 @@ pub struct LookupResponse {
     pub deferred: ::prost::alloc::vec::Vec<Key>,
 }
 /// The request for
-/// [Datastore.RunQuery][google.datastore.v1beta3.Datastore.RunQuery].
+/// \[Datastore.RunQuery][google.datastore.v1beta3.Datastore.RunQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunQueryRequest {
     /// The ID of the project against which to make the request.
@@ -582,7 +579,7 @@ pub mod run_query_request {
     }
 }
 /// The response for
-/// [Datastore.RunQuery][google.datastore.v1beta3.Datastore.RunQuery].
+/// \[Datastore.RunQuery][google.datastore.v1beta3.Datastore.RunQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunQueryResponse {
     /// A batch of query results (always present).
@@ -593,7 +590,7 @@ pub struct RunQueryResponse {
     pub query: ::core::option::Option<Query>,
 }
 /// The request for
-/// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction].
+/// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BeginTransactionRequest {
     /// The ID of the project against which to make the request.
@@ -604,7 +601,7 @@ pub struct BeginTransactionRequest {
     pub transaction_options: ::core::option::Option<TransactionOptions>,
 }
 /// The response for
-/// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction].
+/// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BeginTransactionResponse {
     /// The transaction identifier (always present).
@@ -612,24 +609,24 @@ pub struct BeginTransactionResponse {
     pub transaction: ::prost::alloc::vec::Vec<u8>,
 }
 /// The request for
-/// [Datastore.Rollback][google.datastore.v1beta3.Datastore.Rollback].
+/// \[Datastore.Rollback][google.datastore.v1beta3.Datastore.Rollback\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RollbackRequest {
     /// The ID of the project against which to make the request.
     #[prost(string, tag = "8")]
     pub project_id: ::prost::alloc::string::String,
     /// The transaction identifier, returned by a call to
-    /// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction].
+    /// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\].
     #[prost(bytes = "vec", tag = "1")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
 }
 /// The response for
-/// [Datastore.Rollback][google.datastore.v1beta3.Datastore.Rollback]. (an empty
+/// \[Datastore.Rollback][google.datastore.v1beta3.Datastore.Rollback\]. (an empty
 /// message).
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RollbackResponse {}
 /// The request for
-/// [Datastore.Commit][google.datastore.v1beta3.Datastore.Commit].
+/// \[Datastore.Commit][google.datastore.v1beta3.Datastore.Commit\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CommitRequest {
     /// The ID of the project against which to make the request.
@@ -667,7 +664,7 @@ pub mod commit_request {
         Unspecified = 0,
         /// Transactional: The mutations are either all applied, or none are applied.
         /// Learn about transactions
-        /// [here](https://cloud.google.com/datastore/docs/concepts/transactions).
+        /// \[here\](<https://cloud.google.com/datastore/docs/concepts/transactions>).
         Transactional = 1,
         /// Non-transactional: The mutations may not apply as all or none.
         NonTransactional = 2,
@@ -677,13 +674,13 @@ pub mod commit_request {
     pub enum TransactionSelector {
         /// The identifier of the transaction associated with the commit. A
         /// transaction identifier is returned by a call to
-        /// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction].
+        /// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\].
         #[prost(bytes, tag = "1")]
         Transaction(::prost::alloc::vec::Vec<u8>),
     }
 }
 /// The response for
-/// [Datastore.Commit][google.datastore.v1beta3.Datastore.Commit].
+/// \[Datastore.Commit][google.datastore.v1beta3.Datastore.Commit\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CommitResponse {
     /// The result of performing the mutations.
@@ -696,7 +693,7 @@ pub struct CommitResponse {
     pub index_updates: i32,
 }
 /// The request for
-/// [Datastore.AllocateIds][google.datastore.v1beta3.Datastore.AllocateIds].
+/// \[Datastore.AllocateIds][google.datastore.v1beta3.Datastore.AllocateIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AllocateIdsRequest {
     /// The ID of the project against which to make the request.
@@ -708,7 +705,7 @@ pub struct AllocateIdsRequest {
     pub keys: ::prost::alloc::vec::Vec<Key>,
 }
 /// The response for
-/// [Datastore.AllocateIds][google.datastore.v1beta3.Datastore.AllocateIds].
+/// \[Datastore.AllocateIds][google.datastore.v1beta3.Datastore.AllocateIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AllocateIdsResponse {
     /// The keys specified in the request (in the same order), each with
@@ -717,7 +714,7 @@ pub struct AllocateIdsResponse {
     pub keys: ::prost::alloc::vec::Vec<Key>,
 }
 /// The request for
-/// [Datastore.ReserveIds][google.datastore.v1beta3.Datastore.ReserveIds].
+/// \[Datastore.ReserveIds][google.datastore.v1beta3.Datastore.ReserveIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReserveIdsRequest {
     /// The ID of the project against which to make the request.
@@ -732,7 +729,7 @@ pub struct ReserveIdsRequest {
     pub keys: ::prost::alloc::vec::Vec<Key>,
 }
 /// The response for
-/// [Datastore.ReserveIds][google.datastore.v1beta3.Datastore.ReserveIds].
+/// \[Datastore.ReserveIds][google.datastore.v1beta3.Datastore.ReserveIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReserveIdsResponse {}
 /// A mutation to apply to an entity.
@@ -846,7 +843,7 @@ pub mod read_options {
         ReadConsistency(i32),
         /// The identifier of the transaction in which to read. A
         /// transaction identifier is returned by a call to
-        /// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction].
+        /// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\].
         #[prost(bytes, tag = "2")]
         Transaction(::prost::alloc::vec::Vec<u8>),
     }
@@ -854,9 +851,9 @@ pub mod read_options {
 /// Options for beginning a new transaction.
 ///
 /// Transactions can be created explicitly with calls to
-/// [Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction]
+/// \[Datastore.BeginTransaction][google.datastore.v1beta3.Datastore.BeginTransaction\]
 /// or implicitly by setting
-/// [ReadOptions.new_transaction][google.datastore.v1beta3.ReadOptions.new_transaction]
+/// \[ReadOptions.new_transaction][google.datastore.v1beta3.ReadOptions.new_transaction\]
 /// in read requests.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct TransactionOptions {
@@ -907,7 +904,7 @@ pub mod datastore_client {
     impl<T> DatastoreClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -920,7 +917,7 @@ pub mod datastore_client {
             interceptor: F,
         ) -> DatastoreClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
