@@ -52,10 +52,7 @@ pub struct Document {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Value {
     /// Must have a value set.
-    #[prost(
-        oneof = "value::ValueType",
-        tags = "11, 1, 2, 3, 10, 17, 18, 5, 8, 9, 6"
-    )]
+    #[prost(oneof = "value::ValueType", tags = "11, 1, 2, 3, 10, 17, 18, 5, 8, 9, 6")]
     pub value_type: ::core::option::Option<value::ValueType>,
 }
 /// Nested message and enum types in `Value`.
@@ -398,7 +395,7 @@ pub mod structured_query {
         /// The fields to return.
         ///
         /// If empty, all fields are returned. To only return the name
-        /// of the document, use `['__name__']`.
+        /// of the document, use `\['__name__'\]`.
         #[prost(message, repeated, tag = "2")]
         pub fields: ::prost::alloc::vec::Vec<FieldReference>,
     }
@@ -432,10 +429,10 @@ pub struct Cursor {
 /// Used to restrict a get or update operation on a document to a subset of its
 /// fields.
 /// This is different from standard field masks, as this is always scoped to a
-/// [Document][google.firestore.v1.Document], and takes in account the dynamic nature of [Value][google.firestore.v1.Value].
+/// \[Document][google.firestore.v1.Document\], and takes in account the dynamic nature of \[Value][google.firestore.v1.Value\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DocumentMask {
-    /// The list of field paths in the mask. See [Document.fields][google.firestore.v1.Document.fields] for a field
+    /// The list of field paths in the mask. See \[Document.fields][google.firestore.v1.Document.fields\] for a field
     /// path syntax reference.
     #[prost(string, repeated, tag = "1")]
     pub field_paths: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
@@ -574,7 +571,7 @@ pub mod document_transform {
     /// A transformation of a field of the document.
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct FieldTransform {
-        /// The path of the field. See [Document.fields][google.firestore.v1.Document.fields] for the field path syntax
+        /// The path of the field. See \[Document.fields][google.firestore.v1.Document.fields\] for the field path syntax
         /// reference.
         #[prost(string, tag = "1")]
         pub field_path: ::prost::alloc::string::String,
@@ -682,21 +679,21 @@ pub struct WriteResult {
     /// previous update_time.
     #[prost(message, optional, tag = "1")]
     pub update_time: ::core::option::Option<::prost_types::Timestamp>,
-    /// The results of applying each [DocumentTransform.FieldTransform][google.firestore.v1.DocumentTransform.FieldTransform], in the
+    /// The results of applying each \[DocumentTransform.FieldTransform][google.firestore.v1.DocumentTransform.FieldTransform\], in the
     /// same order.
     #[prost(message, repeated, tag = "2")]
     pub transform_results: ::prost::alloc::vec::Vec<Value>,
 }
-/// A [Document][google.firestore.v1.Document] has changed.
+/// A \[Document][google.firestore.v1.Document\] has changed.
 ///
-/// May be the result of multiple [writes][google.firestore.v1.Write], including deletes, that
-/// ultimately resulted in a new value for the [Document][google.firestore.v1.Document].
+/// May be the result of multiple \[writes][google.firestore.v1.Write\], including deletes, that
+/// ultimately resulted in a new value for the \[Document][google.firestore.v1.Document\].
 ///
-/// Multiple [DocumentChange][google.firestore.v1.DocumentChange] messages may be returned for the same logical
+/// Multiple \[DocumentChange][google.firestore.v1.DocumentChange\] messages may be returned for the same logical
 /// change, if multiple targets are affected.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DocumentChange {
-    /// The new state of the [Document][google.firestore.v1.Document].
+    /// The new state of the \[Document][google.firestore.v1.Document\].
     ///
     /// If `mask` is set, contains only fields that were updated or added.
     #[prost(message, optional, tag = "1")]
@@ -708,16 +705,16 @@ pub struct DocumentChange {
     #[prost(int32, repeated, tag = "6")]
     pub removed_target_ids: ::prost::alloc::vec::Vec<i32>,
 }
-/// A [Document][google.firestore.v1.Document] has been deleted.
+/// A \[Document][google.firestore.v1.Document\] has been deleted.
 ///
-/// May be the result of multiple [writes][google.firestore.v1.Write], including updates, the
-/// last of which deleted the [Document][google.firestore.v1.Document].
+/// May be the result of multiple \[writes][google.firestore.v1.Write\], including updates, the
+/// last of which deleted the \[Document][google.firestore.v1.Document\].
 ///
-/// Multiple [DocumentDelete][google.firestore.v1.DocumentDelete] messages may be returned for the same logical
+/// Multiple \[DocumentDelete][google.firestore.v1.DocumentDelete\] messages may be returned for the same logical
 /// delete, if multiple targets are affected.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DocumentDelete {
-    /// The resource name of the [Document][google.firestore.v1.Document] that was deleted.
+    /// The resource name of the \[Document][google.firestore.v1.Document\] that was deleted.
     #[prost(string, tag = "1")]
     pub document: ::prost::alloc::string::String,
     /// A set of target IDs for targets that previously matched this entity.
@@ -729,17 +726,17 @@ pub struct DocumentDelete {
     #[prost(message, optional, tag = "4")]
     pub read_time: ::core::option::Option<::prost_types::Timestamp>,
 }
-/// A [Document][google.firestore.v1.Document] has been removed from the view of the targets.
+/// A \[Document][google.firestore.v1.Document\] has been removed from the view of the targets.
 ///
 /// Sent if the document is no longer relevant to a target and is out of view.
 /// Can be sent instead of a DocumentDelete or a DocumentChange if the server
 /// can not send the new value of the document.
 ///
-/// Multiple [DocumentRemove][google.firestore.v1.DocumentRemove] messages may be returned for the same logical
+/// Multiple \[DocumentRemove][google.firestore.v1.DocumentRemove\] messages may be returned for the same logical
 /// write or delete, if multiple targets are affected.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DocumentRemove {
-    /// The resource name of the [Document][google.firestore.v1.Document] that has gone out of view.
+    /// The resource name of the \[Document][google.firestore.v1.Document\] that has gone out of view.
     #[prost(string, tag = "1")]
     pub document: ::prost::alloc::string::String,
     /// A set of target IDs for targets that previously matched this document.
@@ -757,14 +754,14 @@ pub struct ExistenceFilter {
     /// The target ID to which this filter applies.
     #[prost(int32, tag = "1")]
     pub target_id: i32,
-    /// The total count of documents that match [target_id][google.firestore.v1.ExistenceFilter.target_id].
+    /// The total count of documents that match \[target_id][google.firestore.v1.ExistenceFilter.target_id\].
     ///
     /// If different from the count of documents in the client that match, the
     /// client must manually determine which documents no longer match the target.
     #[prost(int32, tag = "2")]
     pub count: i32,
 }
-/// The request for [Firestore.GetDocument][google.firestore.v1.Firestore.GetDocument].
+/// The request for \[Firestore.GetDocument][google.firestore.v1.Firestore.GetDocument\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetDocumentRequest {
     /// Required. The resource name of the Document to get. In the format:
@@ -797,7 +794,7 @@ pub mod get_document_request {
         ReadTime(::prost_types::Timestamp),
     }
 }
-/// The request for [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
+/// The request for \[Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListDocumentsRequest {
     /// Required. The parent resource name. In the format:
@@ -829,8 +826,8 @@ pub struct ListDocumentsRequest {
     pub mask: ::core::option::Option<DocumentMask>,
     /// If the list should show missing documents. A missing document is a
     /// document that does not exist but has sub-documents. These documents will
-    /// be returned with a key but will not have fields, [Document.create_time][google.firestore.v1.Document.create_time],
-    /// or [Document.update_time][google.firestore.v1.Document.update_time] set.
+    /// be returned with a key but will not have fields, \[Document.create_time][google.firestore.v1.Document.create_time\],
+    /// or \[Document.update_time][google.firestore.v1.Document.update_time\] set.
     ///
     /// Requests with `show_missing` may not specify `where` or
     /// `order_by`.
@@ -856,7 +853,7 @@ pub mod list_documents_request {
         ReadTime(::prost_types::Timestamp),
     }
 }
-/// The response for [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
+/// The response for \[Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListDocumentsResponse {
     /// The Documents found.
@@ -866,7 +863,7 @@ pub struct ListDocumentsResponse {
     #[prost(string, tag = "2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
-/// The request for [Firestore.CreateDocument][google.firestore.v1.Firestore.CreateDocument].
+/// The request for \[Firestore.CreateDocument][google.firestore.v1.Firestore.CreateDocument\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CreateDocumentRequest {
     /// Required. The parent resource. For example:
@@ -892,7 +889,7 @@ pub struct CreateDocumentRequest {
     #[prost(message, optional, tag = "5")]
     pub mask: ::core::option::Option<DocumentMask>,
 }
-/// The request for [Firestore.UpdateDocument][google.firestore.v1.Firestore.UpdateDocument].
+/// The request for \[Firestore.UpdateDocument][google.firestore.v1.Firestore.UpdateDocument\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdateDocumentRequest {
     /// Required. The updated document.
@@ -919,7 +916,7 @@ pub struct UpdateDocumentRequest {
     #[prost(message, optional, tag = "4")]
     pub current_document: ::core::option::Option<Precondition>,
 }
-/// The request for [Firestore.DeleteDocument][google.firestore.v1.Firestore.DeleteDocument].
+/// The request for \[Firestore.DeleteDocument][google.firestore.v1.Firestore.DeleteDocument\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct DeleteDocumentRequest {
     /// Required. The resource name of the Document to delete. In the format:
@@ -931,7 +928,7 @@ pub struct DeleteDocumentRequest {
     #[prost(message, optional, tag = "2")]
     pub current_document: ::core::option::Option<Precondition>,
 }
-/// The request for [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
+/// The request for \[Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchGetDocumentsRequest {
     /// Required. The database name. In the format:
@@ -952,10 +949,7 @@ pub struct BatchGetDocumentsRequest {
     pub mask: ::core::option::Option<DocumentMask>,
     /// The consistency mode for this transaction.
     /// If not set, defaults to strong consistency.
-    #[prost(
-        oneof = "batch_get_documents_request::ConsistencySelector",
-        tags = "4, 5, 7"
-    )]
+    #[prost(oneof = "batch_get_documents_request::ConsistencySelector", tags = "4, 5, 7")]
     pub consistency_selector:
         ::core::option::Option<batch_get_documents_request::ConsistencySelector>,
 }
@@ -980,12 +974,12 @@ pub mod batch_get_documents_request {
         ReadTime(::prost_types::Timestamp),
     }
 }
-/// The streamed response for [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
+/// The streamed response for \[Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchGetDocumentsResponse {
     /// The transaction that was started as part of this request.
     /// Will only be set in the first response, and only if
-    /// [BatchGetDocumentsRequest.new_transaction][google.firestore.v1.BatchGetDocumentsRequest.new_transaction] was set in the request.
+    /// \[BatchGetDocumentsRequest.new_transaction][google.firestore.v1.BatchGetDocumentsRequest.new_transaction\] was set in the request.
     #[prost(bytes = "vec", tag = "3")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
     /// The time at which the document was read.
@@ -1014,7 +1008,7 @@ pub mod batch_get_documents_response {
         Missing(::prost::alloc::string::String),
     }
 }
-/// The request for [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
+/// The request for \[Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BeginTransactionRequest {
     /// Required. The database name. In the format:
@@ -1026,14 +1020,14 @@ pub struct BeginTransactionRequest {
     #[prost(message, optional, tag = "2")]
     pub options: ::core::option::Option<TransactionOptions>,
 }
-/// The response for [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
+/// The response for \[Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BeginTransactionResponse {
     /// The transaction that was started.
     #[prost(bytes = "vec", tag = "1")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
 }
-/// The request for [Firestore.Commit][google.firestore.v1.Firestore.Commit].
+/// The request for \[Firestore.Commit][google.firestore.v1.Firestore.Commit\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CommitRequest {
     /// Required. The database name. In the format:
@@ -1049,7 +1043,7 @@ pub struct CommitRequest {
     #[prost(bytes = "vec", tag = "3")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
 }
-/// The response for [Firestore.Commit][google.firestore.v1.Firestore.Commit].
+/// The response for \[Firestore.Commit][google.firestore.v1.Firestore.Commit\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct CommitResponse {
     /// The result of applying the writes.
@@ -1063,7 +1057,7 @@ pub struct CommitResponse {
     #[prost(message, optional, tag = "2")]
     pub commit_time: ::core::option::Option<::prost_types::Timestamp>,
 }
-/// The request for [Firestore.Rollback][google.firestore.v1.Firestore.Rollback].
+/// The request for \[Firestore.Rollback][google.firestore.v1.Firestore.Rollback\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RollbackRequest {
     /// Required. The database name. In the format:
@@ -1074,7 +1068,7 @@ pub struct RollbackRequest {
     #[prost(bytes = "vec", tag = "2")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
 }
-/// The request for [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
+/// The request for \[Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunQueryRequest {
     /// Required. The parent resource name. In the format:
@@ -1121,12 +1115,12 @@ pub mod run_query_request {
         ReadTime(::prost_types::Timestamp),
     }
 }
-/// The response for [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
+/// The response for \[Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RunQueryResponse {
     /// The transaction that was started as part of this request.
     /// Can only be set in the first response, and only if
-    /// [RunQueryRequest.new_transaction][google.firestore.v1.RunQueryRequest.new_transaction] was set in the request.
+    /// \[RunQueryRequest.new_transaction][google.firestore.v1.RunQueryRequest.new_transaction\] was set in the request.
     /// If set, no other fields will be set in this response.
     #[prost(bytes = "vec", tag = "2")]
     pub transaction: ::prost::alloc::vec::Vec<u8>,
@@ -1148,7 +1142,7 @@ pub struct RunQueryResponse {
     #[prost(int32, tag = "4")]
     pub skipped_results: i32,
 }
-/// The request for [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
+/// The request for \[Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PartitionQueryRequest {
     /// Required. The parent resource name. In the format:
@@ -1208,7 +1202,7 @@ pub mod partition_query_request {
         StructuredQuery(super::StructuredQuery),
     }
 }
-/// The response for [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
+/// The response for \[Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PartitionQueryResponse {
     /// Partition results.
@@ -1236,7 +1230,7 @@ pub struct PartitionQueryResponse {
     #[prost(string, tag = "2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
-/// The request for [Firestore.Write][google.firestore.v1.Firestore.Write].
+/// The request for \[Firestore.Write][google.firestore.v1.Firestore.Write\].
 ///
 /// The first request creates a stream, or resumes an existing one from a token.
 ///
@@ -1269,7 +1263,7 @@ pub struct WriteRequest {
     /// A stream token that was previously sent by the server.
     ///
     /// The client should set this field to the token from the most recent
-    /// [WriteResponse][google.firestore.v1.WriteResponse] it has received. This acknowledges that the client has
+    /// \[WriteResponse][google.firestore.v1.WriteResponse\] it has received. This acknowledges that the client has
     /// received responses up to this token. After sending this token, earlier
     /// tokens may not be used anymore.
     ///
@@ -1287,7 +1281,7 @@ pub struct WriteRequest {
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
-/// The response for [Firestore.Write][google.firestore.v1.Firestore.Write].
+/// The response for \[Firestore.Write][google.firestore.v1.Firestore.Write\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct WriteResponse {
     /// The ID of the stream.
@@ -1311,7 +1305,7 @@ pub struct WriteResponse {
     #[prost(message, optional, tag = "4")]
     pub commit_time: ::core::option::Option<::prost_types::Timestamp>,
 }
-/// A request for [Firestore.Listen][google.firestore.v1.Firestore.Listen]
+/// A request for \[Firestore.Listen][google.firestore.v1.Firestore.Listen\]
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListenRequest {
     /// Required. The database name. In the format:
@@ -1339,7 +1333,7 @@ pub mod listen_request {
         RemoveTarget(i32),
     }
 }
-/// The response for [Firestore.Listen][google.firestore.v1.Firestore.Listen].
+/// The response for \[Firestore.Listen][google.firestore.v1.Firestore.Listen\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListenResponse {
     /// The supported responses.
@@ -1354,13 +1348,13 @@ pub mod listen_response {
         /// Targets have changed.
         #[prost(message, tag = "2")]
         TargetChange(super::TargetChange),
-        /// A [Document][google.firestore.v1.Document] has changed.
+        /// A \[Document][google.firestore.v1.Document\] has changed.
         #[prost(message, tag = "3")]
         DocumentChange(super::DocumentChange),
-        /// A [Document][google.firestore.v1.Document] has been deleted.
+        /// A \[Document][google.firestore.v1.Document\] has been deleted.
         #[prost(message, tag = "4")]
         DocumentDelete(super::DocumentDelete),
-        /// A [Document][google.firestore.v1.Document] has been removed from a target (because it is no longer
+        /// A \[Document][google.firestore.v1.Document\] has been removed from a target (because it is no longer
         /// relevant to that target).
         #[prost(message, tag = "6")]
         DocumentRemove(super::DocumentRemove),
@@ -1446,7 +1440,7 @@ pub mod target {
     /// subsequent changes.
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum ResumeType {
-        /// A resume token from a prior [TargetChange][google.firestore.v1.TargetChange] for an identical target.
+        /// A resume token from a prior \[TargetChange][google.firestore.v1.TargetChange\] for an identical target.
         ///
         /// Using a resume token with a different target is unsupported and may fail.
         #[prost(bytes, tag = "4")]
@@ -1522,7 +1516,7 @@ pub mod target_change {
         Reset = 4,
     }
 }
-/// The request for [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
+/// The request for \[Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListCollectionIdsRequest {
     /// Required. The parent document. In the format:
@@ -1535,11 +1529,11 @@ pub struct ListCollectionIdsRequest {
     #[prost(int32, tag = "2")]
     pub page_size: i32,
     /// A page token. Must be a value from
-    /// [ListCollectionIdsResponse][google.firestore.v1.ListCollectionIdsResponse].
+    /// \[ListCollectionIdsResponse][google.firestore.v1.ListCollectionIdsResponse\].
     #[prost(string, tag = "3")]
     pub page_token: ::prost::alloc::string::String,
 }
-/// The response from [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
+/// The response from \[Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListCollectionIdsResponse {
     /// The collection ids.
@@ -1549,7 +1543,7 @@ pub struct ListCollectionIdsResponse {
     #[prost(string, tag = "2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
-/// The request for [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
+/// The request for \[Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchWriteRequest {
     /// Required. The database name. In the format:
@@ -1568,7 +1562,7 @@ pub struct BatchWriteRequest {
     pub labels:
         ::std::collections::HashMap<::prost::alloc::string::String, ::prost::alloc::string::String>,
 }
-/// The response from [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
+/// The response from \[Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct BatchWriteResponse {
     /// The result of applying the writes.
@@ -1603,7 +1597,7 @@ pub mod firestore_client {
     impl<T> FirestoreClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -1616,7 +1610,7 @@ pub mod firestore_client {
             interceptor: F,
         ) -> FirestoreClient<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
@@ -1729,9 +1723,7 @@ pub mod firestore_client {
             let path = http::uri::PathAndQuery::from_static(
                 "/google.firestore.v1.Firestore/BatchGetDocuments",
             );
-            self.inner
-                .server_streaming(request.into_request(), path, codec)
-                .await
+            self.inner.server_streaming(request.into_request(), path, codec).await
         }
         #[doc = " Starts a new transaction."]
         pub async fn begin_transaction(
@@ -1797,9 +1789,7 @@ pub mod firestore_client {
             let codec = tonic::codec::ProstCodec::default();
             let path =
                 http::uri::PathAndQuery::from_static("/google.firestore.v1.Firestore/RunQuery");
-            self.inner
-                .server_streaming(request.into_request(), path, codec)
-                .await
+            self.inner.server_streaming(request.into_request(), path, codec).await
         }
         #[doc = " Partitions a query by returning partition cursors that can be used to run"]
         #[doc = " the query in parallel. The returned partition cursors are split points that"]
@@ -1834,9 +1824,7 @@ pub mod firestore_client {
             })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static("/google.firestore.v1.Firestore/Write");
-            self.inner
-                .streaming(request.into_streaming_request(), path, codec)
-                .await
+            self.inner.streaming(request.into_streaming_request(), path, codec).await
         }
         #[doc = " Listens to changes."]
         pub async fn listen(
@@ -1853,9 +1841,7 @@ pub mod firestore_client {
             let codec = tonic::codec::ProstCodec::default();
             let path =
                 http::uri::PathAndQuery::from_static("/google.firestore.v1.Firestore/Listen");
-            self.inner
-                .streaming(request.into_streaming_request(), path, codec)
-                .await
+            self.inner.streaming(request.into_streaming_request(), path, codec).await
         }
         #[doc = " Lists all the collection IDs underneath a document."]
         pub async fn list_collection_ids(
