@@ -1,5 +1,5 @@
 /// Describes a Compute Engine resource that is being managed by a running
-/// [pipeline][google.genomics.v1alpha2.Pipeline].
+/// \[pipeline][google.genomics.v1alpha2.Pipeline\].
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ComputeEngine {
     /// The instance on which the operation is running.
@@ -16,7 +16,7 @@ pub struct ComputeEngine {
     pub disk_names: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Runtime metadata that will be populated in the
-/// [runtimeMetadata][google.genomics.v1.OperationMetadata.runtime_metadata]
+/// \[runtimeMetadata][google.genomics.v1.OperationMetadata.runtime_metadata\]
 /// field of the Operation associated with a RunPipeline execution.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct RuntimeMetadata {
@@ -53,10 +53,10 @@ pub struct Pipeline {
     /// Required fields:
     ///
     /// *
-    /// [minimumCpuCores][google.genomics.v1alpha2.PipelineResources.minimum_cpu_cores]
+    /// \[minimumCpuCores][google.genomics.v1alpha2.PipelineResources.minimum_cpu_cores\]
     ///
     /// *
-    /// [minimumRamGb][google.genomics.v1alpha2.PipelineResources.minimum_ram_gb]
+    /// \[minimumRamGb][google.genomics.v1alpha2.PipelineResources.minimum_ram_gb\]
     #[prost(message, optional, tag = "6")]
     pub resources: ::core::option::Option<PipelineResources>,
     /// Unique pipeline id that is generated by the service when CreatePipeline
@@ -134,12 +134,12 @@ pub struct RunPipelineArgs {
     /// Labels to apply to this pipeline run. Labels will also be applied to
     /// compute resources (VM, disks) created by this pipeline run. When listing
     /// operations, operations can [filtered by labels]
-    /// [google.longrunning.ListOperationsRequest.filter].
+    /// \[google.longrunning.ListOperationsRequest.filter\].
     /// Label keys may not be empty; label values may be empty. Non-empty labels
-    /// must be 1-63 characters long, and comply with [RFC1035]
-    /// (https://www.ietf.org/rfc/rfc1035.txt).
+    /// must be 1-63 characters long, and comply with \[RFC1035\]
+    /// (<https://www.ietf.org/rfc/rfc1035.txt>).
     /// Specifically, the name must be 1-63 characters long and match the regular
-    /// expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
+    /// expression `\[a-z]([-a-z0-9]*[a-z0-9\])?` which means the first
     /// character must be a lowercase letter, and all following characters must be
     /// a dash, lowercase letter, or digit, except the last character, which cannot
     /// be a dash.
@@ -314,11 +314,11 @@ pub struct ServiceAccount {
     /// List of scopes to be enabled for this service account on the VM.
     /// The following scopes are automatically included:
     ///
-    /// * https://www.googleapis.com/auth/compute
-    /// * https://www.googleapis.com/auth/devstorage.full_control
-    /// * https://www.googleapis.com/auth/genomics
-    /// * https://www.googleapis.com/auth/logging.write
-    /// * https://www.googleapis.com/auth/monitoring.write
+    /// * <https://www.googleapis.com/auth/compute>
+    /// * <https://www.googleapis.com/auth/devstorage.full_control>
+    /// * <https://www.googleapis.com/auth/genomics>
+    /// * <https://www.googleapis.com/auth/logging.write>
+    /// * <https://www.googleapis.com/auth/monitoring.write>
     #[prost(string, repeated, tag = "2")]
     pub scopes: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
@@ -363,7 +363,7 @@ pub struct PipelineResources {
     /// Whether to assign an external IP to the instance. This is an experimental
     /// feature that may go away. Defaults to false.
     /// Corresponds to `--no_address` flag for [gcloud compute instances create]
-    /// (https://cloud.google.com/sdk/gcloud/reference/compute/instances/create).
+    /// (<https://cloud.google.com/sdk/gcloud/reference/compute/instances/create>).
     /// In order to use this, must be true for both create time and run time.
     /// Cannot be true at run time if false at create time. If you need to ssh into
     /// a private IP VM for debugging, you can ssh to a public VM and then ssh into
@@ -392,9 +392,9 @@ pub mod pipeline_resources {
         #[prost(int32, tag = "3")]
         pub size_gb: i32,
         /// The full or partial URL of the persistent disk to attach. See
-        /// https://cloud.google.com/compute/docs/reference/latest/instances#resource
+        /// <https://cloud.google.com/compute/docs/reference/latest/instances#resource>
         /// and
-        /// https://cloud.google.com/compute/docs/disks/persistent-disks#snapshots
+        /// <https://cloud.google.com/compute/docs/disks/persistent-disks#snapshots>
         /// for more details.
         #[prost(string, tag = "4")]
         pub source: ::prost::alloc::string::String,
@@ -422,13 +422,13 @@ pub mod pipeline_resources {
             /// Default disk type. Use one of the other options below.
             Unspecified = 0,
             /// Specifies a Google Compute Engine persistent hard disk. See
-            /// https://cloud.google.com/compute/docs/disks/#pdspecs for details.
+            /// <https://cloud.google.com/compute/docs/disks/#pdspecs> for details.
             PersistentHdd = 1,
             /// Specifies a Google Compute Engine persistent solid-state disk. See
-            /// https://cloud.google.com/compute/docs/disks/#pdspecs for details.
+            /// <https://cloud.google.com/compute/docs/disks/#pdspecs> for details.
             PersistentSsd = 2,
             /// Specifies a Google Compute Engine local SSD.
-            /// See https://cloud.google.com/compute/docs/disks/local-ssd for details.
+            /// See <https://cloud.google.com/compute/docs/disks/local-ssd> for details.
             LocalSsd = 3,
         }
     }
@@ -447,7 +447,7 @@ pub mod pipeline_resources {
 /// If `localCopy` is defined, then the parameter specifies a data
 /// source or sink, both in Google Cloud Storage and on the Docker container
 /// where the pipeline computation is run. The [service account associated with
-/// the Pipeline][google.genomics.v1alpha2.RunPipelineArgs.service_account] (by
+/// the Pipeline]\[google.genomics.v1alpha2.RunPipelineArgs.service_account\] (by
 /// default the project's Compute Engine service account) must have access to the
 /// Google Cloud Storage paths.
 ///
@@ -476,7 +476,7 @@ pub mod pipeline_resources {
 /// map, such as:
 ///
 /// ```
-///   inputs["input_file"] = "gs://my-bucket/bar.txt"
+///   inputs\["input_file"\] = "gs://my-bucket/bar.txt"
 /// ```
 ///
 /// This would generate the following gsutil call:
@@ -575,7 +575,7 @@ pub struct DockerExecutor {
     ///
     /// If the command exits with a non-zero exit code, output parameter
     /// de-localization will be skipped and the pipeline operation's
-    /// [`error`][google.longrunning.Operation.error] field will be populated.
+    /// \[`error`][google.longrunning.Operation.error\] field will be populated.
     ///
     /// Maximum command string length is 16384.
     #[prost(string, tag = "2")]
@@ -593,7 +593,7 @@ pub mod pipelines_v1_alpha2_client {
     impl<T> PipelinesV1Alpha2Client<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + Sync + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
@@ -606,7 +606,7 @@ pub mod pipelines_v1_alpha2_client {
             interceptor: F,
         ) -> PipelinesV1Alpha2Client<InterceptedService<T, F>>
         where
-            F: FnMut(tonic::Request<()>) -> Result<tonic::Request<()>, tonic::Status>,
+            F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
                 http::Request<tonic::body::BoxBody>,
                 Response = http::Response<
